(in-package :cl-info)
(let (
(deffn-defvr-pairs '(
; CONTENT: (<INDEX TOPIC> . (<FILENAME> <BYTE OFFSET> <LENGTH IN CHARACTERS> <NODE NAME>))
("!" . ("maxima.info-1" 81302 2485 "Operadores Geral"))
("!!" . ("maxima.info-1" 83788 765 "Operadores Geral"))
("#" . ("maxima.info-1" 84554 1036 "Operadores Geral"))
("%" . ("maxima.info-1" 271092 630 "Definições para Entrada e Saída"))
("%%" . ("maxima.info-1" 271723 1177 "Definições para Entrada e Saída"))
("%e" . ("maxima.info-2" 74813 216 "Definições para Constantes"))
("%e_to_numlog" . ("maxima.info-2" 78541 388 "Definições para Logaritmos"))
("%edispflag" . ("maxima.info-1" 272901 224 "Definições para Entrada e Saída"))
("%emode" . ("maxima.info-1" 175861 583 "Definições para Expressões"))
("%enumer" . ("maxima.info-1" 176445 347 "Definições para Expressões"))
("%gamma" . ("maxima.info-3" 255528 84 "Definições para Teoria dos Números"))
("%i" . ("maxima.info-2" 75030 72 "Definições para Constantes"))
("%phi" . ("maxima.info-2" 75466 2415 "Definições para Constantes"))
("%pi" . ("maxima.info-2" 77882 202 "Definições para Constantes"))
("%rnum_list" . ("maxima.info-2" 195803 376 "Definições para Equações"))
("%th" . ("maxima.info-1" 273126 895 "Definições para Entrada e Saída"))
("%unitexpand" . ("maxima.info-6" 102298 146 "Definições para Units"))
("'" . ("maxima.info-1" 33930 3115 "Introdução a Linha de Comandos"))
("''" . ("maxima.info-1" 37046 5983 "Introdução a Linha de Comandos"))
("*" . ("maxima.info-1" 72652 7440 "Operadores Aritméticos"))
("**" . ("maxima.info-1" 80093 808 "Operadores Aritméticos"))
("+" . ("maxima.info-1" 72635 7457 "Operadores Aritméticos"))
("-" . ("maxima.info-1" 72636 7456 "Operadores Aritméticos"))
("." . ("maxima.info-1" 85591 481 "Operadores Geral"))
("/" . ("maxima.info-1" 72668 7424 "Operadores Aritméticos"))
(":" . ("maxima.info-1" 86073 87 "Operadores Geral"))
("::" . ("maxima.info-1" 86161 219 "Operadores Geral"))
("::=" . ("maxima.info-1" 86381 3763 "Operadores Geral"))
(":=" . ("maxima.info-1" 90145 107 "Operadores Geral"))
("<" . ("maxima.info-1" 81080 68 "Operadores Relacionais"))
("<=" . ("maxima.info-1" 81081 67 "Operadores Relacionais"))
("=" . ("maxima.info-1" 90253 4211 "Operadores Geral"))
(">" . ("maxima.info-1" 81114 34 "Operadores Relacionais"))
(">=" . ("maxima.info-1" 81097 51 "Operadores Relacionais"))
("?" . ("maxima.info-1" 274022 601 "Definições para Entrada e Saída"))
("??" . ("maxima.info-1" 274624 306 "Definições para Entrada e Saída"))
("Adição" . ("maxima.info-1" 72636 7456 "Operadores Aritméticos"))
("Ajuda" . ("maxima.info-1" 30108 2245 "Definições para Ajuda"))
("AntiDifference" . ("maxima.info-6" 104941 197 "Definições para zeilberger"))
("Base do logaritmo natural" . ("maxima.info-2" 74814 215 "Definições para Constantes"))
("Conjunção lógica" . ("maxima.info-1" 94466 991 "Operadores Geral"))
("Constante de Euler" . ("maxima.info-2" 74814 215 "Definições para Constantes"))
("Constante de Euler-Mascheroni" . ("maxima.info-3" 255529 83 "Definições para Teoria dos Números"))
("Consulta documentação" . ("maxima.info-1" 274023 600 "Definições para Entrada e Saída"))
("Consulta documentação (busca inexacta)" . ("maxima.info-1" 274625 305 "Definições para Entrada e Saída"))
("Contração com um vector" . ("maxima.info-3" 132820 1392 "Definições para itensor"))
("DETCOEF" . ("maxima.info-5" 200956 474 "Definições para lsquares"))
("Delimitador de Lista" . ("maxima.info-3" 51927 1112 "Definições para Matrizes e Álgebra Linear"))
("Disjunção lógica" . ("maxima.info-1" 95459 957 "Operadores Geral"))
("Divisão" . ("maxima.info-1" 72684 7408 "Operadores Aritméticos"))
("Duplo factorial" . ("maxima.info-1" 83789 764 "Operadores Geral"))
("Entrada anterior" . ("maxima.info-1" 269567 1524 "Definições para Entrada e Saída"))
("Exponenciação" . ("maxima.info-1" 72700 7392 "Operadores Aritméticos"))
("Expressão de entrada actual" . ("maxima.info-1" 267689 1876 "Definições para Entrada e Saída"))
("Factorial" . ("maxima.info-1" 81303 2484 "Operadores Geral"))
("GGFCFMAX" . ("maxima.info-5" 147578 564 "Definições para ggf"))
("GGFINFINITY" . ("maxima.info-5" 146965 612 "Definições para ggf"))
("Gosper" . ("maxima.info-6" 105139 257 "Definições para zeilberger"))
("GosperSum" . ("maxima.info-6" 105397 2106 "Definições para zeilberger"))
("Igual (igualdade sintática)" . ("maxima.info-1" 90254 4210 "Operadores Geral"))
("Infinito Complexo" . ("maxima.info-2" 75310 71 "Definições para Constantes"))
("Infinito negativo" . ("maxima.info-2" 75383 82 "Definições para Constantes"))
("Infinito positivo real" . ("maxima.info-2" 75242 66 "Definições para Constantes"))
("JF" . ("maxima.info-5" 23678 825 "Definições para diag"))
("Lindstedt" . ("maxima.info-5" 166569 1393 "Definições para lindstedt"))
("MAX_ORD" . ("maxima.info-6" 108626 129 "Definições para zeilberger"))
("Maior que" . ("maxima.info-1" 81131 17 "Operadores Relacionais"))
("Maior que ou igual a" . ("maxima.info-1" 81114 34 "Operadores Relacionais"))
("Menor que" . ("maxima.info-1" 81081 67 "Operadores Relacionais"))
("Menor que ou igual a" . ("maxima.info-1" 81097 51 "Operadores Relacionais"))
("Menos infinito" . ("maxima.info-2" 75383 82 "Definições para Constantes"))
("ModeMatrix" . ("maxima.info-5" 27915 1440 "Definições para diag"))
("Multiplicação" . ("maxima.info-1" 72668 7424 "Operadores Aritméticos"))
("Multiplicação não comutativa matricial" . ("maxima.info-1" 85592 480 "Operadores Geral"))
("N'ésima saída anterior" . ("maxima.info-1" 273127 894 "Definições para Entrada e Saída"))
("Negação lógica" . ("maxima.info-1" 96418 499 "Operadores Geral"))
("Não igual (desigualdade sintática)" . ("maxima.info-1" 84555 1035 "Operadores Geral"))
("Número áureo" . ("maxima.info-2" 75467 2414 "Definições para Constantes"))
("Operador Apóstrofo" . ("maxima.info-1" 33931 3114 "Introdução a Linha de Comandos"))
("Operador apóstrofo-apóstrofo" . ("maxima.info-1" 37047 5982 "Introdução a Linha de Comandos"))
("Operador de Subscrito" . ("maxima.info-3" 51927 1112 "Definições para Matrizes e Álgebra Linear"))
("Operador de atribuição" . ("maxima.info-1" 86074 86 "Operadores Geral"))
("Operador de atribuição (avalia o lado esquerdo da igualdade)" . ("maxima.info-1" 86162 218 "Operadores Geral"))
("Operador de definição de função" . ("maxima.info-1" 90146 106 "Operadores Geral"))
("Operador de definição de função de macro" . ("maxima.info-1" 86382 3762 "Operadores Geral"))
("Operador de equação" . ("maxima.info-1" 90254 4210 "Operadores Geral"))
("Produto Externo" . ("maxima.info-3" 131205 1613 "Definições para itensor"))
("Resultado anterior em expressão composta" . ("maxima.info-1" 271724 1176 "Definições para Entrada e Saída"))
("Saída anterior" . ("maxima.info-1" 271093 629 "Definições para Entrada e Saída"))
("Subtração" . ("maxima.info-1" 72652 7440 "Operadores Aritméticos"))
("Unidade imaginária" . ("maxima.info-2" 75031 71 "Definições para Constantes"))
("Zeilberger" . ("maxima.info-6" 107848 717 "Definições para zeilberger"))
("[" . ("maxima.info-3" 51902 1137 "Definições para Matrizes e Álgebra Linear"))
("]" . ("maxima.info-3" 51903 1136 "Definições para Matrizes e Álgebra Linear"))
("^" . ("maxima.info-1" 72684 7408 "Operadores Aritméticos"))
("^^" . ("maxima.info-1" 81284 17 "Operadores Geral"))
("_" . ("maxima.info-1" 269566 1525 "Definições para Entrada e Saída"))
("__" . ("maxima.info-1" 267688 1877 "Definições para Entrada e Saída"))
("abasep" . ("maxima.info-3" 217409 261 "Definições para o Pacote atensor"))
("abs" . ("maxima.info-1" 96918 143 "Operadores Geral"))
("absboxchar" . ("maxima.info-1" 274931 219 "Definições para Entrada e Saída"))
("absint" . ("maxima.info-2" 261181 589 "Definições para Séries de Fourier"))
("absint <1>" . ("maxima.info-2" 261182 588 "Definições para Séries de Fourier"))
("absint <2>" . ("maxima.info-2" 261225 545 "Definições para Séries de Fourier"))
("acos" . ("maxima.info-2" 88374 44 "Definições para Trigonometria"))
("acosh" . ("maxima.info-2" 88419 57 "Definições para Trigonometria"))
("acot" . ("maxima.info-2" 88477 47 "Definições para Trigonometria"))
("acoth" . ("maxima.info-2" 88525 60 "Definições para Trigonometria"))
("acsc" . ("maxima.info-2" 88586 47 "Definições para Trigonometria"))
("acsch" . ("maxima.info-2" 88634 60 "Definições para Trigonometria"))
("activate" . ("maxima.info-2" 5127 402 "Definições para Contextos"))
("activecontexts" . ("maxima.info-2" 5530 256 "Definições para Contextos"))
("addcol" . ("maxima.info-3" 4066 144 "Definições para Matrizes e Álgebra Linear"))
("additive" . ("maxima.info-1" 97062 681 "Operadores Geral"))
("addmatrices" . ("maxima.info-5" 173124 512 "Definições para linearalgebra"))
("addrow" . ("maxima.info-3" 4211 143 "Definições para Matrizes e Álgebra Linear"))
("adim" . ("maxima.info-3" 215439 182 "Definições para o Pacote atensor"))
("adjoin" . ("maxima.info-4" 97686 484 "Definições para Conjuntos"))
("adjoint" . ("maxima.info-3" 4355 142 "Definições para Matrizes e Álgebra Linear"))
("af" . ("maxima.info-3" 216106 286 "Definições para o Pacote atensor"))
("aform" . ("maxima.info-3" 215622 139 "Definições para o Pacote atensor"))
("agd" . ("maxima.info-5" 283377 167 "Definições para simplification"))
("airy_ai" . ("maxima.info-2" 99493 562 "Definições para Funções Especiais"))
("airy_bi" . ("maxima.info-2" 100157 546 "Definições para Funções Especiais"))
("airy_dai" . ("maxima.info-2" 100056 100 "Definições para Funções Especiais"))
("airy_dbi" . ("maxima.info-2" 100704 112 "Definições para Funções Especiais"))
("alg_type" . ("maxima.info-3" 215285 153 "Definições para o Pacote atensor"))
("algebraic" . ("maxima.info-2" 21600 190 "Definições para Polinómios"))
("algepsilon" . ("maxima.info-2" 747 104 "Definições para ponto Flutuante"))
("algexact" . ("maxima.info-2" 196180 576 "Definições para Equações"))
("algsys" . ("maxima.info-2" 196757 4826 "Definições para Equações"))
("algsys <1>" . ("maxima.info-2" 196758 4825 "Definições para Equações"))
("alias" . ("maxima.info-1" 43231 247 "Definições para Linha de Comandos"))
("aliases" . ("maxima.info-4" 11940 310 "Definições para Opções Diversas"))
("all_dotsimp_denoms" . ("maxima.info-3" 58490 373 "Definições para Funções Afins"))
("allbut" . ("maxima.info-1" 97744 1012 "Operadores Geral"))
("allroots" . ("maxima.info-2" 201584 2408 "Definições para Equações"))
("allroots <1>" . ("maxima.info-2" 201585 2407 "Definições para Equações"))
("allsym" . ("maxima.info-3" 95177 411 "Definições para itensor"))
("alphabetic" . ("maxima.info-4" 12251 667 "Definições para Opções Diversas"))
("alphacharp" . ("maxima.info-6" 60414 101 "Definições para caracteres"))
("alphanumericp" . ("maxima.info-6" 60516 122 "Definições para caracteres"))
("and" . ("maxima.info-1" 94465 992 "Operadores Geral"))
("antid" . ("maxima.info-2" 124881 2445 "Definições para Diferenciação"))
("antidiff" . ("maxima.info-2" 127327 2305 "Definições para Diferenciação"))
("antisymmetric" . ("maxima.info-1" 98757 393 "Operadores Geral"))
("append" . ("maxima.info-4" 74791 317 "Definições para Listas"))
("appendfile" . ("maxima.info-1" 275832 372 "Definições para Entrada e Saída"))
("apply" . ("maxima.info-4" 164812 2297 "Definições para Definição de Função"))
("apply1" . ("maxima.info-4" 27945 700 "Definições para Regras e Modelos"))
("apply2" . ("maxima.info-4" 28646 599 "Definições para Regras e Modelos"))
("applyb1" . ("maxima.info-4" 29246 743 "Definições para Regras e Modelos"))
("apropos" . ("maxima.info-4" 12919 619 "Definições para Opções Diversas"))
("args" . ("maxima.info-4" 13539 534 "Definições para Opções Diversas"))
("arithmetic" . ("maxima.info-5" 281913 219 "Definições para simplification"))
("arithsum" . ("maxima.info-5" 282588 169 "Definições para simplification"))
("array" . ("maxima.info-2" 263629 1546 "Definições para Arrays"))
("array <1>" . ("maxima.info-2" 263630 1545 "Definições para Arrays"))
("array <2>" . ("maxima.info-2" 263680 1495 "Definições para Arrays"))
("arrayapply" . ("maxima.info-2" 265176 262 "Definições para Arrays"))
("arrayinfo" . ("maxima.info-2" 265439 4077 "Definições para Arrays"))
("arraymake" . ("maxima.info-2" 269517 1804 "Definições para Arrays"))
("arrays" . ("maxima.info-2" 271322 1148 "Definições para Arrays"))
("ascii" . ("maxima.info-6" 60639 414 "Definições para caracteres"))
("asec" . ("maxima.info-2" 88695 44 "Definições para Trigonometria"))
("asech" . ("maxima.info-2" 88740 57 "Definições para Trigonometria"))
("asin" . ("maxima.info-2" 88798 41 "Definições para Trigonometria"))
("asinh" . ("maxima.info-2" 88840 54 "Definições para Trigonometria"))
("askexp" . ("maxima.info-1" 216457 231 "Definições para Simplificação"))
("askinteger" . ("maxima.info-1" 216689 683 "Definições para Simplificação"))
("askinteger <1>" . ("maxima.info-1" 216690 682 "Definições para Simplificação"))
("askinteger <2>" . ("maxima.info-1" 216731 641 "Definições para Simplificação"))
("askinteger <3>" . ("maxima.info-1" 216763 609 "Definições para Simplificação"))
("asksign" . ("maxima.info-1" 217373 422 "Definições para Simplificação"))
("assoc" . ("maxima.info-4" 75109 567 "Definições para Listas"))
("assoc <1>" . ("maxima.info-4" 75110 566 "Definições para Listas"))
("assoc_legendre_p" . ("maxima.info-5" 241299 234 "Definições para polinómios ortogonais"))
("assoc_legendre_q" . ("maxima.info-5" 241534 160 "Definições para polinómios ortogonais"))
("assume" . ("maxima.info-2" 5787 2324 "Definições para Contextos"))
("assume_pos" . ("maxima.info-2" 9108 1234 "Definições para Contextos"))
("assume_pos_pred" . ("maxima.info-2" 10343 2243 "Definições para Contextos"))
("assumescalar" . ("maxima.info-2" 8112 995 "Definições para Contextos"))
("asymbol" . ("maxima.info-3" 215762 61 "Definições para o Pacote atensor"))
("asympa" . ("maxima.info-2" 100817 317 "Definições para Funções Especiais"))
("at" . ("maxima.info-1" 154131 2002 "Definições para Expressões"))
("at <1>" . ("maxima.info-1" 154132 2001 "Definições para Expressões"))
("atan" . ("maxima.info-2" 88895 45 "Definições para Trigonometria"))
("atan2" . ("maxima.info-2" 88941 108 "Definições para Trigonometria"))
("atanh" . ("maxima.info-2" 89050 58 "Definições para Trigonometria"))
("atensimp" . ("maxima.info-3" 214872 412 "Definições para o Pacote atensor"))
("atom" . ("maxima.info-4" 75677 295 "Definições para Listas"))
("atomgrad" . ("maxima.info-2" 129633 146 "Definições para Diferenciação"))
("atrig1" . ("maxima.info-2" 89109 415 "Definições para Trigonometria"))
("atvalue" . ("maxima.info-2" 129780 2561 "Definições para Diferenciação"))
("atvalue <1>" . ("maxima.info-2" 129781 2560 "Definições para Diferenciação"))
("augcoefmatrix" . ("maxima.info-3" 4498 657 "Definições para Matrizes e Álgebra Linear"))
("augmented_lagrangian_method" . ("maxima.info-4" 259723 2361 "Definições para augmented_lagrangian"))
("augmented_lagrangian_method <1>" . ("maxima.info-4" 259724 2360 "Definições para augmented_lagrangian"))
("av" . ("maxima.info-3" 216393 1015 "Definições para o Pacote atensor"))
("backsubst" . ("maxima.info-2" 203993 366 "Definições para Equações"))
("backtrace" . ("maxima.info-4" 215605 1679 "Definições para Fluxo de Programa"))
("backtrace <1>" . ("maxima.info-4" 215606 1678 "Definições para Fluxo de Programa"))
("barsplot" . ("maxima.info-5" 18338 2391 "Definições para gráficos estatísticos"))
("barsplot <1>" . ("maxima.info-5" 18339 2390 "Definições para gráficos estatísticos"))
("barsplot <2>" . ("maxima.info-5" 18370 2359 "Definições para gráficos estatísticos"))
("barsplot <3>" . ("maxima.info-5" 18428 2301 "Definições para gráficos estatísticos"))
("bashindices" . ("maxima.info-2" 272471 431 "Definições para Arrays"))
("batch" . ("maxima.info-1" 276205 1742 "Definições para Entrada e Saída"))
("batchload" . ("maxima.info-1" 277948 657 "Definições para Entrada e Saída"))
("bc2" . ("maxima.info-2" 236921 629 "Definições para Equações Diferenciais"))
("bdvac" . ("maxima.info-3" 181250 442 "Definições para ctensor"))
("belln" . ("maxima.info-4" 98171 1018 "Definições para Conjuntos"))
("berlefact" . ("maxima.info-2" 21791 235 "Definições para Polinómios"))
("bern" . ("maxima.info-3" 247012 744 "Definições para Teoria dos Números"))
("bernpoly" . ("maxima.info-3" 247757 97 "Definições para Teoria dos Números"))
("bessel" . ("maxima.info-2" 101135 163 "Definições para Funções Especiais"))
("bessel_i" . ("maxima.info-2" 102519 669 "Definições para Funções Especiais"))
("bessel_j" . ("maxima.info-2" 101299 649 "Definições para Funções Especiais"))
("bessel_k" . ("maxima.info-2" 103189 586 "Definições para Funções Especiais"))
("bessel_y" . ("maxima.info-2" 101949 569 "Definições para Funções Especiais"))
("besselexpand" . ("maxima.info-2" 103776 854 "Definições para Funções Especiais"))
("beta" . ("maxima.info-2" 105274 96 "Definições para Funções Especiais"))
("bezout" . ("maxima.info-2" 22027 170 "Definições para Polinómios"))
("bffac" . ("maxima.info-2" 438 308 "Definições para ponto Flutuante"))
("bfhzeta" . ("maxima.info-3" 248114 357 "Definições para Teoria dos Números"))
("bfloat" . ("maxima.info-2" 852 543 "Definições para ponto Flutuante"))
("bfloatp" . ("maxima.info-2" 1396 160 "Definições para ponto Flutuante"))
("bfpsi" . ("maxima.info-2" 1557 483 "Definições para ponto Flutuante"))
("bfpsi0" . ("maxima.info-2" 1558 482 "Definições para ponto Flutuante"))
("bftorat" . ("maxima.info-2" 2041 394 "Definições para ponto Flutuante"))
("bftrunc" . ("maxima.info-2" 2436 334 "Definições para ponto Flutuante"))
("bfzeta" . ("maxima.info-3" 247855 258 "Definições para Teoria dos Números"))
("bimetric" . ("maxima.info-3" 182154 197 "Definições para ctensor"))
("binomial" . ("maxima.info-3" 248472 992 "Definições para Teoria dos Números"))
("block" . ("maxima.info-4" 167110 2866 "Definições para Definição de Função"))
("block <1>" . ("maxima.info-4" 167111 2865 "Definições para Definição de Função"))
("blockmatrixp" . ("maxima.info-5" 173637 137 "Definições para linearalgebra"))
("bode_gain" . ("maxima.info-4" 262355 1443 "Definições para bode"))
("bode_phase" . ("maxima.info-4" 263799 1690 "Definições para bode"))
("bothcoef" . ("maxima.info-2" 22198 574 "Definições para Polinómios"))
("box" . ("maxima.info-1" 156134 2048 "Definições para Expressões"))
("box <1>" . ("maxima.info-1" 156135 2047 "Definições para Expressões"))
("boxchar" . ("maxima.info-1" 158183 520 "Definições para Expressões"))
("boxplot" . ("maxima.info-5" 20730 1759 "Definições para gráficos estatísticos"))
("boxplot <1>" . ("maxima.info-5" 20731 1758 "Definições para gráficos estatísticos"))
("break" . ("maxima.info-4" 169977 270 "Definições para Definição de Função"))
("breakup" . ("maxima.info-2" 204360 3283 "Definições para Equações"))
("bug_report" . ("maxima.info-1" 20235 470 "Definições para Detecção e Relato de Erros"))
("build_info" . ("maxima.info-1" 20706 169 "Definições para Detecção e Relato de Erros"))
("buildq" . ("maxima.info-4" 156187 3908 "Macros"))
("burn" . ("maxima.info-3" 249465 527 "Definições para Teoria dos Números"))
("cabs" . ("maxima.info-1" 99151 96 "Operadores Geral"))
("canform" . ("maxima.info-3" 98277 959 "Definições para itensor"))
("canten" . ("maxima.info-3" 94375 648 "Definições para itensor"))
("cardinality" . ("maxima.info-4" 99190 547 "Definições para Conjuntos"))
("carg" . ("maxima.info-1" 158704 1189 "Definições para Expressões"))
("cartan" . ("maxima.info-2" 132342 583 "Definições para Diferenciação"))
("cartesian_product" . ("maxima.info-4" 99738 734 "Definições para Conjuntos"))
("catch" . ("maxima.info-4" 170248 1126 "Definições para Definição de Função"))
("cauchysum" . ("maxima.info-3" 218547 1272 "Definições para Séries"))
("cbffac" . ("maxima.info-2" 2771 140 "Definições para ponto Flutuante"))
("cdf_bernoulli" . ("maxima.info-5" 113429 234 "Definições para distribuições discretas"))
("cdf_beta" . ("maxima.info-5" 79941 638 "Definições para distribuições contínuas"))
("cdf_binomial" . ("maxima.info-5" 106146 690 "Definições para distribuições discretas"))
("cdf_cauchy" . ("maxima.info-5" 102049 232 "Definições para distribuições contínuas"))
("cdf_chi2" . ("maxima.info-5" 56154 686 "Definições para distribuições contínuas"))
("cdf_continuous_uniform" . ("maxima.info-5" 83417 256 "Definições para distribuições contínuas"))
("cdf_discrete_uniform" . ("maxima.info-5" 120760 279 "Definições para distribuições discretas"))
("cdf_exp" . ("maxima.info-5" 66848 740 "Definições para distribuições contínuas"))
("cdf_f" . ("maxima.info-5" 62510 625 "Definições para distribuições contínuas"))
("cdf_gamma" . ("maxima.info-5" 76477 549 "Definições para distribuições contínuas"))
("cdf_geometric" . ("maxima.info-5" 117748 234 "Definições para distribuições discretas"))
("cdf_gumbel" . ("maxima.info-5" 103236 232 "Definições para distribuições contínuas"))
("cdf_hypergeometric" . ("maxima.info-5" 123436 310 "Definições para distribuições discretas"))
("cdf_laplace" . ("maxima.info-5" 99880 234 "Definições para distribuições contínuas"))
("cdf_logistic" . ("maxima.info-5" 85859 236 "Definições para distribuições contínuas"))
("cdf_lognormal" . ("maxima.info-5" 73574 618 "Definições para distribuições contínuas"))
("cdf_negative_binomial" . ("maxima.info-5" 127171 733 "Definições para distribuições discretas"))
("cdf_normal" . ("maxima.info-5" 48166 598 "Definições para distribuições contínuas"))
("cdf_pareto" . ("maxima.info-5" 88049 234 "Definições para distribuições contínuas"))
("cdf_poisson" . ("maxima.info-5" 109814 527 "Definições para distribuições discretas"))
("cdf_rank_sum" . ("maxima.info-6" 45927 259 "Definições para distribuições especiais"))
("cdf_rayleigh" . ("maxima.info-5" 93014 804 "Definições para distribuições contínuas"))
("cdf_signed_rank" . ("maxima.info-6" 45422 242 "Definições para distribuições especiais"))
("cdf_student_t" . ("maxima.info-5" 51487 665 "Definições para distribuições contínuas"))
("cdf_weibull" . ("maxima.info-5" 90233 236 "Definições para distribuições contínuas"))
("cdisplay" . ("maxima.info-3" 183004 13894 "Definições para ctensor"))
("ceiling" . ("maxima.info-1" 99248 1950 "Operadores Geral"))
("central_moment" . ("maxima.info-4" 285139 966 "Definições para estatística descritiva"))
("central_moment <1>" . ("maxima.info-4" 285140 965 "Definições para estatística descritiva"))
("cequal" . ("maxima.info-6" 61054 120 "Definições para caracteres"))
("cequalignore" . ("maxima.info-6" 61175 106 "Definições para caracteres"))
("cf" . ("maxima.info-3" 249993 2773 "Definições para Teoria dos Números"))
("cfdisrep" . ("maxima.info-3" 252767 673 "Definições para Teoria dos Números"))
("cfexpand" . ("maxima.info-3" 253441 624 "Definições para Teoria dos Números"))
("cflength" . ("maxima.info-3" 254066 617 "Definições para Teoria dos Números"))
("cframe_flag" . ("maxima.info-3" 198032 479 "Definições para ctensor"))
("cgeodesic" . ("maxima.info-3" 180976 273 "Definições para ctensor"))
("cgreaterp" . ("maxima.info-6" 61282 178 "Definições para caracteres"))
("cgreaterpignore" . ("maxima.info-6" 61461 112 "Definições para caracteres"))
("changename" . ("maxima.info-3" 71860 385 "Definições para itensor"))
("changevar" . ("maxima.info-2" 150533 2323 "Definições para Integração"))
("chaosgame" . ("maxima.info-5" 131931 613 "Análise gráfica de sistemas dinâmicos discretos"))
("charat" . ("maxima.info-6" 64296 277 "Definições para sequências de caracteres"))
("charfun" . ("maxima.info-1" 101199 622 "Operadores Geral"))
("charfun2" . ("maxima.info-5" 152688 171 "Definições para interpol"))
("charlist" . ("maxima.info-6" 64574 285 "Definições para sequências de caracteres"))
("charp" . ("maxima.info-6" 61574 184 "Definições para caracteres"))
("charpoly" . ("maxima.info-3" 5156 1618 "Definições para Matrizes e Álgebra Linear"))
("chebyshev_t" . ("maxima.info-5" 241695 147 "Definições para polinómios ortogonais"))
("chebyshev_u" . ("maxima.info-5" 241843 146 "Definições para polinómios ortogonais"))
("check_overlaps" . ("maxima.info-3" 56699 661 "Definições para Funções Afins"))
("checkdiv" . ("maxima.info-3" 180527 448 "Definições para ctensor"))
("cholesky" . ("maxima.info-5" 175443 292 "Definições para linearalgebra"))
("cholesky <1>" . ("maxima.info-5" 175444 291 "Definições para linearalgebra"))
("christof" . ("maxima.info-3" 155020 931 "Definições para ctensor"))
("cint" . ("maxima.info-6" 61759 83 "Definições para caracteres"))
("clear_rules" . ("maxima.info-4" 73409 171 "Definições para Regras e Modelos"))
("clessp" . ("maxima.info-6" 61843 175 "Definições para caracteres"))
("clesspignore" . ("maxima.info-6" 62019 105 "Definições para caracteres"))
("close" . ("maxima.info-6" 54558 113 "Definições para entrada e saída"))
("closefile" . ("maxima.info-1" 278606 98 "Definições para Entrada e Saída"))
("cmetric" . ("maxima.info-3" 147390 969 "Definições para ctensor"))
("cmetric <1>" . ("maxima.info-3" 147391 968 "Definições para ctensor"))
("cnonmet_flag" . ("maxima.info-3" 198783 315 "Definições para ctensor"))
("coeff" . ("maxima.info-2" 22773 699 "Definições para Polinómios"))
("coefmatrix" . ("maxima.info-3" 6775 445 "Definições para Matrizes e Álgebra Linear"))
("cograd" . ("maxima.info-3" 178286 1339 "Definições para ctensor"))
("col" . ("maxima.info-3" 7221 112 "Definições para Matrizes e Álgebra Linear"))
("collapse" . ("maxima.info-1" 278705 551 "Definições para Entrada e Saída"))
("collectterms" . ("maxima.info-5" 278794 902 "Definições para simplification"))
("columnop" . ("maxima.info-5" 173775 242 "Definições para linearalgebra"))
("columnspace" . ("maxima.info-5" 174189 347 "Definições para linearalgebra"))
("columnswap" . ("maxima.info-5" 174018 170 "Definições para linearalgebra"))
("columnvector" . ("maxima.info-3" 7334 921 "Definições para Matrizes e Álgebra Linear"))
("combination" . ("maxima.info-5" 284118 195 "Definições para simplification"))
("combine" . ("maxima.info-2" 23473 140 "Definições para Polinómios"))
("commutative" . ("maxima.info-1" 101822 222 "Operadores Geral"))
("comp2pui" . ("maxima.info-3" 265065 633 "Definições para Simetrias"))
("compare" . ("maxima.info-1" 102045 1131 "Operadores Geral"))
("compfile" . ("maxima.info-4" 171375 773 "Definições para Definição de Função"))
("compfile <1>" . ("maxima.info-4" 171376 772 "Definições para Definição de Função"))
("compfile <2>" . ("maxima.info-4" 171433 715 "Definições para Definição de Função"))
("compile" . ("maxima.info-4" 172149 562 "Definições para Definição de Função"))
("compile <1>" . ("maxima.info-4" 172150 561 "Definições para Definição de Função"))
("compile <2>" . ("maxima.info-4" 172190 521 "Definições para Definição de Função"))
("compile_file" . ("maxima.info-4" 212815 1382 "Definições para Definição de Função"))
("compile_file <1>" . ("maxima.info-4" 212883 1314 "Definições para Definição de Função"))
("compile_file <2>" . ("maxima.info-4" 212951 1246 "Definições para Definição de Função"))
("components" . ("maxima.info-3" 80219 3965 "Definições para itensor"))
("concan" . ("maxima.info-3" 95024 94 "Definições para itensor"))
("concat" . ("maxima.info-1" 279257 1410 "Definições para Entrada e Saída"))
("conjugate" . ("maxima.info-3" 8256 533 "Definições para Matrizes e Álgebra Linear"))
("conmetderiv" . ("maxima.info-3" 106774 850 "Definições para itensor"))
("cons" . ("maxima.info-4" 75973 261 "Definições para Listas"))
("constant" . ("maxima.info-1" 159894 122 "Definições para Expressões"))
("constantp" . ("maxima.info-1" 160017 1206 "Definições para Expressões"))
("constituent" . ("maxima.info-6" 62125 697 "Definições para caracteres"))
("cont2part" . ("maxima.info-3" 274238 433 "Definições para Simetrias"))
("content" . ("maxima.info-2" 23614 450 "Definições para Polinómios"))
("context" . ("maxima.info-2" 12587 605 "Definições para Contextos"))
("contexts" . ("maxima.info-2" 13193 1511 "Definições para Contextos"))
("continuous_freq" . ("maxima.info-4" 271679 909 "Definições para manipulação da dados"))
("continuous_freq <1>" . ("maxima.info-4" 271680 908 "Definições para manipulação da dados"))
("contortion" . ("maxima.info-3" 175340 132 "Definições para ctensor"))
("contract" . ("maxima.info-3" 79455 528 "Definições para itensor"))
("contract <1>" . ("maxima.info-3" 274672 774 "Definições para Simetrias"))
("contragrad" . ("maxima.info-3" 178453 1172 "Definições para ctensor"))
("convert" . ("maxima.info-6" 88794 3589 "Definições para Units"))
("coord" . ("maxima.info-3" 105799 428 "Definições para itensor"))
("copy" . ("maxima.info-5" 174537 905 "Definições para linearalgebra"))
("copylist" . ("maxima.info-4" 76235 70 "Definições para Listas"))
("copymatrix" . ("maxima.info-3" 8790 440 "Definições para Matrizes e Álgebra Linear"))
("cor" . ("maxima.info-5" 4926 2166 "Definições específicas para estatística descritiva de várias variáveis"))
("cor <1>" . ("maxima.info-5" 4927 2165 "Definições específicas para estatística descritiva de várias variáveis"))
("cos" . ("maxima.info-2" 89525 38 "Definições para Trigonometria"))
("cosh" . ("maxima.info-2" 89564 51 "Definições para Trigonometria"))
("cosnpiflag" . ("maxima.info-2" 262160 88 "Definições para Séries de Fourier"))
("cot" . ("maxima.info-2" 89616 41 "Definições para Trigonometria"))
("coth" . ("maxima.info-2" 89658 54 "Definições para Trigonometria"))
("cov" . ("maxima.info-5" 436 1329 "Definições específicas para estatística descritiva de várias variáveis"))
("cov1" . ("maxima.info-5" 1766 1328 "Definições específicas para estatística descritiva de várias variáveis"))
("covdiff" . ("maxima.info-3" 112784 1733 "Definições para itensor"))
("covect" . ("maxima.info-3" 7335 920 "Definições para Matrizes e Álgebra Linear"))
("covers" . ("maxima.info-5" 283678 151 "Definições para simplification"))
("create_list" . ("maxima.info-4" 76306 1168 "Definições para Listas"))
("csc" . ("maxima.info-2" 89713 41 "Definições para Trigonometria"))
("csch" . ("maxima.info-2" 89755 54 "Definições para Trigonometria"))
("csetup" . ("maxima.info-3" 147179 210 "Definições para ctensor"))
("cspline" . ("maxima.info-5" 155251 4319 "Definições para interpol"))
("cspline <1>" . ("maxima.info-5" 155252 4318 "Definições para interpol"))
("ct_coords" . ("maxima.info-3" 203922 386 "Definições para ctensor"))
("ct_coordsys" . ("maxima.info-3" 148360 5189 "Definições para ctensor"))
("ct_coordsys <1>" . ("maxima.info-3" 148361 5188 "Definições para ctensor"))
("ctaylor" . ("maxima.info-3" 161285 5426 "Definições para ctensor"))
("ctaypov" . ("maxima.info-3" 199505 144 "Definições para ctensor"))
("ctaypt" . ("maxima.info-3" 199650 156 "Definições para ctensor"))
("ctayswitch" . ("maxima.info-3" 199099 272 "Definições para ctensor"))
("ctayvar" . ("maxima.info-3" 199372 132 "Definições para ctensor"))
("ctorsion_flag" . ("maxima.info-3" 198512 270 "Definições para ctensor"))
("ctransform" . ("maxima.info-3" 175672 285 "Definições para ctensor"))
("ctranspose" . ("maxima.info-5" 175736 200 "Definições para linearalgebra"))
("ctrgsimp" . ("maxima.info-3" 197811 220 "Definições para ctensor"))
("cunlisp" . ("maxima.info-6" 62823 155 "Definições para caracteres"))
("current_let_rule_package" . ("maxima.info-4" 29990 630 "Definições para Regras e Modelos"))
("cv" . ("maxima.info-4" 286106 663 "Definições para estatística descritiva"))
("cv <1>" . ("maxima.info-4" 286107 662 "Definições para estatística descritiva"))
("dataplot" . ("maxima.info-5" 10655 5398 "Definições para gráficos estatísticos"))
("dataplot <1>" . ("maxima.info-5" 10656 5397 "Definições para gráficos estatísticos"))
("dataplot <2>" . ("maxima.info-5" 10687 5366 "Definições para gráficos estatísticos"))
("dataplot <3>" . ("maxima.info-5" 10745 5308 "Definições para gráficos estatísticos"))
("dblint" . ("maxima.info-2" 152857 2640 "Definições para Integração"))
("deactivate" . ("maxima.info-2" 14705 127 "Definições para Contextos"))
("debugmode" . ("maxima.info-1" 43479 523 "Definições para Linha de Comandos"))
("declare" . ("maxima.info-1" 161224 11285 "Definições para Expressões"))
("declare_translated" . ("maxima.info-4" 214250 595 "Definições para Definição de Função"))
("declare_weights" . ("maxima.info-3" 55579 258 "Definições para Funções Afins"))
("decsym" . ("maxima.info-3" 95589 2520 "Definições para itensor"))
("default_let_rule_package" . ("maxima.info-4" 30621 315 "Definições para Regras e Modelos"))
("defcon" . ("maxima.info-3" 78178 1022 "Definições para itensor"))
("defcon <1>" . ("maxima.info-3" 78179 1021 "Definições para itensor"))
("define" . ("maxima.info-4" 172712 4083 "Definições para Definição de Função"))
("define <1>" . ("maxima.info-4" 172713 4082 "Definições para Definição de Função"))
("define <2>" . ("maxima.info-4" 172765 4030 "Definições para Definição de Função"))
("define <3>" . ("maxima.info-4" 172817 3978 "Definições para Definição de Função"))
("define <4>" . ("maxima.info-4" 172881 3914 "Definições para Definição de Função"))
("define_variable" . ("maxima.info-4" 176796 3859 "Definições para Definição de Função"))
("defint" . ("maxima.info-2" 155498 590 "Definições para Integração"))
("defmatch" . ("maxima.info-4" 30937 4649 "Definições para Regras e Modelos"))
("defmatch <1>" . ("maxima.info-4" 30938 4648 "Definições para Regras e Modelos"))
("defrule" . ("maxima.info-4" 35587 757 "Definições para Regras e Modelos"))
("deftaylor" . ("maxima.info-3" 219820 1324 "Definições para Séries"))
("del" . ("maxima.info-2" 132926 681 "Definições para Diferenciação"))
("delete" . ("maxima.info-4" 77475 769 "Definições para Listas"))
("delete <1>" . ("maxima.info-4" 77476 768 "Definições para Listas"))
("deleten" . ("maxima.info-3" 196899 118 "Definições para ctensor"))
("delta" . ("maxima.info-2" 133608 352 "Definições para Diferenciação"))
("demo" . ("maxima.info-1" 27062 2973 "Definições para Ajuda"))
("demoivre" . ("maxima.info-1" 217796 686 "Definições para Simplificação"))
("demoivre <1>" . ("maxima.info-1" 217797 685 "Definições para Simplificação"))
("denom" . ("maxima.info-2" 24065 84 "Definições para Polinómios"))
("dependencies" . ("maxima.info-2" 133961 321 "Definições para Diferenciação"))
("depends" . ("maxima.info-2" 134283 2507 "Definições para Diferenciação"))
("derivabbrev" . ("maxima.info-2" 136791 270 "Definições para Diferenciação"))
("derivdegree" . ("maxima.info-2" 137062 590 "Definições para Diferenciação"))
("derivlist" . ("maxima.info-2" 137653 145 "Definições para Diferenciação"))
("derivsubst" . ("maxima.info-2" 137799 222 "Definições para Diferenciação"))
("describe" . ("maxima.info-1" 30036 2317 "Definições para Ajuda"))
("describe <1>" . ("maxima.info-1" 30037 2316 "Definições para Ajuda"))
("describe <2>" . ("maxima.info-1" 30069 2284 "Definições para Ajuda"))
("desolve" . ("maxima.info-2" 237551 2151 "Definições para Equações Diferenciais"))
("desolve <1>" . ("maxima.info-2" 237552 2150 "Definições para Equações Diferenciais"))
("determinant" . ("maxima.info-3" 9231 336 "Definições para Matrizes e Álgebra Linear"))
("detout" . ("maxima.info-3" 9568 1004 "Definições para Matrizes e Álgebra Linear"))
("diag" . ("maxima.info-5" 22747 930 "Definições para diag"))
("diag_matrix" . ("maxima.info-5" 175937 1023 "Definições para linearalgebra"))
("diagmatrix" . ("maxima.info-3" 10573 526 "Definições para Matrizes e Álgebra Linear"))
("diagmatrixp" . ("maxima.info-3" 182406 100 "Definições para ctensor"))
("diagmetric" . ("maxima.info-3" 197323 487 "Definições para ctensor"))
("diff" . ("maxima.info-2" 141312 165 "Definições para Diferenciação"))
("diff <1>" . ("maxima.info-2" 138022 3289 "Definições para Diferenciação"))
("diff <2>" . ("maxima.info-2" 138023 3288 "Definições para Diferenciação"))
("diff <3>" . ("maxima.info-2" 138082 3229 "Definições para Diferenciação"))
("diff <4>" . ("maxima.info-2" 138118 3193 "Definições para Diferenciação"))
("diff <5>" . ("maxima.info-3" 99311 819 "Definições para itensor"))
("digitcharp" . ("maxima.info-6" 62979 108 "Definições para caracteres"))
("dim" . ("maxima.info-3" 197094 228 "Definições para ctensor"))
("dimension" . ("maxima.info-2" 207644 214 "Definições para Equações"))
("dimension <1>" . ("maxima.info-2" 207645 213 "Definições para Equações"))
("direct" . ("maxima.info-3" 276739 3784 "Definições para Simetrias"))
("discrete_freq" . ("maxima.info-4" 272589 1052 "Definições para manipulação da dados"))
("disjoin" . ("maxima.info-4" 100473 698 "Definições para Conjuntos"))
("disjointp" . ("maxima.info-4" 101172 393 "Definições para Conjuntos"))
("disolate" . ("maxima.info-1" 172510 520 "Definições para Expressões"))
("disp" . ("maxima.info-1" 281053 283 "Definições para Entrada e Saída"))
("dispJordan" . ("maxima.info-5" 26179 1061 "Definições para diag"))
("dispcon" . ("maxima.info-1" 281337 259 "Definições para Entrada e Saída"))
("dispcon <1>" . ("maxima.info-1" 281338 258 "Definições para Entrada e Saída"))
("dispflag" . ("maxima.info-2" 207859 291 "Definições para Equações"))
("dispform" . ("maxima.info-1" 173031 673 "Definições para Expressões"))
("dispfun" . ("maxima.info-4" 180656 3765 "Definições para Definição de Função"))
("dispfun <1>" . ("maxima.info-4" 180657 3764 "Definições para Definição de Função"))
("display" . ("maxima.info-1" 281597 652 "Definições para Entrada e Saída"))
("display2d" . ("maxima.info-1" 282250 172 "Definições para Entrada e Saída"))
("display_format_internal" . ("maxima.info-1" 282423 682 "Definições para Entrada e Saída"))
("disprule" . ("maxima.info-4" 36345 1398 "Definições para Regras e Modelos"))
("disprule <1>" . ("maxima.info-4" 36346 1397 "Definições para Regras e Modelos"))
("dispterms" . ("maxima.info-1" 283106 833 "Definições para Entrada e Saída"))
("distrib" . ("maxima.info-1" 173705 963 "Definições para Expressões"))
("divide" . ("maxima.info-2" 24150 604 "Definições para Polinómios"))
("divisors" . ("maxima.info-4" 101566 1703 "Definições para Conjuntos"))
("divsum" . ("maxima.info-3" 254684 547 "Definições para Teoria dos Números"))
("divsum <1>" . ("maxima.info-3" 254685 546 "Definições para Teoria dos Números"))
("do" . ("maxima.info-4" 217285 8837 "Definições para Fluxo de Programa"))
("doallmxops" . ("maxima.info-3" 11100 279 "Definições para Matrizes e Álgebra Linear"))
("domain" . ("maxima.info-1" 218483 186 "Definições para Simplificação"))
("domxexpt" . ("maxima.info-3" 11380 1290 "Definições para Matrizes e Álgebra Linear"))
("domxmxops" . ("maxima.info-3" 12671 261 "Definições para Matrizes e Álgebra Linear"))
("domxnctimes" . ("maxima.info-3" 12933 162 "Definições para Matrizes e Álgebra Linear"))
("dontfactor" . ("maxima.info-3" 13096 458 "Definições para Matrizes e Álgebra Linear"))
("doscmxops" . ("maxima.info-3" 13555 146 "Definições para Matrizes e Álgebra Linear"))
("doscmxplus" . ("maxima.info-3" 13702 213 "Definições para Matrizes e Álgebra Linear"))
("dot0nscsimp" . ("maxima.info-3" 13916 208 "Definições para Matrizes e Álgebra Linear"))
("dot0simp" . ("maxima.info-3" 14125 202 "Definições para Matrizes e Álgebra Linear"))
("dot1simp" . ("maxima.info-3" 14328 191 "Definições para Matrizes e Álgebra Linear"))
("dotassoc" . ("maxima.info-3" 14520 152 "Definições para Matrizes e Álgebra Linear"))
("dotconstrules" . ("maxima.info-3" 14673 320 "Definições para Matrizes e Álgebra Linear"))
("dotdistrib" . ("maxima.info-3" 14994 161 "Definições para Matrizes e Álgebra Linear"))
("dotexptsimp" . ("maxima.info-3" 15156 151 "Definições para Matrizes e Álgebra Linear"))
("dotident" . ("maxima.info-3" 15308 107 "Definições para Matrizes e Álgebra Linear"))
("dotproduct" . ("maxima.info-5" 176961 228 "Definições para linearalgebra"))
("dotscrules" . ("maxima.info-3" 15416 201 "Definições para Matrizes e Álgebra Linear"))
("dotsimp" . ("maxima.info-3" 56019 257 "Definições para Funções Afins"))
("dpart" . ("maxima.info-1" 174669 617 "Definições para Expressões"))
("dscalar" . ("maxima.info-2" 141478 134 "Definições para Diferenciação"))
("dscalar <1>" . ("maxima.info-3" 179626 900 "Definições para ctensor"))
("e" . ("maxima.info-2" 74814 215 "Definições para Constantes"))
("echelon" . ("maxima.info-3" 15618 1492 "Definições para Matrizes e Álgebra Linear"))
("eigens_by_jacobi" . ("maxima.info-5" 177190 3276 "Definições para linearalgebra"))
("eigens_by_jacobi <1>" . ("maxima.info-5" 177191 3275 "Definições para linearalgebra"))
("eigenvalues" . ("maxima.info-3" 17111 1291 "Definições para Matrizes e Álgebra Linear"))
("eigenvectors" . ("maxima.info-3" 18403 1873 "Definições para Matrizes e Álgebra Linear"))
("eighth" . ("maxima.info-4" 78245 131 "Definições para Listas"))
("einstein" . ("maxima.info-3" 156903 583 "Definições para ctensor"))
("eivals" . ("maxima.info-3" 17112 1290 "Definições para Matrizes e Álgebra Linear"))
("eivects" . ("maxima.info-3" 18404 1872 "Definições para Matrizes e Álgebra Linear"))
("ele2comp" . ("maxima.info-3" 265897 197 "Definições para Simetrias"))
("ele2polynome" . ("maxima.info-3" 286380 810 "Definições para Simetrias"))
("ele2pui" . ("maxima.info-3" 265699 197 "Definições para Simetrias"))
("elem" . ("maxima.info-3" 266095 1435 "Definições para Simetrias"))
("elementp" . ("maxima.info-4" 103270 394 "Definições para Conjuntos"))
("eliminate" . ("maxima.info-2" 24755 1309 "Definições para Polinómios"))
("elliptic_e" . ("maxima.info-2" 120429 218 "Definições para Integrais Elípticas"))
("elliptic_ec" . ("maxima.info-2" 121523 286 "Definições para Integrais Elípticas"))
("elliptic_eu" . ("maxima.info-2" 120648 342 "Definições para Integrais Elípticas"))
("elliptic_f" . ("maxima.info-2" 120225 203 "Definições para Integrais Elípticas"))
("elliptic_kc" . ("maxima.info-2" 121235 287 "Definições para Integrais Elípticas"))
("elliptic_pi" . ("maxima.info-2" 120991 243 "Definições para Integrais Elípticas"))
("ematrix" . ("maxima.info-3" 20277 172 "Definições para Matrizes e Álgebra Linear"))
("emptyp" . ("maxima.info-4" 103665 321 "Definições para Conjuntos"))
("endcons" . ("maxima.info-4" 78377 230 "Definições para Listas"))
("entermatrix" . ("maxima.info-3" 20450 1369 "Definições para Matrizes e Álgebra Linear"))
("entertensor" . ("maxima.info-3" 71517 342 "Definições para itensor"))
("entier" . ("maxima.info-1" 103177 199 "Operadores Geral"))
("epsilon_sx" . ("maxima.info-5" 267977 169 "Definições para simplex"))
("equal" . ("maxima.info-1" 103377 4766 "Operadores Geral"))
("equalp" . ("maxima.info-2" 260364 186 "Definições para Séries de Fourier"))
("equiv_classes" . ("maxima.info-4" 103987 1269 "Definições para Conjuntos"))
("erf" . ("maxima.info-2" 156089 103 "Definições para Integração"))
("erfflag" . ("maxima.info-2" 156193 208 "Definições para Integração"))
("errcatch" . ("maxima.info-4" 226123 506 "Definições para Fluxo de Programa"))
("error" . ("maxima.info-4" 226630 717 "Definições para Fluxo de Programa"))
("error <1>" . ("maxima.info-4" 226631 716 "Definições para Fluxo de Programa"))
("error_size" . ("maxima.info-1" 283940 1529 "Definições para Entrada e Saída"))
("error_syms" . ("maxima.info-1" 285470 662 "Definições para Entrada e Saída"))
("errormsg" . ("maxima.info-4" 227348 162 "Definições para Fluxo de Programa"))
("euler" . ("maxima.info-3" 255232 295 "Definições para Teoria dos Números"))
("ev" . ("maxima.info-1" 44003 8796 "Definições para Linha de Comandos"))
("ev_point" . ("maxima.info-6" 110275 193 "Definições para zeilberger"))
("eval" . ("maxima.info-1" 111635 135 "Operadores Geral"))
("eval_string" . ("maxima.info-5" 143117 801 "Definições para eval_string"))
("evenp" . ("maxima.info-1" 111771 132 "Operadores Geral"))
("every" . ("maxima.info-4" 105257 2877 "Definições para Conjuntos"))
("every <1>" . ("maxima.info-4" 105258 2876 "Definições para Conjuntos"))
("evflag" . ("maxima.info-1" 52800 2439 "Definições para Linha de Comandos"))
("evfun" . ("maxima.info-1" 55240 2918 "Definições para Linha de Comandos"))
("evolution" . ("maxima.info-5" 132545 574 "Análise gráfica de sistemas dinâmicos discretos"))
("evolution2d" . ("maxima.info-5" 133120 443 "Análise gráfica de sistemas dinâmicos discretos"))
("evundiff" . ("maxima.info-3" 102347 2396 "Definições para itensor"))
("example" . ("maxima.info-1" 32354 1136 "Definições para Ajuda"))
("example <1>" . ("maxima.info-1" 32355 1135 "Definições para Ajuda"))
("exp" . ("maxima.info-1" 175287 573 "Definições para Expressões"))
("expand" . ("maxima.info-1" 218670 1995 "Definições para Simplificação"))
("expand <1>" . ("maxima.info-1" 218671 1994 "Definições para Simplificação"))
("expandwrt" . ("maxima.info-1" 220666 606 "Definições para Simplificação"))
("expandwrt_denom" . ("maxima.info-1" 221273 403 "Definições para Simplificação"))
("expandwrt_factored" . ("maxima.info-1" 221677 351 "Definições para Simplificação"))
("explose" . ("maxima.info-3" 275447 248 "Definições para Simetrias"))
("expon" . ("maxima.info-1" 222029 280 "Definições para Simplificação"))
("exponenciação não comutativa" . ("maxima.info-1" 81285 16 "Operadores Geral"))
("exponentialize" . ("maxima.info-1" 222310 584 "Definições para Simplificação"))
("exponentialize <1>" . ("maxima.info-1" 222311 583 "Definições para Simplificação"))
("expop" . ("maxima.info-1" 222895 410 "Definições para Simplificação"))
("express" . ("maxima.info-2" 141613 2733 "Definições para Diferenciação"))
("expt" . ("maxima.info-1" 286133 264 "Definições para Entrada e Saída"))
("exptdispflag" . ("maxima.info-1" 286398 203 "Definições para Entrada e Saída"))
("exptisolate" . ("maxima.info-1" 176793 208 "Definições para Expressões"))
("exptsubst" . ("maxima.info-1" 177002 167 "Definições para Expressões"))
("exsec" . ("maxima.info-5" 283830 147 "Definições para simplification"))
("extdiff" . ("maxima.info-3" 134213 1458 "Definições para itensor"))
("extract_linear_equations" . ("maxima.info-3" 57793 403 "Definições para Funções Afins"))
("extremal_subset" . ("maxima.info-4" 108135 729 "Definições para Conjuntos"))
("extremal_subset <1>" . ("maxima.info-4" 108136 728 "Definições para Conjuntos"))
("ezgcd" . ("maxima.info-2" 26065 263 "Definições para Polinómios"))
("f90" . ("maxima.info-5" 145076 1648 "Definições para f90"))
("facexpand" . ("maxima.info-2" 26329 220 "Definições para Polinómios"))
("facsum" . ("maxima.info-5" 274664 2257 "Definições para simplification"))
("facsum_combine" . ("maxima.info-5" 277711 726 "Definições para simplification"))
("factcomb" . ("maxima.info-2" 26550 295 "Definições para Polinómios"))
("factlim" . ("maxima.info-1" 223306 192 "Definições para Simplificação"))
("factor" . ("maxima.info-2" 26846 6207 "Definições para Polinómios"))
("factor <1>" . ("maxima.info-2" 26847 6206 "Definições para Polinómios"))
("factorfacsum" . ("maxima.info-5" 278438 355 "Definições para simplification"))
("factorflag" . ("maxima.info-2" 33054 174 "Definições para Polinómios"))
("factorial" . ("maxima.info-3" 255613 139 "Definições para Teoria dos Números"))
("factorout" . ("maxima.info-2" 33229 240 "Definições para Polinómios"))
("factorsum" . ("maxima.info-2" 33470 860 "Definições para Polinómios"))
("facts" . ("maxima.info-2" 14833 453 "Definições para Contextos"))
("facts <1>" . ("maxima.info-2" 14834 452 "Definições para Contextos"))
("false" . ("maxima.info-2" 75103 137 "Definições para Constantes"))
("fast_central_elements" . ("maxima.info-3" 56277 421 "Definições para Funções Afins"))
("fast_linsolve" . ("maxima.info-3" 53398 691 "Definições para Funções Afins"))
("fasttimes" . ("maxima.info-2" 34331 422 "Definições para Polinómios"))
("fb" . ("maxima.info-3" 202318 114 "Definições para ctensor"))
("feature" . ("maxima.info-4" 5148 384 "Definições para Ambiente em Tempo de Execução"))
("featurep" . ("maxima.info-4" 5533 532 "Definições para Ambiente em Tempo de Execução"))
("features" . ("maxima.info-2" 15287 1105 "Definições para Contextos"))
("fft" . ("maxima.info-2" 248081 2359 "Definições para Numérico"))
("fib" . ("maxima.info-3" 255753 416 "Definições para Teoria dos Números"))
("fibtophi" . ("maxima.info-3" 256170 1209 "Definições para Teoria dos Números"))
("fifth" . ("maxima.info-4" 78608 126 "Definições para Listas"))
("file_output_append" . ("maxima.info-1" 275151 680 "Definições para Entrada e Saída"))
("file_search" . ("maxima.info-1" 286935 1963 "Definições para Entrada e Saída"))
("file_search <1>" . ("maxima.info-1" 286936 1962 "Definições para Entrada e Saída"))
("file_search_demo" . ("maxima.info-1" 288942 1604 "Definições para Entrada e Saída"))
("file_search_lisp" . ("maxima.info-1" 288900 1646 "Definições para Entrada e Saída"))
("file_search_maxima" . ("maxima.info-1" 288899 1647 "Definições para Entrada e Saída"))
("file_type" . ("maxima.info-1" 290547 570 "Definições para Entrada e Saída"))
("filename_merge" . ("maxima.info-1" 286602 332 "Definições para Entrada e Saída"))
("fillarray" . ("maxima.info-2" 272903 2248 "Definições para Arrays"))
("find_root" . ("maxima.info-2" 254336 2417 "Definições para Numérico"))
("find_root <1>" . ("maxima.info-2" 254337 2416 "Definições para Numérico"))
("find_root_abs" . ("maxima.info-2" 256754 686 "Definições para Numérico"))
("find_root_error" . ("maxima.info-2" 257441 720 "Definições para Numérico"))
("find_root_rel" . ("maxima.info-2" 258162 674 "Definições para Numérico"))
("findde" . ("maxima.info-3" 175958 2327 "Definições para ctensor"))
("first" . ("maxima.info-4" 78735 770 "Definições para Listas"))
("fix" . ("maxima.info-1" 111904 60 "Operadores Geral"))
("flatten" . ("maxima.info-4" 108865 2575 "Definições para Conjuntos"))
("flength" . ("maxima.info-6" 54672 77 "Definições para entrada e saída"))
("flipflag" . ("maxima.info-3" 77512 665 "Definições para itensor"))
("float" . ("maxima.info-2" 2912 326 "Definições para ponto Flutuante"))
("float2bf" . ("maxima.info-2" 3239 293 "Definições para ponto Flutuante"))
("floatnump" . ("maxima.info-2" 3533 132 "Definições para ponto Flutuante"))
("floor" . ("maxima.info-1" 108144 1917 "Operadores Geral"))
("flush" . ("maxima.info-3" 104744 168 "Definições para itensor"))
("flush1deriv" . ("maxima.info-3" 110734 164 "Definições para itensor"))
("flushd" . ("maxima.info-3" 104913 165 "Definições para itensor"))
("flushnd" . ("maxima.info-3" 105079 719 "Definições para itensor"))
("for" . ("maxima.info-4" 227511 126 "Definições para Fluxo de Programa"))
("forget" . ("maxima.info-2" 16393 347 "Definições para Contextos"))
("forget <1>" . ("maxima.info-2" 16394 346 "Definições para Contextos"))
("fortindent" . ("maxima.info-2" 250441 318 "Definições para Numérico"))
("fortran" . ("maxima.info-2" 250760 2262 "Definições para Numérico"))
("fortspaces" . ("maxima.info-2" 253023 196 "Definições para Numérico"))
("fourcos" . ("maxima.info-2" 262520 135 "Definições para Séries de Fourier"))
("fourexpand" . ("maxima.info-2" 262249 270 "Definições para Séries de Fourier"))
("fourier" . ("maxima.info-2" 261771 144 "Definições para Séries de Fourier"))
("fourint" . ("maxima.info-2" 262916 153 "Definições para Séries de Fourier"))
("fourintcos" . ("maxima.info-2" 263070 133 "Definições para Séries de Fourier"))
("fourintsin" . ("maxima.info-2" 263204 132 "Definições para Séries de Fourier"))
("foursimp" . ("maxima.info-2" 261916 154 "Definições para Séries de Fourier"))
("foursin" . ("maxima.info-2" 262656 132 "Definições para Séries de Fourier"))
("fourth" . ("maxima.info-4" 79506 126 "Definições para Listas"))
("fposition" . ("maxima.info-6" 54750 323 "Definições para entrada e saída"))
("fposition <1>" . ("maxima.info-6" 54751 322 "Definições para entrada e saída"))
("fpprec" . ("maxima.info-2" 3666 293 "Definições para ponto Flutuante"))
("fpprintprec" . ("maxima.info-2" 3960 853 "Definições para ponto Flutuante"))
("frame_bracket" . ("maxima.info-3" 166900 325 "Definições para ctensor"))
("freeof" . ("maxima.info-1" 177170 4167 "Definições para Expressões"))
("freshline" . ("maxima.info-6" 55074 176 "Definições para entrada e saída"))
("freshline <1>" . ("maxima.info-6" 55075 175 "Definições para entrada e saída"))
("full_listify" . ("maxima.info-4" 111441 575 "Definições para Conjuntos"))
("fullmap" . ("maxima.info-1" 111965 722 "Operadores Geral"))
("fullmapl" . ("maxima.info-1" 112688 264 "Operadores Geral"))
("fullratsimp" . ("maxima.info-2" 34754 1671 "Definições para Polinómios"))
("fullratsubst" . ("maxima.info-2" 36426 2147 "Definições para Polinómios"))
("fullsetify" . ("maxima.info-4" 112017 673 "Definições para Conjuntos"))
("funcsolve" . ("maxima.info-2" 208151 932 "Definições para Equações"))
("functions" . ("maxima.info-4" 184422 1898 "Definições para Definição de Função"))
("fundef" . ("maxima.info-4" 186321 862 "Definições para Definição de Função"))
("funmake" . ("maxima.info-4" 187236 3076 "Definições para Definição de Função"))
("funp" . ("maxima.info-2" 260879 301 "Definições para Séries de Fourier"))
("funp <1>" . ("maxima.info-2" 260880 300 "Definições para Séries de Fourier"))
("gamma" . ("maxima.info-2" 105371 194 "Definições para Funções Especiais"))
("gammalim" . ("maxima.info-2" 105566 405 "Definições para Funções Especiais"))
("gaussprob" . ("maxima.info-5" 283047 178 "Definições para simplification"))
("gcd" . ("maxima.info-2" 38574 1237 "Definições para Polinómios"))
("gcdex" . ("maxima.info-2" 39812 1600 "Definições para Polinómios"))
("gcdex <1>" . ("maxima.info-2" 39813 1599 "Definições para Polinómios"))
("gcdivide" . ("maxima.info-5" 281586 326 "Definições para simplification"))
("gcfac" . ("maxima.info-5" 290828 1030 "Definições para simplification"))
("gcfactor" . ("maxima.info-2" 41413 276 "Definições para Polinómios"))
("gd" . ("maxima.info-5" 283226 150 "Definições para simplification"))
("gdet" . ("maxima.info-3" 199807 161 "Definições para ctensor"))
("gen_laguerre" . ("maxima.info-5" 241990 150 "Definições para polinómios ortogonais"))
("genfact" . ("maxima.info-1" 181338 229 "Definições para Expressões"))
("genindex" . ("maxima.info-4" 14074 162 "Definições para Opções Diversas"))
("genmatrix" . ("maxima.info-3" 21820 2784 "Definições para Matrizes e Álgebra Linear"))
("genmatrix <1>" . ("maxima.info-3" 21821 2783 "Definições para Matrizes e Álgebra Linear"))
("genmatrix <2>" . ("maxima.info-3" 21877 2727 "Definições para Matrizes e Álgebra Linear"))
("gensumnum" . ("maxima.info-4" 14237 264 "Definições para Opções Diversas"))
("geometric" . ("maxima.info-5" 282133 211 "Definições para simplification"))
("geometric_mean" . ("maxima.info-4" 293576 936 "Definições para estatística descritiva"))
("geometric_mean <1>" . ("maxima.info-4" 293577 935 "Definições para estatística descritiva"))
("geosum" . ("maxima.info-5" 282758 288 "Definições para simplification"))
("get" . ("maxima.info-4" 79633 1003 "Definições para Listas"))
("get_lu_factors" . ("maxima.info-5" 180467 298 "Definições para linearalgebra"))
("gfactor" . ("maxima.info-2" 41690 335 "Definições para Polinómios"))
("gfactorsum" . ("maxima.info-2" 42026 104 "Definições para Polinómios"))
("ggf" . ("maxima.info-5" 148143 519 "Definições para ggf"))
("global_variances" . ("maxima.info-5" 3095 1830 "Definições específicas para estatística descritiva de várias variáveis"))
("global_variances <1>" . ("maxima.info-5" 3096 1829 "Definições específicas para estatística descritiva de várias variáveis"))
("globalsolve" . ("maxima.info-2" 209084 2115 "Definições para Equações"))
("go" . ("maxima.info-4" 227638 596 "Definições para Fluxo de Programa"))
("gosper_in_zeilberger" . ("maxima.info-6" 109329 263 "Definições para zeilberger"))
("gradef" . ("maxima.info-2" 144347 1990 "Definições para Diferenciação"))
("gradef <1>" . ("maxima.info-2" 144348 1989 "Definições para Diferenciação"))
("gradefs" . ("maxima.info-2" 146338 281 "Definições para Diferenciação"))
("gramschmidt" . ("maxima.info-3" 24605 1931 "Definições para Matrizes e Álgebra Linear"))
("grind" . ("maxima.info-1" 291118 4661 "Definições para Entrada e Saída"))
("grind <1>" . ("maxima.info-1" 291119 4660 "Definições para Entrada e Saída"))
("grobner_basis" . ("maxima.info-3" 54090 607 "Definições para Funções Afins"))
("gschmit" . ("maxima.info-3" 24606 1930 "Definições para Matrizes e Álgebra Linear"))
("halfangles" . ("maxima.info-2" 89810 152 "Definições para Trigonometria"))
("hankel" . ("maxima.info-5" 180766 293 "Definições para linearalgebra"))
("hankel <1>" . ("maxima.info-5" 180767 292 "Definições para linearalgebra"))
("harmonic" . ("maxima.info-5" 282345 242 "Definições para simplification"))
("harmonic_mean" . ("maxima.info-4" 292630 945 "Definições para estatística descritiva"))
("harmonic_mean <1>" . ("maxima.info-4" 292631 944 "Definições para estatística descritiva"))
("hav" . ("maxima.info-5" 283978 139 "Definições para simplification"))
("hermite" . ("maxima.info-5" 242141 127 "Definições para polinómios ortogonais"))
("hessian" . ("maxima.info-5" 181060 199 "Definições para linearalgebra"))
("hilbert_matrix" . ("maxima.info-5" 181260 155 "Definições para linearalgebra"))
("hipow" . ("maxima.info-2" 42131 886 "Definições para Polinómios"))
("histogram" . ("maxima.info-5" 16054 2283 "Definições para gráficos estatísticos"))
("histogram <1>" . ("maxima.info-5" 16055 2282 "Definições para gráficos estatísticos"))
("histogram <2>" . ("maxima.info-5" 16087 2250 "Definições para gráficos estatísticos"))
("histogram <3>" . ("maxima.info-5" 16146 2191 "Definições para gráficos estatísticos"))
("hodge" . ("maxima.info-3" 135672 1520 "Definições para itensor"))
("horner" . ("maxima.info-2" 253220 1115 "Definições para Numérico"))
("horner <1>" . ("maxima.info-2" 253221 1114 "Definições para Numérico"))
("i" . ("maxima.info-2" 75031 71 "Definições para Constantes"))
("ibase" . ("maxima.info-1" 295780 538 "Definições para Entrada e Saída"))
("ic1" . ("maxima.info-2" 239703 454 "Definições para Equações Diferenciais"))
("ic2" . ("maxima.info-2" 240158 672 "Definições para Equações Diferenciais"))
("ic_convert" . ("maxima.info-3" 139376 2257 "Definições para itensor"))
("icc1" . ("maxima.info-3" 121203 644 "Definições para itensor"))
("icc2" . ("maxima.info-3" 121848 675 "Definições para itensor"))
("ichr1" . ("maxima.info-3" 111559 355 "Definições para itensor"))
("ichr2" . ("maxima.info-3" 111915 283 "Definições para itensor"))
("icounter" . ("maxima.info-3" 87413 263 "Definições para itensor"))
("icurvature" . ("maxima.info-3" 112199 584 "Definições para itensor"))
("ident" . ("maxima.info-3" 26537 72 "Definições para Matrizes e Álgebra Linear"))
("identfor" . ("maxima.info-5" 181416 625 "Definições para linearalgebra"))
("identfor <1>" . ("maxima.info-5" 181417 624 "Definições para linearalgebra"))
("identity" . ("maxima.info-4" 112691 285 "Definições para Conjuntos"))
("idiff" . ("maxima.info-3" 100131 778 "Definições para itensor"))
("idim" . ("maxima.info-3" 111383 175 "Definições para itensor"))
("idummy" . ("maxima.info-3" 86889 352 "Definições para itensor"))
("idummyx" . ("maxima.info-3" 87242 170 "Definições para itensor"))
("ieqn" . ("maxima.info-2" 211200 1400 "Definições para Equações"))
("ieqnprint" . ("maxima.info-2" 212601 715 "Definições para Equações"))
("if" . ("maxima.info-4" 228235 2274 "Definições para Fluxo de Programa"))
("ifactors" . ("maxima.info-3" 257380 583 "Definições para Teoria dos Números"))
("ifb" . ("maxima.info-3" 120138 1064 "Definições para itensor"))
("ifc1" . ("maxima.info-3" 122524 467 "Definições para itensor"))
("ifc2" . ("maxima.info-3" 122992 432 "Definições para itensor"))
("ifg" . ("maxima.info-3" 123826 124 "Definições para itensor"))
("ifgi" . ("maxima.info-3" 123951 128 "Definições para itensor"))
("ifr" . ("maxima.info-3" 123425 173 "Definições para itensor"))
("iframe_bracket_form" . ("maxima.info-3" 124080 143 "Definições para itensor"))
("iframes" . ("maxima.info-3" 119928 209 "Definições para itensor"))
("ifri" . ("maxima.info-3" 123599 226 "Definições para itensor"))
("ifs" . ("maxima.info-5" 133564 994 "Análise gráfica de sistemas dinâmicos discretos"))
("ift" . ("maxima.info-2" 247650 430 "Definições para Numérico"))
("ift <1>" . ("maxima.info-2" 248082 2358 "Definições para Numérico"))
("igeodesic_coords" . ("maxima.info-3" 114737 1915 "Definições para itensor"))
("igeowedge_flag" . ("maxima.info-3" 137193 414 "Definições para itensor"))
("ikt1" . ("maxima.info-3" 125886 458 "Definições para itensor"))
("ikt2" . ("maxima.info-3" 126345 293 "Definições para itensor"))
("ilt" . ("maxima.info-2" 156402 2164 "Definições para Integração"))
("imagpart" . ("maxima.info-1" 181568 238 "Definições para Expressões"))
("imetric" . ("maxima.info-3" 110967 415 "Definições para itensor"))
("imetric <1>" . ("maxima.info-3" 110968 414 "Definições para itensor"))
("implicit_derivative" . ("maxima.info-5" 148940 448 "Definições para impdiff"))
("in_netmath" . ("maxima.info-1" 237150 301 "Definições para Criação de Gráficos"))
("inchar" . ("maxima.info-1" 296319 689 "Definições para Entrada e Saída"))
("indexed_tensor" . ("maxima.info-3" 79984 234 "Definições para itensor"))
("indices" . ("maxima.info-3" 73142 1024 "Definições para itensor"))
("inf" . ("maxima.info-2" 75241 67 "Definições para Constantes"))
("inf <1>" . ("maxima.info-4" 14502 48 "Definições para Opções Diversas"))
("inference_result" . ("maxima.info-6" 11316 1938 "Definições para inference_result"))
("inferencep" . ("maxima.info-6" 13255 129 "Definições para inference_result"))
("infeval" . ("maxima.info-1" 58159 400 "Definições para Linha de Comandos"))
("infinity" . ("maxima.info-2" 75309 72 "Definições para Constantes"))
("infinity <1>" . ("maxima.info-4" 14551 135 "Definições para Opções Diversas"))
("infix" . ("maxima.info-1" 181807 3514 "Definições para Expressões"))
("infix <1>" . ("maxima.info-1" 181808 3513 "Definições para Expressões"))
("infix <2>" . ("maxima.info-1" 181833 3488 "Definições para Expressões"))
("inflag" . ("maxima.info-1" 185322 735 "Definições para Expressões"))
("infolists" . ("maxima.info-4" 14687 2208 "Definições para Opções Diversas"))
("init_atensor" . ("maxima.info-3" 212321 2550 "Definições para o Pacote atensor"))
("init_atensor <1>" . ("maxima.info-3" 212322 2549 "Definições para o Pacote atensor"))
("init_ctensor" . ("maxima.info-3" 153550 378 "Definições para ctensor"))
("inm" . ("maxima.info-3" 124584 354 "Definições para itensor"))
("inmc1" . ("maxima.info-3" 124939 388 "Definições para itensor"))
("inmc2" . ("maxima.info-3" 125328 557 "Definições para itensor"))
("innerproduct" . ("maxima.info-3" 26610 471 "Definições para Matrizes e Álgebra Linear"))
("inpart" . ("maxima.info-1" 186058 1304 "Definições para Expressões"))
("inprod" . ("maxima.info-3" 26611 470 "Definições para Matrizes e Álgebra Linear"))
("inrt" . ("maxima.info-3" 257964 292 "Definições para Teoria dos Números"))
("integer_partitions" . ("maxima.info-4" 112977 1973 "Definições para Conjuntos"))
("integer_partitions <1>" . ("maxima.info-4" 112978 1972 "Definições para Conjuntos"))
("integerp" . ("maxima.info-4" 16896 954 "Definições para Opções Diversas"))
("integrate" . ("maxima.info-2" 158567 8710 "Definições para Integração"))
("integrate <1>" . ("maxima.info-2" 158568 8709 "Definições para Integração"))
("integrate_use_rootsof" . ("maxima.info-2" 167626 2430 "Definições para Integração"))
("integration_constant_counter" . ("maxima.info-2" 167278 347 "Definições para Integração"))
("intersect" . ("maxima.info-4" 114951 104 "Definições para Conjuntos"))
("intersection" . ("maxima.info-4" 115056 945 "Definições para Conjuntos"))
("intervalp" . ("maxima.info-5" 242269 113 "Definições para polinómios ortogonais"))
("intfaclim" . ("maxima.info-2" 43018 786 "Definições para Polinómios"))
("intopois" . ("maxima.info-2" 105972 70 "Definições para Funções Especiais"))
("intosum" . ("maxima.info-1" 223499 516 "Definições para Simplificação"))
("inv_mod" . ("maxima.info-3" 258257 385 "Definições para Teoria dos Números"))
("invariant1" . ("maxima.info-3" 181693 202 "Definições para ctensor"))
("invariant2" . ("maxima.info-3" 181896 257 "Definições para ctensor"))
("inverse_jacobi_cd" . ("maxima.info-2" 119645 94 "Definições para Funções Elípticas"))
("inverse_jacobi_cn" . ("maxima.info-2" 118980 94 "Definições para Funções Elípticas"))
("inverse_jacobi_cs" . ("maxima.info-2" 119550 94 "Definições para Funções Elípticas"))
("inverse_jacobi_dc" . ("maxima.info-2" 119930 96 "Definições para Funções Elípticas"))
("inverse_jacobi_dn" . ("maxima.info-2" 119075 94 "Definições para Funções Elípticas"))
("inverse_jacobi_ds" . ("maxima.info-2" 119835 94 "Definições para Funções Elípticas"))
("inverse_jacobi_nc" . ("maxima.info-2" 119455 94 "Definições para Funções Elípticas"))
("inverse_jacobi_nd" . ("maxima.info-2" 119740 94 "Definições para Funções Elípticas"))
("inverse_jacobi_ns" . ("maxima.info-2" 119170 94 "Definições para Funções Elípticas"))
("inverse_jacobi_sc" . ("maxima.info-2" 119265 94 "Definições para Funções Elípticas"))
("inverse_jacobi_sd" . ("maxima.info-2" 119360 94 "Definições para Funções Elípticas"))
("inverse_jacobi_sn" . ("maxima.info-2" 118885 94 "Definições para Funções Elípticas"))
("invert" . ("maxima.info-3" 27082 1131 "Definições para Matrizes e Álgebra Linear"))
("invert_by_lu" . ("maxima.info-5" 182042 177 "Definições para linearalgebra"))
("is" . ("maxima.info-1" 112953 1942 "Operadores Geral"))
("ishow" . ("maxima.info-3" 72807 334 "Definições para itensor"))
("isolate" . ("maxima.info-1" 187363 840 "Definições para Expressões"))
("isolate_wrt_times" . ("maxima.info-1" 188204 784 "Definições para Expressões"))
("isqrt" . ("maxima.info-1" 115649 112 "Operadores Geral"))
("items_inference" . ("maxima.info-6" 13385 710 "Definições para inference_result"))
("itr" . ("maxima.info-3" 126639 2670 "Definições para itensor"))
("jacobi" . ("maxima.info-3" 258643 251 "Definições para Teoria dos Números"))
("jacobi_cd" . ("maxima.info-2" 118515 93 "Definições para Funções Elípticas"))
("jacobi_cn" . ("maxima.info-2" 117905 75 "Definições para Funções Elípticas"))
("jacobi_cs" . ("maxima.info-2" 118421 93 "Definições para Funções Elípticas"))
("jacobi_dc" . ("maxima.info-2" 118791 93 "Definições para Funções Elípticas"))
("jacobi_dn" . ("maxima.info-2" 117981 75 "Definições para Funções Elípticas"))
("jacobi_ds" . ("maxima.info-2" 118697 93 "Definições para Funções Elípticas"))
("jacobi_nc" . ("maxima.info-2" 118333 87 "Definições para Funções Elípticas"))
("jacobi_nd" . ("maxima.info-2" 118609 87 "Definições para Funções Elípticas"))
("jacobi_ns" . ("maxima.info-2" 118057 87 "Definições para Funções Elípticas"))
("jacobi_p" . ("maxima.info-5" 242383 343 "Definições para polinómios ortogonais"))
("jacobi_sc" . ("maxima.info-2" 118145 93 "Definições para Funções Elípticas"))
("jacobi_sd" . ("maxima.info-2" 118239 93 "Definições para Funções Elípticas"))
("jacobi_sn" . ("maxima.info-2" 117829 75 "Definições para Funções Elípticas"))
("join" . ("maxima.info-4" 80637 750 "Definições para Listas"))
("jordan" . ("maxima.info-5" 24504 1674 "Definições para diag"))
("kdels" . ("maxima.info-3" 88527 858 "Definições para itensor"))
("kdelta" . ("maxima.info-3" 87677 849 "Definições para itensor"))
("keepfloat" . ("maxima.info-2" 43805 279 "Definições para Polinómios"))
("kill" . ("maxima.info-1" 58560 2830 "Definições para Linha de Comandos"))
("kill <1>" . ("maxima.info-1" 58561 2829 "Definições para Linha de Comandos"))
("kill <2>" . ("maxima.info-1" 58598 2792 "Definições para Linha de Comandos"))
("kill <3>" . ("maxima.info-1" 58624 2766 "Definições para Linha de Comandos"))
("kill <4>" . ("maxima.info-1" 58675 2715 "Definições para Linha de Comandos"))
("kill <5>" . ("maxima.info-1" 58698 2692 "Definições para Linha de Comandos"))
("kill <6>" . ("maxima.info-1" 58728 2662 "Definições para Linha de Comandos"))
("kill <7>" . ("maxima.info-1" 58778 2612 "Definições para Linha de Comandos"))
("killcontext" . ("maxima.info-2" 16741 752 "Definições para Contextos"))
("kinvariant" . ("maxima.info-3" 202433 95 "Definições para ctensor"))
("kostka" . ("maxima.info-3" 284740 235 "Definições para Simetrias"))
("kron_delta" . ("maxima.info-4" 116002 4364 "Definições para Conjuntos"))
("kronecker_product" . ("maxima.info-5" 182220 102 "Definições para linearalgebra"))
("kt" . ("maxima.info-3" 203396 103 "Definições para ctensor"))
("kurtosis" . ("maxima.info-4" 294513 894 "Definições para estatística descritiva"))
("kurtosis <1>" . ("maxima.info-4" 294514 893 "Definições para estatística descritiva"))
("kurtosis_bernoulli" . ("maxima.info-5" 116360 701 "Definições para distribuições discretas"))
("kurtosis_beta" . ("maxima.info-5" 81640 201 "Definições para distribuições contínuas"))
("kurtosis_binomial" . ("maxima.info-5" 108078 233 "Definições para distribuições discretas"))
("kurtosis_chi2" . ("maxima.info-5" 60417 767 "Definições para distribuições contínuas"))
("kurtosis_continuous_uniform" . ("maxima.info-5" 84895 227 "Definições para distribuições contínuas"))
("kurtosis_discrete_uniform" . ("maxima.info-5" 122363 248 "Definições para distribuições discretas"))
("kurtosis_exp" . ("maxima.info-5" 71282 684 "Definições para distribuições contínuas"))
("kurtosis_f" . ("maxima.info-5" 64602 201 "Definições para distribuições contínuas"))
("kurtosis_gamma" . ("maxima.info-5" 78104 203 "Definições para distribuições contínuas"))
("kurtosis_geometric" . ("maxima.info-5" 119073 209 "Definições para distribuições discretas"))
("kurtosis_gumbel" . ("maxima.info-5" 105059 203 "Definições para distribuições contínuas"))
("kurtosis_hypergeometric" . ("maxima.info-5" 125246 281 "Definições para distribuições discretas"))
("kurtosis_laplace" . ("maxima.info-5" 101203 205 "Definições para distribuições contínuas"))
("kurtosis_logistic" . ("maxima.info-5" 87194 208 "Definições para distribuições contínuas"))
("kurtosis_lognormal" . ("maxima.info-5" 75303 209 "Definições para distribuições contínuas"))
("kurtosis_negative_binomial" . ("maxima.info-5" 129250 251 "Definições para distribuições discretas"))
("kurtosis_normal" . ("maxima.info-5" 49899 227 "Definições para distribuições contínuas"))
("kurtosis_pareto" . ("maxima.info-5" 89381 207 "Definições para distribuições contínuas"))
("kurtosis_poisson" . ("maxima.info-5" 111394 203 "Definições para distribuições discretas"))
("kurtosis_rayleigh" . ("maxima.info-5" 98231 1013 "Definições para distribuições contínuas"))
("kurtosis_student_t" . ("maxima.info-5" 53447 206 "Definições para distribuições contínuas"))
("kurtosis_weibull" . ("maxima.info-5" 91568 207 "Definições para distribuições contínuas"))
("labels" . ("maxima.info-1" 61391 1833 "Definições para Linha de Comandos"))
("labels <1>" . ("maxima.info-1" 61392 1832 "Definições para Linha de Comandos"))
("lagrange" . ("maxima.info-5" 150093 2594 "Definições para interpol"))
("lagrange <1>" . ("maxima.info-5" 150094 2593 "Definições para interpol"))
("laguerre" . ("maxima.info-5" 242727 146 "Definições para polinómios ortogonais"))
("lambda" . ("maxima.info-4" 190380 6107 "Definições para Definição de Função"))
("lambda <1>" . ("maxima.info-4" 190434 6053 "Definições para Definição de Função"))
("lambda <2>" . ("maxima.info-4" 190507 5980 "Definições para Definição de Função"))
("laplace" . ("maxima.info-2" 146620 2488 "Definições para Diferenciação"))
("lassociative" . ("maxima.info-1" 224016 216 "Definições para Simplificação"))
("last" . ("maxima.info-4" 81388 99 "Definições para Listas"))
("lbfgs" . ("maxima.info-5" 160965 5178 "Definições para lbfgs"))
("lbfgs_ncorrections" . ("maxima.info-5" 166204 62 "Definições para lbfgs"))
("lbfgs_nfeval_max" . ("maxima.info-5" 166144 59 "Definições para lbfgs"))
("lc2kdt" . ("maxima.info-3" 89648 3317 "Definições para itensor"))
("lc_l" . ("maxima.info-3" 92966 1098 "Definições para itensor"))
("lc_u" . ("maxima.info-3" 94065 309 "Definições para itensor"))
("lcharp" . ("maxima.info-6" 63088 122 "Definições para caracteres"))
("lcm" . ("maxima.info-3" 258895 209 "Definições para Teoria dos Números"))
("ldefint" . ("maxima.info-2" 170057 734 "Definições para Integração"))
("ldisp" . ("maxima.info-1" 297009 1063 "Definições para Entrada e Saída"))
("ldisplay" . ("maxima.info-1" 298073 1280 "Definições para Entrada e Saída"))
("legendre_p" . ("maxima.info-5" 242874 164 "Definições para polinómios ortogonais"))
("legendre_q" . ("maxima.info-5" 243039 144 "Definições para polinómios ortogonais"))
("leinstein" . ("maxima.info-3" 157487 417 "Definições para ctensor"))
("length" . ("maxima.info-4" 81488 543 "Definições para Listas"))
("let" . ("maxima.info-4" 37744 4461 "Definições para Regras e Modelos"))
("let <1>" . ("maxima.info-4" 37745 4460 "Definições para Regras e Modelos"))
("let_rule_packages" . ("maxima.info-4" 44237 253 "Definições para Regras e Modelos"))
("letrat" . ("maxima.info-4" 42206 835 "Definições para Regras e Modelos"))
("letrules" . ("maxima.info-4" 43042 549 "Definições para Regras e Modelos"))
("letrules <1>" . ("maxima.info-4" 43043 548 "Definições para Regras e Modelos"))
("letsimp" . ("maxima.info-4" 43592 644 "Definições para Regras e Modelos"))
("letsimp <1>" . ("maxima.info-4" 43593 643 "Definições para Regras e Modelos"))
("letsimp <2>" . ("maxima.info-4" 43622 614 "Definições para Regras e Modelos"))
("levi_civita" . ("maxima.info-3" 89386 261 "Definições para itensor"))
("lfg" . ("maxima.info-3" 200933 207 "Definições para ctensor"))
("lfreeof" . ("maxima.info-1" 190489 205 "Definições para Expressões"))
("lg" . ("maxima.info-3" 201985 172 "Definições para ctensor"))
("lgtreillis" . ("maxima.info-3" 284976 241 "Definições para Simetrias"))
("lhospitallim" . ("maxima.info-2" 122106 237 "Definições para Limites"))
("lhs" . ("maxima.info-2" 213317 1611 "Definições para Equações"))
("li" . ("maxima.info-2" 78930 2578 "Definições para Logaritmos"))
("liediff" . ("maxima.info-3" 100910 807 "Definições para itensor"))
("limit" . ("maxima.info-2" 122344 1562 "Definições para Limites"))
("limit <1>" . ("maxima.info-2" 122345 1561 "Definições para Limites"))
("limit <2>" . ("maxima.info-2" 122391 1515 "Definições para Limites"))
("limsubst" . ("maxima.info-2" 123907 285 "Definições para Limites"))
("linear" . ("maxima.info-1" 224233 596 "Definições para Simplificação"))
("linear <1>" . ("maxima.info-5" 281279 306 "Definições para simplification"))
("linear_program" . ("maxima.info-5" 268147 1057 "Definições para simplex"))
("linear_solver" . ("maxima.info-6" 108952 193 "Definições para zeilberger"))
("linearinterpol" . ("maxima.info-5" 152860 2390 "Definições para interpol"))
("linearinterpol <1>" . ("maxima.info-5" 152861 2389 "Definições para interpol"))
("linechar" . ("maxima.info-1" 299354 503 "Definições para Entrada e Saída"))
("linel" . ("maxima.info-1" 299858 451 "Definições para Entrada e Saída"))
("linenum" . ("maxima.info-1" 63225 119 "Definições para Linha de Comandos"))
("linsolve" . ("maxima.info-2" 214929 2990 "Definições para Equações"))
("linsolve_params" . ("maxima.info-2" 218087 372 "Definições para Equações"))
("linsolvewarn" . ("maxima.info-2" 217920 166 "Definições para Equações"))
("lispdisp" . ("maxima.info-1" 300310 504 "Definições para Entrada e Saída"))
("list_correlations" . ("maxima.info-5" 7093 3312 "Definições específicas para estatística descritiva de várias variáveis"))
("list_correlations <1>" . ("maxima.info-5" 7094 3311 "Definições específicas para estatística descritiva de várias variáveis"))
("list_nc_monomials" . ("maxima.info-3" 58197 292 "Definições para Funções Afins"))
("list_nc_monomials <1>" . ("maxima.info-3" 58198 291 "Definições para Funções Afins"))
("listarith" . ("maxima.info-4" 82032 383 "Definições para Listas"))
("listarray" . ("maxima.info-2" 275152 3837 "Definições para Arrays"))
("listconstvars" . ("maxima.info-1" 188989 338 "Definições para Expressões"))
("listdummyvars" . ("maxima.info-1" 189328 707 "Definições para Expressões"))
("listify" . ("maxima.info-4" 120367 453 "Definições para Conjuntos"))
("listoftens" . ("maxima.info-3" 72246 560 "Definições para itensor"))
("listofvars" . ("maxima.info-1" 190036 452 "Definições para Expressões"))
("listp" . ("maxima.info-4" 82416 108 "Definições para Listas"))
("listp <1>" . ("maxima.info-5" 182323 350 "Definições para linearalgebra"))
("listp <2>" . ("maxima.info-5" 182324 349 "Definições para linearalgebra"))
("lmax" . ("maxima.info-1" 115762 195 "Operadores Geral"))
("lmin" . ("maxima.info-1" 115958 198 "Operadores Geral"))
("lmxchar" . ("maxima.info-3" 28214 519 "Definições para Matrizes e Álgebra Linear"))
("load" . ("maxima.info-1" 300815 1423 "Definições para Entrada e Saída"))
("loadfile" . ("maxima.info-1" 302239 719 "Definições para Entrada e Saída"))
("loadprint" . ("maxima.info-1" 302959 581 "Definições para Entrada e Saída"))
("local" . ("maxima.info-4" 196527 440 "Definições para Definição de Função"))
("locate_matrix_entry" . ("maxima.info-5" 182674 1065 "Definições para linearalgebra"))
("log" . ("maxima.info-2" 81509 1745 "Definições para Logaritmos"))
("logabs" . ("maxima.info-2" 83255 439 "Definições para Logaritmos"))
("logarc" . ("maxima.info-2" 83695 441 "Definições para Logaritmos"))
("logarc <1>" . ("maxima.info-2" 83696 440 "Definições para Logaritmos"))
("logconcoeffp" . ("maxima.info-2" 84137 427 "Definições para Logaritmos"))
("logcontract" . ("maxima.info-2" 84565 975 "Definições para Logaritmos"))
("logexpand" . ("maxima.info-2" 85541 517 "Definições para Logaritmos"))
("lognegint" . ("maxima.info-2" 86059 177 "Definições para Logaritmos"))
("lognumer" . ("maxima.info-2" 86237 388 "Definições para Logaritmos"))
("logsimp" . ("maxima.info-2" 86626 177 "Definições para Logaritmos"))
("lopow" . ("maxima.info-1" 190695 223 "Definições para Expressões"))
("lorentz_gauge" . ("maxima.info-3" 114518 218 "Definições para itensor"))
("lowercasep" . ("maxima.info-6" 63211 105 "Definições para caracteres"))
("lpart" . ("maxima.info-1" 190919 236 "Definições para Expressões"))
("lratsubst" . ("maxima.info-2" 44085 1026 "Definições para Polinómios"))
("lreduce" . ("maxima.info-4" 120821 1376 "Definições para Conjuntos"))
("lreduce <1>" . ("maxima.info-4" 120822 1375 "Definições para Conjuntos"))
("lriem" . ("maxima.info-3" 201617 92 "Definições para ctensor"))
("lriemann" . ("maxima.info-3" 159158 513 "Definições para ctensor"))
("lsquares" . ("maxima.info-5" 201431 4286 "Definições para lsquares"))
("lsquares <1>" . ("maxima.info-5" 201432 4285 "Definições para lsquares"))
("lstringp" . ("maxima.info-6" 63994 156 "Definições para sequências de caracteres"))
("lsum" . ("maxima.info-1" 215040 692 "Definições para Expressões"))
("ltreillis" . ("maxima.info-3" 285218 271 "Definições para Simetrias"))
("lu_backsub" . ("maxima.info-5" 183740 158 "Definições para linearalgebra"))
("lu_factor" . ("maxima.info-5" 183899 5983 "Definições para linearalgebra"))
("m1pbranch" . ("maxima.info-4" 17851 599 "Definições para Opções Diversas"))
("macroexpand" . ("maxima.info-4" 160096 1304 "Macros"))
("macroexpand1" . ("maxima.info-4" 161401 1184 "Macros"))
("macroexpansion" . ("maxima.info-4" 197007 1106 "Definições para Definição de Função"))
("macros" . ("maxima.info-4" 162586 336 "Macros"))
("mainvar" . ("maxima.info-1" 224830 749 "Definições para Simplificação"))
("makeOrders" . ("maxima.info-5" 210299 838 "Definições para makeOrders"))
("make_array" . ("maxima.info-2" 278990 2024 "Definições para Arrays"))
("make_random_state" . ("maxima.info-1" 119068 816 "Operadores Geral"))
("make_random_state <1>" . ("maxima.info-1" 119069 815 "Operadores Geral"))
("make_random_state <2>" . ("maxima.info-1" 119105 779 "Operadores Geral"))
("make_random_state <3>" . ("maxima.info-1" 119141 743 "Operadores Geral"))
("make_transform" . ("maxima.info-1" 262606 302 "Definições para Criação de Gráficos"))
("makebox" . ("maxima.info-3" 106514 259 "Definições para itensor"))
("makefact" . ("maxima.info-2" 106043 155 "Definições para Funções Especiais"))
("makegamma" . ("maxima.info-2" 106199 162 "Definições para Funções Especiais"))
("makelist" . ("maxima.info-4" 82525 744 "Definições para Listas"))
("makelist <1>" . ("maxima.info-4" 82526 743 "Definições para Listas"))
("makeset" . ("maxima.info-4" 122198 1652 "Definições para Conjuntos"))
("map" . ("maxima.info-4" 230510 1781 "Definições para Fluxo de Programa"))
("mapatom" . ("maxima.info-4" 232292 225 "Definições para Fluxo de Programa"))
("maperror" . ("maxima.info-4" 232518 521 "Definições para Fluxo de Programa"))
("maplist" . ("maxima.info-4" 233040 436 "Definições para Fluxo de Programa"))
("mat_cond" . ("maxima.info-5" 189883 529 "Definições para linearalgebra"))
("mat_cond <1>" . ("maxima.info-5" 189884 528 "Definições para linearalgebra"))
("mat_fullunblocker" . ("maxima.info-5" 191270 219 "Definições para linearalgebra"))
("mat_function" . ("maxima.info-5" 29356 10169 "Definições para diag"))
("mat_norm" . ("maxima.info-5" 190413 303 "Definições para linearalgebra"))
("mat_norm <1>" . ("maxima.info-5" 190414 302 "Definições para linearalgebra"))
("mat_norm <2>" . ("maxima.info-5" 190444 272 "Definições para linearalgebra"))
("mat_trace" . ("maxima.info-5" 191490 258 "Definições para linearalgebra"))
("mat_unblocker" . ("maxima.info-5" 191749 1785 "Definições para linearalgebra"))
("matchdeclare" . ("maxima.info-4" 44491 8462 "Definições para Regras e Modelos"))
("matchfix" . ("maxima.info-4" 52954 4994 "Definições para Regras e Modelos"))
("matchfix <1>" . ("maxima.info-4" 52955 4993 "Definições para Regras e Modelos"))
("matrix" . ("maxima.info-3" 28734 6024 "Definições para Matrizes e Álgebra Linear"))
("matrix_element_add" . ("maxima.info-3" 35031 1319 "Definições para Matrizes e Álgebra Linear"))
("matrix_element_mult" . ("maxima.info-3" 36351 1987 "Definições para Matrizes e Álgebra Linear"))
("matrix_element_transpose" . ("maxima.info-3" 38339 2201 "Definições para Matrizes e Álgebra Linear"))
("matrix_size" . ("maxima.info-5" 191117 152 "Definições para linearalgebra"))
("matrixmap" . ("maxima.info-3" 34759 160 "Definições para Matrizes e Álgebra Linear"))
("matrixp" . ("maxima.info-3" 34920 110 "Definições para Matrizes e Álgebra Linear"))
("matrixp <1>" . ("maxima.info-5" 190717 399 "Definições para linearalgebra"))
("matrixp <2>" . ("maxima.info-5" 190718 398 "Definições para linearalgebra"))
("mattrace" . ("maxima.info-3" 40541 269 "Definições para Matrizes e Álgebra Linear"))
("max" . ("maxima.info-1" 116157 505 "Operadores Geral"))
("maxapplydepth" . ("maxima.info-1" 225580 165 "Definições para Simplificação"))
("maxapplyheight" . ("maxima.info-1" 225746 160 "Definições para Simplificação"))
("maxi" . ("maxima.info-4" 287256 490 "Definições para estatística descritiva"))
("maxi <1>" . ("maxima.info-4" 287257 489 "Definições para estatística descritiva"))
("maxima_tempdir" . ("maxima.info-4" 6066 504 "Definições para Ambiente em Tempo de Execução"))
("maxima_userdir" . ("maxima.info-4" 6571 802 "Definições para Ambiente em Tempo de Execução"))
("maximize_sx" . ("maxima.info-5" 269205 268 "Definições para simplex"))
("maxnegex" . ("maxima.info-1" 225907 178 "Definições para Simplificação"))
("maxposex" . ("maxima.info-1" 226086 170 "Definições para Simplificação"))
("maxpsifracdenom" . ("maxima.info-2" 113270 273 "Definições para Funções Especiais"))
("maxpsifracnum" . ("maxima.info-2" 111727 267 "Definições para Funções Especiais"))
("maxpsinegint" . ("maxima.info-2" 111417 309 "Definições para Funções Especiais"))
("maxpsiposint" . ("maxima.info-2" 111242 174 "Definições para Funções Especiais"))
("maxtayorder" . ("maxima.info-3" 221145 257 "Definições para Séries"))
("maybe" . ("maxima.info-1" 114896 752 "Operadores Geral"))
("mean" . ("maxima.info-4" 280440 913 "Definições para estatística descritiva"))
("mean <1>" . ("maxima.info-4" 280441 912 "Definições para estatística descritiva"))
("mean_bernoulli" . ("maxima.info-5" 113986 537 "Definições para distribuições discretas"))
("mean_beta" . ("maxima.info-5" 80894 174 "Definições para distribuições contínuas"))
("mean_binomial" . ("maxima.info-5" 107192 212 "Definições para distribuições discretas"))
("mean_chi2" . ("maxima.info-5" 57718 628 "Definições para distribuições contínuas"))
("mean_continuous_uniform" . ("maxima.info-5" 84033 206 "Definições para distribuições contínuas"))
("mean_deviation" . ("maxima.info-4" 290753 975 "Definições para estatística descritiva"))
("mean_deviation <1>" . ("maxima.info-4" 290754 974 "Definições para estatística descritiva"))
("mean_discrete_uniform" . ("maxima.info-5" 121417 227 "Definições para distribuições discretas"))
("mean_exp" . ("maxima.info-5" 68374 714 "Definições para distribuições contínuas"))
("mean_f" . ("maxima.info-5" 63850 174 "Definições para distribuições contínuas"))
("mean_gamma" . ("maxima.info-5" 77344 176 "Definições para distribuições contínuas"))
("mean_geometric" . ("maxima.info-5" 118305 178 "Definições para distribuições discretas"))
("mean_gumbel" . ("maxima.info-5" 103787 335 "Definições para distribuições contínuas"))
("mean_hypergeometric" . ("maxima.info-5" 124156 267 "Definições para distribuições discretas"))
("mean_laplace" . ("maxima.info-5" 100435 178 "Definições para distribuições contínuas"))
("mean_lognormal" . ("maxima.info-5" 74519 182 "Definições para distribuições contínuas"))
("mean_negative_binomial" . ("maxima.info-5" 128292 230 "Definições para distribuições discretas"))
("mean_normal" . ("maxima.info-5" 49069 195 "Definições para distribuições contínuas"))
("mean_pareto" . ("maxima.info-5" 88605 180 "Definições para distribuições contínuas"))
("mean_poisson" . ("maxima.info-5" 110656 172 "Definições para distribuições discretas"))
("mean_rayleigh" . ("maxima.info-5" 94740 731 "Definições para distribuições contínuas"))
("mean_student_t" . ("maxima.info-5" 52478 209 "Definições para distribuições contínuas"))
("mean_weibull" . ("maxima.info-5" 90792 180 "Definições para distribuições contínuas"))
("meanlog" . ("maxima.info-5" 86420 175 "Definições para distribuições contínuas"))
("median" . ("maxima.info-4" 289201 778 "Definições para estatística descritiva"))
("median <1>" . ("maxima.info-4" 289202 777 "Definições para estatística descritiva"))
("median_deviation" . ("maxima.info-4" 291729 900 "Definições para estatística descritiva"))
("median_deviation <1>" . ("maxima.info-4" 291730 899 "Definições para estatística descritiva"))
("member" . ("maxima.info-4" 83270 1364 "Definições para Listas"))
("metricexpandall" . ("maxima.info-6" 101248 1049 "Definições para Units"))
("min" . ("maxima.info-1" 116663 505 "Operadores Geral"))
("minf" . ("maxima.info-2" 75382 83 "Definições para Constantes"))
("minfactorial" . ("maxima.info-3" 259105 549 "Definições para Teoria dos Números"))
("mini" . ("maxima.info-4" 286770 485 "Definições para estatística descritiva"))
("mini <1>" . ("maxima.info-4" 286771 484 "Definições para estatística descritiva"))
("minimalPoly" . ("maxima.info-5" 27241 673 "Definições para diag"))
("minimize_sx" . ("maxima.info-5" 269474 1961 "Definições para simplex"))
("minor" . ("maxima.info-3" 40811 191 "Definições para Matrizes e Álgebra Linear"))
("mnewton" . ("maxima.info-5" 211863 1087 "Definições para mnewton"))
("mod" . ("maxima.info-1" 117496 1254 "Operadores Geral"))
("mod_big_prime" . ("maxima.info-6" 110469 149 "Definições para zeilberger"))
("mod_test" . ("maxima.info-6" 109918 174 "Definições para zeilberger"))
("mod_threshold" . ("maxima.info-6" 110619 163 "Definições para zeilberger"))
("mode_check_errorp" . ("maxima.info-4" 198326 118 "Definições para Definição de Função"))
("mode_check_warnp" . ("maxima.info-4" 198486 101 "Definições para Definição de Função"))
("mode_checkp" . ("maxima.info-4" 198150 133 "Definições para Definição de Função"))
("mode_declare" . ("maxima.info-4" 198654 1814 "Definições para Definição de Função"))
("mode_identity" . ("maxima.info-4" 200515 1344 "Definições para Definição de Função"))
("modular_linear_solver" . ("maxima.info-6" 110093 181 "Definições para zeilberger"))
("modulus" . ("maxima.info-2" 45112 1186 "Definições para Polinómios"))
("moebius" . ("maxima.info-4" 123851 1265 "Definições para Conjuntos"))
("mon2schur" . ("maxima.info-3" 267531 1121 "Definições para Simetrias"))
("mono" . ("maxima.info-3" 57361 244 "Definições para Funções Afins"))
("monomial_dimensions" . ("maxima.info-3" 57606 186 "Definições para Funções Afins"))
("multi_elem" . ("maxima.info-3" 268653 698 "Definições para Simetrias"))
("multi_orbit" . ("maxima.info-3" 280524 643 "Definições para Simetrias"))
("multi_pui" . ("maxima.info-3" 269352 420 "Definições para Simetrias"))
("multinomial" . ("maxima.info-3" 300558 259 "Definições para Simetrias"))
("multinomial_coeff" . ("maxima.info-4" 125117 1269 "Definições para Conjuntos"))
("multinomial_coeff <1>" . ("maxima.info-4" 125118 1268 "Definições para Conjuntos"))
("multiplicative" . ("maxima.info-1" 226257 734 "Definições para Simplificação"))
("multiplicities" . ("maxima.info-2" 218460 205 "Definições para Equações"))
("multsym" . ("maxima.info-3" 281168 781 "Definições para Simetrias"))
("multthru" . ("maxima.info-1" 191156 2336 "Definições para Expressões"))
("multthru <1>" . ("maxima.info-1" 191157 2335 "Definições para Expressões"))
("myoptions" . ("maxima.info-1" 63345 223 "Definições para Linha de Comandos"))
("nc_degree" . ("maxima.info-3" 55838 180 "Definições para Funções Afins"))
("ncexpt" . ("maxima.info-3" 41003 293 "Definições para Matrizes e Álgebra Linear"))
("ncharpoly" . ("maxima.info-3" 41297 796 "Definições para Matrizes e Álgebra Linear"))
("negdistrib" . ("maxima.info-1" 226992 494 "Definições para Simplificação"))
("negsumdispflag" . ("maxima.info-1" 227487 401 "Definições para Simplificação"))
("newcontext" . ("maxima.info-2" 17494 287 "Definições para Contextos"))
("newdet" . ("maxima.info-3" 42094 215 "Definições para Matrizes e Álgebra Linear"))
("newline" . ("maxima.info-6" 63317 54 "Definições para caracteres"))
("newline <1>" . ("maxima.info-6" 55251 237 "Definições para entrada e saída"))
("newline <2>" . ("maxima.info-6" 55252 236 "Definições para entrada e saída"))
("newton" . ("maxima.info-2" 258837 1338 "Definições para Numérico"))
("newtonepsilon" . ("maxima.info-5" 211425 203 "Definições para mnewton"))
("newtonmaxiter" . ("maxima.info-5" 211629 233 "Definições para mnewton"))
("next_prime" . ("maxima.info-3" 259655 145 "Definições para Teoria dos Números"))
("nextlayerfactor" . ("maxima.info-5" 276922 788 "Definições para simplification"))
("niceindices" . ("maxima.info-3" 221403 1469 "Definições para Séries"))
("niceindicespref" . ("maxima.info-3" 222873 1095 "Definições para Séries"))
("ninth" . ("maxima.info-4" 84635 124 "Definições para Listas"))
("nm" . ("maxima.info-3" 203500 106 "Definições para ctensor"))
("nmc" . ("maxima.info-3" 203607 113 "Definições para ctensor"))
("noeval" . ("maxima.info-1" 227889 213 "Definições para Simplificação"))
("nolabels" . ("maxima.info-1" 63569 615 "Definições para Linha de Comandos"))
("noncentral_moment" . ("maxima.info-4" 284169 969 "Definições para estatística descritiva"))
("noncentral_moment <1>" . ("maxima.info-4" 284170 968 "Definições para estatística descritiva"))
("nonegative_sx" . ("maxima.info-5" 271436 263 "Definições para simplex"))
("nonmetricity" . ("maxima.info-3" 175473 148 "Definições para ctensor"))
("nonnegintegerp" . ("maxima.info-5" 193535 103 "Definições para linearalgebra"))
("nonscalar" . ("maxima.info-3" 42310 135 "Definições para Matrizes e Álgebra Linear"))
("nonscalarp" . ("maxima.info-3" 42446 162 "Definições para Matrizes e Álgebra Linear"))
("nonzeroandfreeof" . ("maxima.info-5" 281038 240 "Definições para simplification"))
("not" . ("maxima.info-1" 96417 500 "Operadores Geral"))
("notequal" . ("maxima.info-1" 110062 1572 "Operadores Geral"))
("noun" . ("maxima.info-1" 228103 202 "Definições para Simplificação"))
("noundisp" . ("maxima.info-1" 228306 247 "Definições para Simplificação"))
("nounify" . ("maxima.info-1" 193493 437 "Definições para Expressões"))
("nouns" . ("maxima.info-1" 228554 345 "Definições para Simplificação"))
("np" . ("maxima.info-3" 202529 91 "Definições para ctensor"))
("npi" . ("maxima.info-3" 202621 650 "Definições para ctensor"))
("nptetrad" . ("maxima.info-3" 167541 723 "Definições para ctensor"))
("nroots" . ("maxima.info-2" 218666 440 "Definições para Equações"))
("nterms" . ("maxima.info-1" 193931 369 "Definições para Expressões"))
("ntermst" . ("maxima.info-3" 182608 395 "Definições para ctensor"))
("nthroot" . ("maxima.info-2" 219107 329 "Definições para Equações"))
("ntrig" . ("maxima.info-2" 89963 280 "Definições para Trigonometria"))
("nullity" . ("maxima.info-5" 193982 97 "Definições para linearalgebra"))
("nullspace" . ("maxima.info-5" 193639 342 "Definições para linearalgebra"))
("num" . ("maxima.info-2" 46299 172 "Definições para Polinómios"))
("num_distinct_partitions" . ("maxima.info-4" 126387 859 "Definições para Conjuntos"))
("num_distinct_partitions <1>" . ("maxima.info-4" 126388 858 "Definições para Conjuntos"))
("num_partitions" . ("maxima.info-4" 127247 931 "Definições para Conjuntos"))
("num_partitions <1>" . ("maxima.info-4" 127248 930 "Definições para Conjuntos"))
("numberp" . ("maxima.info-4" 18451 1214 "Definições para Opções Diversas"))
("numer" . ("maxima.info-1" 228900 351 "Definições para Simplificação"))
("numerval" . ("maxima.info-1" 229252 458 "Definições para Simplificação"))
("numfactor" . ("maxima.info-2" 106362 557 "Definições para Funções Especiais"))
("nusum" . ("maxima.info-3" 223969 2214 "Definições para Séries"))
("obase" . ("maxima.info-1" 303541 494 "Definições para Entrada e Saída"))
("oddp" . ("maxima.info-1" 118751 124 "Operadores Geral"))
("ode2" . ("maxima.info-2" 240831 4045 "Definições para Equações Diferenciais"))
("op" . ("maxima.info-1" 194301 1765 "Definições para Expressões"))
("opena" . ("maxima.info-6" 55489 186 "Definições para entrada e saída"))
("openr" . ("maxima.info-6" 55676 120 "Definições para entrada e saída"))
("openw" . ("maxima.info-6" 55797 218 "Definições para entrada e saída"))
("operatorp" . ("maxima.info-1" 196067 330 "Definições para Expressões"))
("operatorp <1>" . ("maxima.info-1" 196068 329 "Definições para Expressões"))
("opproperties" . ("maxima.info-1" 229711 330 "Definições para Simplificação"))
("opsubst" . ("maxima.info-1" 230042 235 "Definições para Simplificação"))
("opsubst <1>" . ("maxima.info-5" 219958 2297 "Definições para opsubst"))
("opsubst <2>" . ("maxima.info-5" 219959 2296 "Definições para opsubst"))
("opsubst <3>" . ("maxima.info-5" 219993 2262 "Definições para opsubst"))
("optimize" . ("maxima.info-1" 196398 388 "Definições para Expressões"))
("optimprefix" . ("maxima.info-1" 196787 153 "Definições para Expressões"))
("optionset" . ("maxima.info-1" 64185 371 "Definições para Linha de Comandos"))
("or" . ("maxima.info-1" 95458 958 "Operadores Geral"))
("orbit" . ("maxima.info-3" 281950 527 "Definições para Simetrias"))
("orbits" . ("maxima.info-5" 134559 850 "Análise gráfica de sistemas dinâmicos discretos"))
("ordergreat" . ("maxima.info-1" 196941 248 "Definições para Expressões"))
("ordergreatp" . ("maxima.info-1" 197190 149 "Definições para Expressões"))
("orderless" . ("maxima.info-1" 197340 686 "Definições para Expressões"))
("orderlessp" . ("maxima.info-1" 198027 147 "Definições para Expressões"))
("orthogonal_complement" . ("maxima.info-5" 194080 289 "Definições para linearalgebra"))
("orthopoly_recur" . ("maxima.info-5" 243184 1209 "Definições para polinómios ortogonais"))
("orthopoly_returns_intervals" . ("maxima.info-5" 244394 372 "Definições para polinómios ortogonais"))
("orthopoly_weight" . ("maxima.info-5" 244767 778 "Definições para polinómios ortogonais"))
("outative" . ("maxima.info-1" 230278 860 "Definições para Simplificação"))
("outchar" . ("maxima.info-1" 304036 686 "Definições para Entrada e Saída"))
("outermap" . ("maxima.info-4" 235990 6854 "Definições para Fluxo de Programa"))
("outofpois" . ("maxima.info-2" 106920 374 "Definições para Funções Especiais"))
("packagefile" . ("maxima.info-1" 304723 799 "Definições para Entrada e Saída"))
("pade" . ("maxima.info-3" 226184 3136 "Definições para Séries"))
("parGosper" . ("maxima.info-6" 107504 343 "Definições para zeilberger"))
("parse_string" . ("maxima.info-5" 143919 912 "Definições para eval_string"))
("parsetoken" . ("maxima.info-6" 64860 645 "Definições para sequências de caracteres"))
("part" . ("maxima.info-1" 198175 1200 "Definições para Expressões"))
("part2cont" . ("maxima.info-3" 275696 343 "Definições para Simetrias"))
("partfrac" . ("maxima.info-3" 259801 1218 "Definições para Teoria dos Números"))
("partition" . ("maxima.info-1" 199376 595 "Definições para Expressões"))
("partition_set" . ("maxima.info-4" 128179 756 "Definições para Conjuntos"))
("partpol" . ("maxima.info-3" 276040 272 "Definições para Simetrias"))
("partswitch" . ("maxima.info-1" 199972 241 "Definições para Expressões"))
("pdf_bernoulli" . ("maxima.info-5" 112823 605 "Definições para distribuições discretas"))
("pdf_beta" . ("maxima.info-5" 79713 227 "Definições para distribuições contínuas"))
("pdf_binomial" . ("maxima.info-5" 105891 254 "Definições para distribuições discretas"))
("pdf_cauchy" . ("maxima.info-5" 101819 229 "Definições para distribuições contínuas"))
("pdf_chi2" . ("maxima.info-5" 55187 966 "Definições para distribuições contínuas"))
("pdf_continuous_uniform" . ("maxima.info-5" 83163 253 "Definições para distribuições contínuas"))
("pdf_discrete_uniform" . ("maxima.info-5" 120501 258 "Definições para distribuições discretas"))
("pdf_exp" . ("maxima.info-5" 66089 758 "Definições para distribuições contínuas"))
("pdf_f" . ("maxima.info-5" 62285 224 "Definições para distribuições contínuas"))
("pdf_gamma" . ("maxima.info-5" 76247 229 "Definições para distribuições contínuas"))
("pdf_geometric" . ("maxima.info-5" 117526 221 "Definições para distribuições discretas"))
("pdf_gumbel" . ("maxima.info-5" 103006 229 "Definições para distribuições contínuas"))
("pdf_hypergeometric" . ("maxima.info-5" 123138 297 "Definições para distribuições discretas"))
("pdf_laplace" . ("maxima.info-5" 99648 231 "Definições para distribuições contínuas"))
("pdf_logistic" . ("maxima.info-5" 85624 234 "Definições para distribuições contínuas"))
("pdf_lognormal" . ("maxima.info-5" 73338 235 "Definições para distribuições contínuas"))
("pdf_negative_binomial" . ("maxima.info-5" 126898 272 "Definições para distribuições discretas"))
("pdf_normal" . ("maxima.info-5" 47936 229 "Definições para distribuições contínuas"))
("pdf_pareto" . ("maxima.info-5" 87817 231 "Definições para distribuições contínuas"))
("pdf_poisson" . ("maxima.info-5" 109598 215 "Definições para distribuições discretas"))
("pdf_rank_sum" . ("maxima.info-6" 45665 261 "Definições para distribuições especiais"))
("pdf_rayleigh" . ("maxima.info-5" 92188 825 "Definições para distribuições contínuas"))
("pdf_signed_rank" . ("maxima.info-6" 45176 245 "Definições para distribuições especiais"))
("pdf_student_t" . ("maxima.info-5" 51254 232 "Definições para distribuições contínuas"))
("pdf_weibull" . ("maxima.info-5" 89999 233 "Definições para distribuições contínuas"))
("pearson_skewness" . ("maxima.info-4" 296319 846 "Definições para estatística descritiva"))
("pearson_skewness <1>" . ("maxima.info-4" 296320 845 "Definições para estatística descritiva"))
("permanent" . ("maxima.info-3" 42609 143 "Definições para Matrizes e Álgebra Linear"))
("permut" . ("maxima.info-3" 300818 75 "Definições para Simetrias"))
("permutation" . ("maxima.info-5" 284314 206 "Definições para simplification"))
("permutations" . ("maxima.info-4" 128936 580 "Definições para Conjuntos"))
("petrov" . ("maxima.info-3" 169718 3973 "Definições para ctensor"))
("pfeformat" . ("maxima.info-1" 305523 816 "Definições para Entrada e Saída"))
("phi" . ("maxima.info-2" 75467 2414 "Definições para Constantes"))
("pi" . ("maxima.info-2" 77883 201 "Definições para Constantes"))
("pickapart" . ("maxima.info-1" 200214 2970 "Definições para Expressões"))
("piece" . ("maxima.info-1" 203185 214 "Definições para Expressões"))
("playback" . ("maxima.info-1" 64557 2085 "Definições para Linha de Comandos"))
("playback <1>" . ("maxima.info-1" 64558 2084 "Definições para Linha de Comandos"))
("playback <2>" . ("maxima.info-1" 64582 2060 "Definições para Linha de Comandos"))
("playback <3>" . ("maxima.info-1" 64609 2033 "Definições para Linha de Comandos"))
("playback <4>" . ("maxima.info-1" 64643 1999 "Definições para Linha de Comandos"))
("playback <5>" . ("maxima.info-1" 64672 1970 "Definições para Linha de Comandos"))
("playback <6>" . ("maxima.info-1" 64701 1941 "Definições para Linha de Comandos"))
("playback <7>" . ("maxima.info-1" 64729 1913 "Definições para Linha de Comandos"))
("plog" . ("maxima.info-2" 86804 142 "Definições para Logaritmos"))
("plot2d" . ("maxima.info-1" 237452 6795 "Definições para Criação de Gráficos"))
("plot2d <1>" . ("maxima.info-1" 237453 6794 "Definições para Criação de Gráficos"))
("plot2d <2>" . ("maxima.info-1" 237516 6731 "Definições para Criação de Gráficos"))
("plot3d" . ("maxima.info-1" 257977 4628 "Definições para Criação de Gráficos"))
("plot3d <1>" . ("maxima.info-1" 258041 4564 "Definições para Criação de Gráficos"))
("plot3d <2>" . ("maxima.info-1" 258082 4523 "Definições para Criação de Gráficos"))
("plot3d <3>" . ("maxima.info-1" 258152 4453 "Definições para Criação de Gráficos"))
("plot3d <4>" . ("maxima.info-1" 258222 4383 "Definições para Criação de Gráficos"))
("plot_options" . ("maxima.info-1" 244248 13728 "Definições para Criação de Gráficos"))
("plotdf" . ("maxima.info-5" 250443 9480 "Definições para plotdf"))
("plotdf <1>" . ("maxima.info-5" 250444 9479 "Definições para plotdf"))
("plsquares" . ("maxima.info-5" 205718 4272 "Definições para lsquares"))
("plsquares <1>" . ("maxima.info-5" 205719 4271 "Definições para lsquares"))
("plsquares <2>" . ("maxima.info-5" 205769 4221 "Definições para lsquares"))
("pochhammer" . ("maxima.info-5" 245546 1313 "Definições para polinómios ortogonais"))
("pochhammer_max_index" . ("maxima.info-5" 246860 515 "Definições para polinómios ortogonais"))
("poisdiff" . ("maxima.info-2" 107295 158 "Definições para Funções Especiais"))
("poisexpt" . ("maxima.info-2" 107454 125 "Definições para Funções Especiais"))
("poisint" . ("maxima.info-2" 107580 197 "Definições para Funções Especiais"))
("poislim" . ("maxima.info-2" 107778 305 "Definições para Funções Especiais"))
("poismap" . ("maxima.info-2" 108084 326 "Definições para Funções Especiais"))
("poisplus" . ("maxima.info-2" 108411 85 "Definições para Funções Especiais"))
("poissimp" . ("maxima.info-2" 108497 99 "Definições para Funções Especiais"))
("poisson" . ("maxima.info-2" 108597 125 "Definições para Funções Especiais"))
("poissubst" . ("maxima.info-2" 108723 902 "Definições para Funções Especiais"))
("poistimes" . ("maxima.info-2" 109626 88 "Definições para Funções Especiais"))
("poistrim" . ("maxima.info-2" 109715 416 "Definições para Funções Especiais"))
("polarform" . ("maxima.info-1" 203400 148 "Definições para Expressões"))
("polartorect" . ("maxima.info-2" 246113 726 "Definições para Numérico"))
("polartorect <1>" . ("maxima.info-2" 248182 2258 "Definições para Numérico"))
("polydecomp" . ("maxima.info-2" 46472 1955 "Definições para Polinómios"))
("polymod" . ("maxima.info-1" 117169 326 "Operadores Geral"))
("polymod <1>" . ("maxima.info-1" 117170 325 "Operadores Geral"))
("polynome2ele" . ("maxima.info-3" 287191 562 "Definições para Simetrias"))
("polynomialp" . ("maxima.info-5" 194370 2564 "Definições para linearalgebra"))
("polynomialp <1>" . ("maxima.info-5" 194371 2563 "Definições para linearalgebra"))
("polynomialp <2>" . ("maxima.info-5" 194426 2508 "Definições para linearalgebra"))
("polytocompanion" . ("maxima.info-5" 196935 301 "Definições para linearalgebra"))
("posfun" . ("maxima.info-1" 231139 122 "Definições para Simplificação"))
("potential" . ("maxima.info-2" 170792 550 "Definições para Integração"))
("power_mod" . ("maxima.info-3" 261020 541 "Definições para Teoria dos Números"))
("powerdisp" . ("maxima.info-3" 229321 418 "Definições para Séries"))
("powers" . ("maxima.info-1" 203549 140 "Definições para Expressões"))
("powerseries" . ("maxima.info-3" 229740 1712 "Definições para Séries"))
("powerset" . ("maxima.info-4" 129517 1138 "Definições para Conjuntos"))
("powerset <1>" . ("maxima.info-4" 129518 1137 "Definições para Conjuntos"))
("pred" . ("maxima.info-1" 118876 191 "Operadores Geral"))
("prederror" . ("maxima.info-4" 233477 476 "Definições para Fluxo de Programa"))
("prev_prime" . ("maxima.info-3" 262497 145 "Definições para Teoria dos Números"))
("primep" . ("maxima.info-3" 261562 801 "Definições para Teoria dos Números"))
("primep_number_of_tests" . ("maxima.info-3" 262364 132 "Definições para Teoria dos Números"))
("print" . ("maxima.info-1" 306340 1274 "Definições para Entrada e Saída"))
("printf" . ("maxima.info-6" 56016 3139 "Definições para entrada e saída"))
("printf <1>" . ("maxima.info-6" 56017 3138 "Definições para entrada e saída"))
("printpois" . ("maxima.info-2" 110132 197 "Definições para Funções Especiais"))
("printprops" . ("maxima.info-1" 66643 524 "Definições para Linha de Comandos"))
("printprops <1>" . ("maxima.info-1" 66644 523 "Definições para Linha de Comandos"))
("printprops <2>" . ("maxima.info-1" 66678 489 "Definições para Linha de Comandos"))
("prodrac" . ("maxima.info-3" 287754 250 "Definições para Simetrias"))
("product" . ("maxima.info-1" 203690 2561 "Definições para Expressões"))
("product_use_gamma" . ("maxima.info-6" 8177 257 "Definições para solve_rec"))
("programmode" . ("maxima.info-2" 219437 456 "Definições para Equações"))
("prompt" . ("maxima.info-1" 67168 223 "Definições para Linha de Comandos"))
("properties" . ("maxima.info-4" 19666 119 "Definições para Opções Diversas"))
("props" . ("maxima.info-4" 19786 256 "Definições para Opções Diversas"))
("propvars" . ("maxima.info-4" 20043 236 "Definições para Opções Diversas"))
("psexpand" . ("maxima.info-3" 231453 474 "Definições para Séries"))
("psi" . ("maxima.info-2" 110330 911 "Definições para Funções Especiais"))
("psi <1>" . ("maxima.info-3" 168265 1452 "Definições para ctensor"))
("ptriangularize" . ("maxima.info-5" 197237 454 "Definições para linearalgebra"))
("pui" . ("maxima.info-3" 269773 1331 "Definições para Simetrias"))
("pui2comp" . ("maxima.info-3" 271105 1295 "Definições para Simetrias"))
("pui2ele" . ("maxima.info-3" 272401 410 "Definições para Simetrias"))
("pui2polynome" . ("maxima.info-3" 288005 652 "Definições para Simetrias"))
("pui_direct" . ("maxima.info-3" 282478 2227 "Definições para Simetrias"))
("puireduc" . ("maxima.info-3" 272812 708 "Definições para Simetrias"))
("put" . ("maxima.info-4" 20280 847 "Definições para Opções Diversas"))
("qput" . ("maxima.info-4" 21128 809 "Definições para Opções Diversas"))
("qrange" . ("maxima.info-4" 289980 772 "Definições para estatística descritiva"))
("qrange <1>" . ("maxima.info-4" 289981 771 "Definições para estatística descritiva"))
("quad_qag" . ("maxima.info-2" 177400 2479 "Definições para QUADPACK"))
("quad_qag <1>" . ("maxima.info-2" 177465 2414 "Definições para QUADPACK"))
("quad_qagi" . ("maxima.info-2" 181761 2365 "Definições para QUADPACK"))
("quad_qagi <1>" . ("maxima.info-2" 181762 2364 "Definições para QUADPACK"))
("quad_qags" . ("maxima.info-2" 179880 1880 "Definições para QUADPACK"))
("quad_qags <1>" . ("maxima.info-2" 179881 1879 "Definições para QUADPACK"))
("quad_qawc" . ("maxima.info-2" 184127 2882 "Definições para QUADPACK"))
("quad_qawc <1>" . ("maxima.info-2" 184128 2881 "Definições para QUADPACK"))
("quad_qawf" . ("maxima.info-2" 187010 2734 "Definições para QUADPACK"))
("quad_qawf <1>" . ("maxima.info-2" 187079 2665 "Definições para QUADPACK"))
("quad_qawo" . ("maxima.info-2" 189745 2897 "Definições para QUADPACK"))
("quad_qawo <1>" . ("maxima.info-2" 189819 2823 "Definições para QUADPACK"))
("quad_qaws" . ("maxima.info-2" 192643 2850 "Definições para QUADPACK"))
("quad_qaws <1>" . ("maxima.info-2" 192715 2778 "Definições para QUADPACK"))
("quantile" . ("maxima.info-4" 288251 949 "Definições para estatística descritiva"))
("quantile <1>" . ("maxima.info-4" 288252 948 "Definições para estatística descritiva"))
("quantile_bernoulli" . ("maxima.info-5" 113664 321 "Definições para distribuições discretas"))
("quantile_beta" . ("maxima.info-5" 80580 313 "Definições para distribuições contínuas"))
("quantile_binomial" . ("maxima.info-5" 106837 354 "Definições para distribuições discretas"))
("quantile_cauchy" . ("maxima.info-5" 102282 317 "Definições para distribuições contínuas"))
("quantile_chi2" . ("maxima.info-5" 56841 876 "Definições para distribuições contínuas"))
("quantile_continuous_uniform" . ("maxima.info-5" 83674 358 "Definições para distribuições contínuas"))
("quantile_discrete_uniform" . ("maxima.info-5" 121040 376 "Definições para distribuições discretas"))
("quantile_exp" . ("maxima.info-5" 67589 784 "Definições para distribuições contínuas"))
("quantile_f" . ("maxima.info-5" 63136 713 "Definições para distribuições contínuas"))
("quantile_gamma" . ("maxima.info-5" 77027 316 "Definições para distribuições contínuas"))
("quantile_geometric" . ("maxima.info-5" 117983 321 "Definições para distribuições discretas"))
("quantile_gumbel" . ("maxima.info-5" 103469 317 "Definições para distribuições contínuas"))
("quantile_hypergeometric" . ("maxima.info-5" 123747 408 "Definições para distribuições discretas"))
("quantile_laplace" . ("maxima.info-5" 100115 319 "Definições para distribuições contínuas"))
("quantile_logistic" . ("maxima.info-5" 86096 323 "Definições para distribuições contínuas"))
("quantile_lognormal" . ("maxima.info-5" 74193 325 "Definições para distribuições contínuas"))
("quantile_negative_binomial" . ("maxima.info-5" 127905 386 "Definições para distribuições discretas"))
("quantile_normal" . ("maxima.info-5" 48765 303 "Definições para distribuições contínuas"))
("quantile_pareto" . ("maxima.info-5" 88284 320 "Definições para distribuições contínuas"))
("quantile_poisson" . ("maxima.info-5" 110342 313 "Definições para distribuições discretas"))
("quantile_rayleigh" . ("maxima.info-5" 93819 920 "Definições para distribuições contínuas"))
("quantile_student_t" . ("maxima.info-5" 52153 324 "Definições para distribuições contínuas"))
("quantile_weibull" . ("maxima.info-5" 90470 321 "Definições para distribuições contínuas"))
("quartile_skewness" . ("maxima.info-4" 297166 942 "Definições para estatística descritiva"))
("quartile_skewness <1>" . ("maxima.info-4" 297167 941 "Definições para estatística descritiva"))
("quit" . ("maxima.info-1" 67392 373 "Definições para Linha de Comandos"))
("qunit" . ("maxima.info-3" 262643 425 "Definições para Teoria dos Números"))
("quotient" . ("maxima.info-2" 48428 333 "Definições para Polinómios"))
("quotient <1>" . ("maxima.info-2" 48429 332 "Definições para Polinómios"))
("radcan" . ("maxima.info-1" 231262 1256 "Definições para Simplificação"))
("radexpand" . ("maxima.info-1" 232519 908 "Definições para Simplificação"))
("radsubstflag" . ("maxima.info-1" 233428 187 "Definições para Simplificação"))
("random" . ("maxima.info-1" 120032 1672 "Operadores Geral"))
("random_bernoulli" . ("maxima.info-5" 117062 463 "Definições para distribuições discretas"))
("random_bernoulli <1>" . ("maxima.info-5" 117063 462 "Definições para distribuições discretas"))
("random_beta" . ("maxima.info-5" 82560 602 "Definições para distribuições contínuas"))
("random_beta <1>" . ("maxima.info-5" 82561 601 "Definições para distribuições contínuas"))
("random_beta_algorithm" . ("maxima.info-5" 81842 717 "Definições para distribuições contínuas"))
("random_binomial" . ("maxima.info-5" 108942 655 "Definições para distribuições discretas"))
("random_binomial <1>" . ("maxima.info-5" 108943 654 "Definições para distribuições discretas"))
("random_binomial_algorithm" . ("maxima.info-5" 108312 629 "Definições para distribuições discretas"))
("random_cauchy" . ("maxima.info-5" 102600 405 "Definições para distribuições contínuas"))
("random_cauchy <1>" . ("maxima.info-5" 102601 404 "Definições para distribuições contínuas"))
("random_chi2" . ("maxima.info-5" 61676 608 "Definições para distribuições contínuas"))
("random_chi2 <1>" . ("maxima.info-5" 61677 607 "Definições para distribuições contínuas"))
("random_chi2_algorithm" . ("maxima.info-5" 61185 490 "Definições para distribuições contínuas"))
("random_continuous_uniform" . ("maxima.info-5" 85123 500 "Definições para distribuições contínuas"))
("random_continuous_uniform <1>" . ("maxima.info-5" 85124 499 "Definições para distribuições contínuas"))
("random_discrete_uniform" . ("maxima.info-5" 122612 525 "Definições para distribuições discretas"))
("random_discrete_uniform <1>" . ("maxima.info-5" 122613 524 "Definições para distribuições discretas"))
("random_exp" . ("maxima.info-5" 72744 593 "Definições para distribuições contínuas"))
("random_exp <1>" . ("maxima.info-5" 72745 592 "Definições para distribuições contínuas"))
("random_exp_algorithm" . ("maxima.info-5" 71967 776 "Definições para distribuições contínuas"))
("random_f" . ("maxima.info-5" 65499 589 "Definições para distribuições contínuas"))
("random_f <1>" . ("maxima.info-5" 65500 588 "Definições para distribuições contínuas"))
("random_f_algorithm" . ("maxima.info-5" 64804 694 "Definições para distribuições contínuas"))
("random_gamma" . ("maxima.info-5" 79097 615 "Definições para distribuições contínuas"))
("random_gamma <1>" . ("maxima.info-5" 79098 614 "Definições para distribuições contínuas"))
("random_gamma_algorithm" . ("maxima.info-5" 78308 788 "Definições para distribuições contínuas"))
("random_geometric" . ("maxima.info-5" 119876 624 "Definições para distribuições discretas"))
("random_geometric <1>" . ("maxima.info-5" 119877 623 "Definições para distribuições discretas"))
("random_geometric_algorithm" . ("maxima.info-5" 119283 592 "Definições para distribuições discretas"))
("random_gumbel" . ("maxima.info-5" 105263 407 "Definições para distribuições contínuas"))
("random_gumbel <1>" . ("maxima.info-5" 105264 406 "Definições para distribuições contínuas"))
("random_hypergeometric" . ("maxima.info-5" 126165 732 "Definições para distribuições discretas"))
("random_hypergeometric <1>" . ("maxima.info-5" 126166 731 "Definições para distribuições discretas"))
("random_hypergeometric_algorithm" . ("maxima.info-5" 125528 636 "Definições para distribuições discretas"))
("random_laplace" . ("maxima.info-5" 101409 409 "Definições para distribuições contínuas"))
("random_laplace <1>" . ("maxima.info-5" 101410 408 "Definições para distribuições contínuas"))
("random_logistic" . ("maxima.info-5" 87403 413 "Definições para distribuições contínuas"))
("random_logistic <1>" . ("maxima.info-5" 87404 412 "Definições para distribuições contínuas"))
("random_lognormal" . ("maxima.info-5" 75513 733 "Definições para distribuições contínuas"))
("random_lognormal <1>" . ("maxima.info-5" 75514 732 "Definições para distribuições contínuas"))
("random_negative_binomial" . ("maxima.info-5" 130123 715 "Definições para distribuições discretas"))
("random_negative_binomial <1>" . ("maxima.info-5" 130124 714 "Definições para distribuições discretas"))
("random_negative_binomial_algorithm" . ("maxima.info-5" 129502 620 "Definições para distribuições discretas"))
("random_normal" . ("maxima.info-5" 50626 627 "Definições para distribuições contínuas"))
("random_normal <1>" . ("maxima.info-5" 50627 626 "Definições para distribuições contínuas"))
("random_normal_algorithm" . ("maxima.info-5" 50127 498 "Definições para distribuições contínuas"))
("random_pareto" . ("maxima.info-5" 89589 409 "Definições para distribuições contínuas"))
("random_pareto <1>" . ("maxima.info-5" 89590 408 "Definições para distribuições contínuas"))
("random_poisson" . ("maxima.info-5" 112208 614 "Definições para distribuições discretas"))
("random_poisson <1>" . ("maxima.info-5" 112209 613 "Definições para distribuições discretas"))
("random_poisson_algorithm" . ("maxima.info-5" 111598 609 "Definições para distribuições discretas"))
("random_rayleigh" . ("maxima.info-5" 99245 402 "Definições para distribuições contínuas"))
("random_rayleigh <1>" . ("maxima.info-5" 99246 401 "Definições para distribuições contínuas"))
("random_student_t" . ("maxima.info-5" 54564 622 "Definições para distribuições contínuas"))
("random_student_t <1>" . ("maxima.info-5" 54565 621 "Definições para distribuições contínuas"))
("random_student_t_algorithm" . ("maxima.info-5" 53654 909 "Definições para distribuições contínuas"))
("random_weibull" . ("maxima.info-5" 91776 411 "Definições para distribuições contínuas"))
("random_weibull <1>" . ("maxima.info-5" 91777 410 "Definições para distribuições contínuas"))
("range" . ("maxima.info-4" 287747 503 "Definições para estatística descritiva"))
("range <1>" . ("maxima.info-4" 287748 502 "Definições para estatística descritiva"))
("rank" . ("maxima.info-3" 42753 271 "Definições para Matrizes e Álgebra Linear"))
("rank <1>" . ("maxima.info-5" 197932 622 "Definições para linearalgebra"))
("rassociative" . ("maxima.info-1" 233616 205 "Definições para Simplificação"))
("rat" . ("maxima.info-2" 48762 2559 "Definições para Polinómios"))
("rat <1>" . ("maxima.info-2" 48763 2558 "Definições para Polinómios"))
("ratalgdenom" . ("maxima.info-2" 51322 304 "Definições para Polinómios"))
("ratchristof" . ("maxima.info-3" 199969 122 "Definições para ctensor"))
("ratcoef" . ("maxima.info-2" 51627 1166 "Definições para Polinómios"))
("ratcoef <1>" . ("maxima.info-2" 51628 1165 "Definições para Polinómios"))
("ratdenom" . ("maxima.info-2" 52794 645 "Definições para Polinómios"))
("ratdenomdivide" . ("maxima.info-2" 53440 1862 "Definições para Polinómios"))
("ratdiff" . ("maxima.info-2" 55303 1873 "Definições para Polinómios"))
("ratdisrep" . ("maxima.info-2" 57177 452 "Definições para Polinómios"))
("rateinstein" . ("maxima.info-3" 200092 258 "Definições para ctensor"))
("ratepsilon" . ("maxima.info-2" 57630 173 "Definições para Polinómios"))
("ratexpand" . ("maxima.info-2" 57804 2351 "Definições para Polinómios"))
("ratexpand <1>" . ("maxima.info-2" 57805 2350 "Definições para Polinómios"))
("ratfac" . ("maxima.info-2" 60156 1100 "Definições para Polinómios"))
("rational" . ("maxima.info-5" 280677 360 "Definições para simplification"))
("rationalize" . ("maxima.info-1" 121705 3290 "Operadores Geral"))
("ratmx" . ("maxima.info-3" 43025 615 "Definições para Matrizes e Álgebra Linear"))
("ratnumer" . ("maxima.info-2" 61257 643 "Definições para Polinómios"))
("ratnump" . ("maxima.info-2" 61901 150 "Definições para Polinómios"))
("ratp" . ("maxima.info-2" 62052 279 "Definições para Polinómios"))
("ratprint" . ("maxima.info-2" 62332 220 "Definições para Polinómios"))
("ratriemann" . ("maxima.info-3" 200351 302 "Definições para ctensor"))
("ratsimp" . ("maxima.info-2" 62553 2204 "Definições para Polinómios"))
("ratsimp <1>" . ("maxima.info-2" 62554 2203 "Definições para Polinómios"))
("ratsimpexpons" . ("maxima.info-2" 64758 190 "Definições para Polinómios"))
("ratsubst" . ("maxima.info-2" 64949 1536 "Definições para Polinómios"))
("ratvars" . ("maxima.info-2" 66486 1020 "Definições para Polinómios"))
("ratvars <1>" . ("maxima.info-2" 66487 1019 "Definições para Polinómios"))
("ratvars <2>" . ("maxima.info-2" 66527 979 "Definições para Polinómios"))
("ratweight" . ("maxima.info-2" 67507 1165 "Definições para Polinómios"))
("ratweight <1>" . ("maxima.info-2" 67508 1164 "Definições para Polinómios"))
("ratweights" . ("maxima.info-2" 68673 304 "Definições para Polinómios"))
("ratweyl" . ("maxima.info-3" 200654 278 "Definições para ctensor"))
("ratwtlvl" . ("maxima.info-2" 68978 255 "Definições para Polinómios"))
("read" . ("maxima.info-1" 308815 535 "Definições para Entrada e Saída"))
("read_hashed_array" . ("maxima.info-5" 217756 426 "Definições para numericalio"))
("read_hashed_array <1>" . ("maxima.info-5" 217757 425 "Definições para numericalio"))
("read_lisp_array" . ("maxima.info-5" 216567 592 "Definições para numericalio"))
("read_lisp_array <1>" . ("maxima.info-5" 216568 591 "Definições para numericalio"))
("read_list" . ("maxima.info-5" 218533 211 "Definições para numericalio"))
("read_list <1>" . ("maxima.info-5" 218534 210 "Definições para numericalio"))
("read_matrix" . ("maxima.info-5" 216062 504 "Definições para numericalio"))
("read_matrix <1>" . ("maxima.info-5" 216063 503 "Definições para numericalio"))
("read_maxima_array" . ("maxima.info-5" 217160 595 "Definições para numericalio"))
("read_maxima_array <1>" . ("maxima.info-5" 217161 594 "Definições para numericalio"))
("read_nested_list" . ("maxima.info-5" 218183 349 "Definições para numericalio"))
("read_nested_list <1>" . ("maxima.info-5" 218184 348 "Definições para numericalio"))
("readline" . ("maxima.info-6" 59156 221 "Definições para entrada e saída"))
("readonly" . ("maxima.info-1" 309351 640 "Definições para Entrada e Saída"))
("realonly" . ("maxima.info-2" 219894 162 "Definições para Equações"))
("realpart" . ("maxima.info-1" 206252 246 "Definições para Expressões"))
("realroots" . ("maxima.info-2" 220057 2186 "Definições para Equações"))
("realroots <1>" . ("maxima.info-2" 220058 2185 "Definições para Equações"))
("realroots <2>" . ("maxima.info-2" 220098 2145 "Definições para Equações"))
("realroots <3>" . ("maxima.info-2" 220137 2106 "Definições para Equações"))
("rearray" . ("maxima.info-2" 281015 364 "Definições para Arrays"))
("rectform" . ("maxima.info-1" 206499 136 "Definições para Expressões"))
("recttopolar" . ("maxima.info-2" 246840 809 "Definições para Numérico"))
("recttopolar <1>" . ("maxima.info-2" 248132 2308 "Definições para Numérico"))
("rediff" . ("maxima.info-3" 101718 115 "Definições para itensor"))
("reduce_consts" . ("maxima.info-5" 289343 1442 "Definições para simplification"))
("reduce_order" . ("maxima.info-6" 1179 1800 "Definições para solve_rec"))
("refcheck" . ("maxima.info-4" 249958 221 "Definições para Depuração"))
("rem" . ("maxima.info-4" 21938 109 "Definições para Opções Diversas"))
("remainder" . ("maxima.info-2" 69234 348 "Definições para Polinómios"))
("remainder <1>" . ("maxima.info-2" 69235 347 "Definições para Polinómios"))
("remarray" . ("maxima.info-2" 281380 557 "Definições para Arrays"))
("remarray <1>" . ("maxima.info-2" 281381 556 "Definições para Arrays"))
("rembox" . ("maxima.info-1" 206636 3113 "Definições para Expressões"))
("rembox <1>" . ("maxima.info-1" 206637 3112 "Definições para Expressões"))
("rembox <2>" . ("maxima.info-1" 206677 3072 "Definições para Expressões"))
("remcomps" . ("maxima.info-3" 84185 131 "Definições para itensor"))
("remcon" . ("maxima.info-3" 79201 253 "Definições para itensor"))
("remcon <1>" . ("maxima.info-3" 79202 252 "Definições para itensor"))
("remcoord" . ("maxima.info-3" 106228 285 "Definições para itensor"))
("remcoord <1>" . ("maxima.info-3" 106229 284 "Definições para itensor"))
("remfun" . ("maxima.info-2" 260551 327 "Definições para Séries de Fourier"))
("remfun <1>" . ("maxima.info-2" 260552 326 "Definições para Séries de Fourier"))
("remfunction" . ("maxima.info-1" 67766 653 "Definições para Linha de Comandos"))
("remfunction <1>" . ("maxima.info-1" 67767 652 "Definições para Linha de Comandos"))
("remlet" . ("maxima.info-4" 57949 1006 "Definições para Regras e Modelos"))
("remlet <1>" . ("maxima.info-4" 57950 1005 "Definições para Regras e Modelos"))
("remlet <2>" . ("maxima.info-4" 57986 969 "Definições para Regras e Modelos"))
("remlet <3>" . ("maxima.info-4" 58008 947 "Definições para Regras e Modelos"))
("remove" . ("maxima.info-4" 22048 1537 "Definições para Opções Diversas"))
("remove <1>" . ("maxima.info-4" 22049 1536 "Definições para Opções Diversas"))
("remove <2>" . ("maxima.info-4" 22102 1483 "Definições para Opções Diversas"))
("remove <3>" . ("maxima.info-4" 22169 1416 "Definições para Opções Diversas"))
("remove <4>" . ("maxima.info-4" 22206 1379 "Definições para Opções Diversas"))
("rempart" . ("maxima.info-5" 279739 243 "Definições para simplification"))
("remrule" . ("maxima.info-4" 58956 2058 "Definições para Regras e Modelos"))
("remrule <1>" . ("maxima.info-4" 58957 2057 "Definições para Regras e Modelos"))
("remsym" . ("maxima.info-3" 98110 166 "Definições para itensor"))
("remvalue" . ("maxima.info-4" 23586 448 "Definições para Opções Diversas"))
("remvalue <1>" . ("maxima.info-4" 23587 447 "Definições para Opções Diversas"))
("rename" . ("maxima.info-3" 74167 3344 "Definições para itensor"))
("rename <1>" . ("maxima.info-3" 74168 3343 "Definições para itensor"))
("reset" . ("maxima.info-1" 68420 481 "Definições para Linha de Comandos"))
("residue" . ("maxima.info-2" 171343 651 "Definições para Integração"))
("resolvante" . ("maxima.info-3" 288942 7373 "Definições para Simetrias"))
("resolvante_alternee1" . ("maxima.info-3" 296316 411 "Definições para Simetrias"))
("resolvante_bipartite" . ("maxima.info-3" 296728 764 "Definições para Simetrias"))
("resolvante_diedrale" . ("maxima.info-3" 297493 694 "Definições para Simetrias"))
("resolvante_klein" . ("maxima.info-3" 298188 329 "Definições para Simetrias"))
("resolvante_klein3" . ("maxima.info-3" 298518 323 "Definições para Simetrias"))
("resolvante_produit_sym" . ("maxima.info-3" 298842 1070 "Definições para Simetrias"))
("resolvante_unitaire" . ("maxima.info-3" 299913 326 "Definições para Simetrias"))
("resolvante_vierer" . ("maxima.info-3" 300240 317 "Definições para Simetrias"))
("rest" . ("maxima.info-4" 84760 312 "Definições para Listas"))
("rest <1>" . ("maxima.info-4" 84761 311 "Definições para Listas"))
("resultant" . ("maxima.info-2" 69583 1000 "Definições para Polinómios"))
("resultant <1>" . ("maxima.info-2" 69584 999 "Definições para Polinómios"))
("return" . ("maxima.info-4" 233954 149 "Definições para Fluxo de Programa"))
("reveal" . ("maxima.info-1" 309992 2439 "Definições para Entrada e Saída"))
("reverse" . ("maxima.info-4" 85073 203 "Definições para Listas"))
("revert" . ("maxima.info-3" 231928 1850 "Definições para Séries"))
("revert2" . ("maxima.info-3" 231929 1849 "Definições para Séries"))
("rhs" . ("maxima.info-2" 222244 1609 "Definições para Equações"))
("ric" . ("maxima.info-3" 201812 80 "Definições para ctensor"))
("ricci" . ("maxima.info-3" 155952 250 "Definições para ctensor"))
("riem" . ("maxima.info-3" 201308 308 "Definições para ctensor"))
("riemann" . ("maxima.info-3" 157905 1252 "Definições para ctensor"))
("rinvariant" . ("maxima.info-3" 159874 269 "Definições para ctensor"))
("risch" . ("maxima.info-2" 171995 1035 "Definições para Integração"))
("rk" . ("maxima.info-5" 135410 2496 "Análise gráfica de sistemas dinâmicos discretos"))
("rk <1>" . ("maxima.info-5" 135411 2495 "Análise gráfica de sistemas dinâmicos discretos"))
("rmxchar" . ("maxima.info-1" 312432 158 "Definições para Entrada e Saída"))
("rncombine" . ("maxima.info-4" 24035 758 "Definições para Opções Diversas"))
("romberg" . ("maxima.info-5" 260195 5029 "Definições para romberg"))
("romberg <1>" . ("maxima.info-5" 260196 5028 "Definições para romberg"))
("rombergabs" . ("maxima.info-5" 265225 544 "Definições para romberg"))
("rombergit" . ("maxima.info-5" 265770 592 "Definições para romberg"))
("rombergmin" . ("maxima.info-5" 266363 282 "Definições para romberg"))
("rombergtol" . ("maxima.info-5" 266646 547 "Definições para romberg"))
("room" . ("maxima.info-4" 7374 370 "Definições para Ambiente em Tempo de Execução"))
("room <1>" . ("maxima.info-4" 7375 369 "Definições para Ambiente em Tempo de Execução"))
("room <2>" . ("maxima.info-4" 7395 349 "Definições para Ambiente em Tempo de Execução"))
("rootsconmode" . ("maxima.info-2" 223854 181 "Definições para Equações"))
("rootscontract" . ("maxima.info-2" 224036 2663 "Definições para Equações"))
("rootsepsilon" . ("maxima.info-2" 226700 198 "Definições para Equações"))
("row" . ("maxima.info-3" 43641 112 "Definições para Matrizes e Álgebra Linear"))
("rowop" . ("maxima.info-5" 197692 239 "Definições para linearalgebra"))
("rowswap" . ("maxima.info-5" 198555 166 "Definições para linearalgebra"))
("rreduce" . ("maxima.info-4" 130656 1544 "Definições para Conjuntos"))
("rreduce <1>" . ("maxima.info-4" 130657 1543 "Definições para Conjuntos"))
("run_testsuite" . ("maxima.info-1" 18353 1172 "Definições para Detecção e Relato de Erros"))
("run_testsuite <1>" . ("maxima.info-1" 18354 1171 "Definições para Detecção e Relato de Erros"))
("run_testsuite <2>" . ("maxima.info-1" 18383 1142 "Definições para Detecção e Relato de Erros"))
("run_testsuite <3>" . ("maxima.info-1" 18421 1104 "Definições para Detecção e Relato de Erros"))
("save" . ("maxima.info-1" 312591 3527 "Definições para Entrada e Saída"))
("save <1>" . ("maxima.info-1" 312592 3526 "Definições para Entrada e Saída"))
("save <2>" . ("maxima.info-1" 312657 3461 "Definições para Entrada e Saída"))
("save <3>" . ("maxima.info-1" 312719 3399 "Definições para Entrada e Saída"))
("save <4>" . ("maxima.info-1" 312761 3357 "Definições para Entrada e Saída"))
("save <5>" . ("maxima.info-1" 312815 3303 "Definições para Entrada e Saída"))
("savedef" . ("maxima.info-1" 316119 395 "Definições para Entrada e Saída"))
("savefactors" . ("maxima.info-2" 70584 343 "Definições para Polinómios"))
("scalarmatrixp" . ("maxima.info-3" 43754 508 "Definições para Matrizes e Álgebra Linear"))
("scalarp" . ("maxima.info-4" 24794 251 "Definições para Opções Diversas"))
("scaled_bessel_i" . ("maxima.info-2" 104631 488 "Definições para Funções Especiais"))
("scaled_bessel_i0" . ("maxima.info-2" 105120 76 "Definições para Funções Especiais"))
("scaled_bessel_i1" . ("maxima.info-2" 105197 76 "Definições para Funções Especiais"))
("scalefactors" . ("maxima.info-3" 44263 1040 "Definições para Matrizes e Álgebra Linear"))
("scanmap" . ("maxima.info-4" 234104 1655 "Definições para Fluxo de Programa"))
("scanmap <1>" . ("maxima.info-4" 234105 1654 "Definições para Fluxo de Programa"))
("schur2comp" . ("maxima.info-3" 273521 648 "Definições para Simetrias"))
("sconc" . ("maxima.info-6" 65506 427 "Definições para sequências de caracteres"))
("sconcat" . ("maxima.info-1" 280668 384 "Definições para Entrada e Saída"))
("scopy" . ("maxima.info-6" 65934 118 "Definições para sequências de caracteres"))
("scsimp" . ("maxima.info-1" 233822 427 "Definições para Simplificação"))
("scurvature" . ("maxima.info-3" 156741 161 "Definições para ctensor"))
("sdowncase" . ("maxima.info-6" 66053 247 "Definições para sequências de caracteres"))
("sdowncase <1>" . ("maxima.info-6" 66054 246 "Definições para sequências de caracteres"))
("sdowncase <2>" . ("maxima.info-6" 66092 208 "Definições para sequências de caracteres"))
("sec" . ("maxima.info-2" 90244 38 "Definições para Trigonometria"))
("sech" . ("maxima.info-2" 90283 51 "Definições para Trigonometria"))
("second" . ("maxima.info-4" 85277 128 "Definições para Listas"))
("sequal" . ("maxima.info-6" 66301 183 "Definições para sequências de caracteres"))
("sequalignore" . ("maxima.info-6" 66485 116 "Definições para sequências de caracteres"))
("set_partitions" . ("maxima.info-4" 134894 1764 "Definições para Conjuntos"))
("set_partitions <1>" . ("maxima.info-4" 134895 1763 "Definições para Conjuntos"))
("set_plot_option" . ("maxima.info-1" 262909 2415 "Definições para Criação de Gráficos"))
("set_random_state" . ("maxima.info-1" 119885 146 "Operadores Geral"))
("set_up_dot_simplifications" . ("maxima.info-3" 54698 880 "Definições para Funções Afins"))
("set_up_dot_simplifications <1>" . ("maxima.info-3" 54699 879 "Definições para Funções Afins"))
("setcheck" . ("maxima.info-4" 250180 1305 "Definições para Depuração"))
("setcheckbreak" . ("maxima.info-4" 251486 515 "Definições para Depuração"))
("setdifference" . ("maxima.info-4" 132201 872 "Definições para Conjuntos"))
("setelmx" . ("maxima.info-3" 45304 226 "Definições para Matrizes e Álgebra Linear"))
("setequalp" . ("maxima.info-4" 133074 631 "Definições para Conjuntos"))
("setify" . ("maxima.info-4" 133706 584 "Definições para Conjuntos"))
("setp" . ("maxima.info-4" 134291 602 "Definições para Conjuntos"))
("setunits" . ("maxima.info-6" 82392 5024 "Definições para Units"))
("setup_autoload" . ("maxima.info-4" 25046 1393 "Definições para Opções Diversas"))
("setval" . ("maxima.info-4" 252002 281 "Definições para Depuração"))
("seventh" . ("maxima.info-4" 85406 128 "Definições para Listas"))
("sexplode" . ("maxima.info-6" 66602 92 "Definições para sequências de caracteres"))
("sf" . ("maxima.info-3" 215824 281 "Definições para o Pacote atensor"))
("show" . ("maxima.info-1" 316515 278 "Definições para Entrada e Saída"))
("showcomps" . ("maxima.info-3" 84317 2571 "Definições para itensor"))
("showratvars" . ("maxima.info-1" 316794 158 "Definições para Entrada e Saída"))
("showtime" . ("maxima.info-1" 68902 374 "Definições para Linha de Comandos"))
("sign" . ("maxima.info-1" 124996 385 "Operadores Geral"))
("signum" . ("maxima.info-1" 125382 325 "Operadores Geral"))
("similaritytransform" . ("maxima.info-3" 45531 1208 "Definições para Matrizes e Álgebra Linear"))
("simple_linear_regression" . ("maxima.info-6" 40725 4252 "Definições para stats"))
("simple_linear_regression <1>" . ("maxima.info-6" 40726 4251 "Definições para stats"))
("simplified_output" . ("maxima.info-6" 108756 195 "Definições para zeilberger"))
("simplify_products" . ("maxima.info-6" 2980 208 "Definições para solve_rec"))
("simplify_sum" . ("maxima.info-6" 3189 1077 "Definições para solve_rec"))
("simplode" . ("maxima.info-6" 66695 701 "Definições para sequências de caracteres"))
("simplode <1>" . ("maxima.info-6" 66696 700 "Definições para sequências de caracteres"))
("simpmetderiv" . ("maxima.info-3" 107625 3108 "Definições para itensor"))
("simpmetderiv <1>" . ("maxima.info-3" 107626 3107 "Definições para itensor"))
("simpsum" . ("maxima.info-1" 234250 408 "Definições para Simplificação"))
("simtran" . ("maxima.info-3" 45532 1207 "Definições para Matrizes e Álgebra Linear"))
("sin" . ("maxima.info-2" 90335 35 "Definições para Trigonometria"))
("sinh" . ("maxima.info-2" 90371 48 "Definições para Trigonometria"))
("sinnpiflag" . ("maxima.info-2" 262071 88 "Definições para Séries de Fourier"))
("sinsert" . ("maxima.info-6" 67397 605 "Definições para sequências de caracteres"))
("sinvertcase" . ("maxima.info-6" 68003 515 "Definições para sequências de caracteres"))
("sinvertcase <1>" . ("maxima.info-6" 68004 514 "Definições para sequências de caracteres"))
("sinvertcase <2>" . ("maxima.info-6" 68044 474 "Definições para sequências de caracteres"))
("sixth" . ("maxima.info-4" 85535 125 "Definições para Listas"))
("skewness" . ("maxima.info-4" 295408 910 "Definições para estatística descritiva"))
("skewness <1>" . ("maxima.info-4" 295409 909 "Definições para estatística descritiva"))
("skewness_bernoulli" . ("maxima.info-5" 115649 710 "Definições para distribuições discretas"))
("skewness_beta" . ("maxima.info-5" 81435 204 "Definições para distribuições contínuas"))
("skewness_binomial" . ("maxima.info-5" 107841 236 "Definições para distribuições discretas"))
("skewness_chi2" . ("maxima.info-5" 59631 785 "Definições para distribuições contínuas"))
("skewness_continuous_uniform" . ("maxima.info-5" 84664 230 "Definições para distribuições contínuas"))
("skewness_discrete_uniform" . ("maxima.info-5" 122111 251 "Definições para distribuições discretas"))
("skewness_exp" . ("maxima.info-5" 70591 690 "Definições para distribuições contínuas"))
("skewness_f" . ("maxima.info-5" 64397 204 "Definições para distribuições contínuas"))
("skewness_gamma" . ("maxima.info-5" 77897 206 "Definições para distribuições contínuas"))
("skewness_geometric" . ("maxima.info-5" 118864 208 "Definições para distribuições discretas"))
("skewness_gumbel" . ("maxima.info-5" 104493 565 "Definições para distribuições contínuas"))
("skewness_hypergeometric" . ("maxima.info-5" 124961 284 "Definições para distribuições discretas"))
("skewness_laplace" . ("maxima.info-5" 100994 208 "Definições para distribuições contínuas"))
("skewness_logistic" . ("maxima.info-5" 86982 211 "Definições para distribuições contínuas"))
("skewness_lognormal" . ("maxima.info-5" 75090 212 "Definições para distribuições contínuas"))
("skewness_negative_binomial" . ("maxima.info-5" 128995 254 "Definições para distribuições discretas"))
("skewness_normal" . ("maxima.info-5" 49669 229 "Definições para distribuições contínuas"))
("skewness_pareto" . ("maxima.info-5" 89170 210 "Definições para distribuições contínuas"))
("skewness_poisson" . ("maxima.info-5" 111191 202 "Definições para distribuições discretas"))
("skewness_rayleigh" . ("maxima.info-5" 97191 1039 "Definições para distribuições contínuas"))
("skewness_student_t" . ("maxima.info-5" 53213 233 "Definições para distribuições contínuas"))
("skewness_weibull" . ("maxima.info-5" 91357 210 "Definições para distribuições contínuas"))
("slength" . ("maxima.info-6" 68519 88 "Definições para sequências de caracteres"))
("smake" . ("maxima.info-6" 68608 237 "Definições para sequências de caracteres"))
("smismatch" . ("maxima.info-6" 68846 565 "Definições para sequências de caracteres"))
("smismatch <1>" . ("maxima.info-6" 68847 564 "Definições para sequências de caracteres"))
("solve" . ("maxima.info-2" 226899 6723 "Definições para Equações"))
("solve <1>" . ("maxima.info-2" 226900 6722 "Definições para Equações"))
("solve <2>" . ("maxima.info-2" 226932 6690 "Definições para Equações"))
("solve_inconsistent_error" . ("maxima.info-2" 235113 722 "Definições para Equações"))
("solve_rec" . ("maxima.info-6" 4267 3029 "Definições para solve_rec"))
("solve_rec_rat" . ("maxima.info-6" 7297 879 "Definições para solve_rec"))
("solvedecomposes" . ("maxima.info-2" 233623 183 "Definições para Equações"))
("solveexplicit" . ("maxima.info-2" 233807 228 "Definições para Equações"))
("solvefactors" . ("maxima.info-2" 234036 250 "Definições para Equações"))
("solvenullwarn" . ("maxima.info-2" 234287 307 "Definições para Equações"))
("solveradcan" . ("maxima.info-2" 234595 250 "Definições para Equações"))
("solvetrigwarn" . ("maxima.info-2" 234846 266 "Definições para Equações"))
("some" . ("maxima.info-4" 136659 3034 "Definições para Conjuntos"))
("some <1>" . ("maxima.info-4" 136660 3033 "Definições para Conjuntos"))
("somrac" . ("maxima.info-3" 288658 247 "Definições para Simetrias"))
("sort" . ("maxima.info-1" 125708 2420 "Operadores Geral"))
("sort <1>" . ("maxima.info-1" 125709 2419 "Operadores Geral"))
("space" . ("maxima.info-6" 63372 58 "Definições para caracteres"))
("sparse" . ("maxima.info-3" 46740 209 "Definições para Matrizes e Álgebra Linear"))
("specint" . ("maxima.info-2" 111995 1274 "Definições para Funções Especiais"))
("spherical_bessel_j" . ("maxima.info-5" 247376 186 "Definições para polinómios ortogonais"))
("spherical_bessel_y" . ("maxima.info-5" 247563 185 "Definições para polinómios ortogonais"))
("spherical_hankel1" . ("maxima.info-5" 247749 159 "Definições para polinómios ortogonais"))
("spherical_hankel2" . ("maxima.info-5" 247909 158 "Definições para polinómios ortogonais"))
("spherical_harmonic" . ("maxima.info-5" 248068 120 "Definições para polinómios ortogonais"))
("splice" . ("maxima.info-4" 162923 1701 "Macros"))
("split" . ("maxima.info-6" 69412 915 "Definições para sequências de caracteres"))
("split <1>" . ("maxima.info-6" 69413 914 "Definições para sequências de caracteres"))
("split <2>" . ("maxima.info-6" 69447 880 "Definições para sequências de caracteres"))
("sposition" . ("maxima.info-6" 70328 305 "Definições para sequências de caracteres"))
("sprint" . ("maxima.info-6" 59378 810 "Definições para entrada e saída"))
("sqfr" . ("maxima.info-2" 70928 728 "Definições para Polinómios"))
("sqrt" . ("maxima.info-1" 128129 360 "Operadores Geral"))
("sqrtdenest" . ("maxima.info-5" 291901 1098 "Definições para simplification"))
("sqrtdispflag" . ("maxima.info-1" 128490 165 "Operadores Geral"))
("sremove" . ("maxima.info-6" 70634 897 "Definições para sequências de caracteres"))
("sremove <1>" . ("maxima.info-6" 70635 896 "Definições para sequências de caracteres"))
("sremove <2>" . ("maxima.info-6" 70678 853 "Definições para sequências de caracteres"))
("sremove <3>" . ("maxima.info-6" 70729 802 "Definições para sequências de caracteres"))
("sremovefirst" . ("maxima.info-6" 71532 356 "Definições para sequências de caracteres"))
("sremovefirst <1>" . ("maxima.info-6" 71533 355 "Definições para sequências de caracteres"))
("sremovefirst <2>" . ("maxima.info-6" 71581 307 "Definições para sequências de caracteres"))
("sremovefirst <3>" . ("maxima.info-6" 71637 251 "Definições para sequências de caracteres"))
("sreverse" . ("maxima.info-6" 71889 142 "Definições para sequências de caracteres"))
("ssearch" . ("maxima.info-6" 72032 740 "Definições para sequências de caracteres"))
("ssearch <1>" . ("maxima.info-6" 72033 739 "Definições para sequências de caracteres"))
("ssearch <2>" . ("maxima.info-6" 72076 696 "Definições para sequências de caracteres"))
("ssearch <3>" . ("maxima.info-6" 72127 645 "Definições para sequências de caracteres"))
("ssort" . ("maxima.info-6" 72773 755 "Definições para sequências de caracteres"))
("ssort <1>" . ("maxima.info-6" 72774 754 "Definições para sequências de caracteres"))
("sstatus" . ("maxima.info-1" 69277 310 "Definições para Linha de Comandos"))
("ssubst" . ("maxima.info-6" 73529 1139 "Definições para sequências de caracteres"))
("ssubst <1>" . ("maxima.info-6" 73530 1138 "Definições para sequências de caracteres"))
("ssubst <2>" . ("maxima.info-6" 73583 1085 "Definições para sequências de caracteres"))
("ssubst <3>" . ("maxima.info-6" 73644 1024 "Definições para sequências de caracteres"))
("ssubstfirst" . ("maxima.info-6" 74669 429 "Definições para sequências de caracteres"))
("ssubstfirst <1>" . ("maxima.info-6" 74670 428 "Definições para sequências de caracteres"))
("ssubstfirst <2>" . ("maxima.info-6" 74728 370 "Definições para sequências de caracteres"))
("ssubstfirst <3>" . ("maxima.info-6" 74860 238 "Definições para sequências de caracteres"))
("staircase" . ("maxima.info-5" 137907 4419 "Análise gráfica de sistemas dinâmicos discretos"))
("stardisp" . ("maxima.info-1" 316953 169 "Definições para Entrada e Saída"))
("stats_numer" . ("maxima.info-6" 16181 297 "Definições para stats"))
("status" . ("maxima.info-4" 7745 1367 "Definições para Ambiente em Tempo de Execução"))
("status <1>" . ("maxima.info-4" 7746 1366 "Definições para Ambiente em Tempo de Execução"))
("status <2>" . ("maxima.info-4" 7775 1337 "Definições para Ambiente em Tempo de Execução"))
("std" . ("maxima.info-4" 282871 642 "Definições para estatística descritiva"))
("std <1>" . ("maxima.info-4" 282872 641 "Definições para estatística descritiva"))
("std1" . ("maxima.info-4" 283514 654 "Definições para estatística descritiva"))
("std1 <1>" . ("maxima.info-4" 283515 653 "Definições para estatística descritiva"))
("std_bernoulli" . ("maxima.info-5" 115080 568 "Definições para distribuições discretas"))
("std_beta" . ("maxima.info-5" 81247 187 "Definições para distribuições contínuas"))
("std_binomial" . ("maxima.info-5" 107621 219 "Definições para distribuições discretas"))
("std_chi2" . ("maxima.info-5" 58982 648 "Definições para distribuições contínuas"))
("std_continuous_uniform" . ("maxima.info-5" 84450 213 "Definições para distribuições contínuas"))
("std_discrete_uniform" . ("maxima.info-5" 121876 234 "Definições para distribuições discretas"))
("std_exp" . ("maxima.info-5" 69857 733 "Definições para distribuições contínuas"))
("std_f" . ("maxima.info-5" 64209 187 "Definições para distribuições contínuas"))
("std_gamma" . ("maxima.info-5" 77707 189 "Definições para distribuições contínuas"))
("std_geometric" . ("maxima.info-5" 118672 191 "Definições para distribuições discretas"))
("std_gumbel" . ("maxima.info-5" 104303 189 "Definições para distribuições contínuas"))
("std_hypergeometric" . ("maxima.info-5" 124693 267 "Definições para distribuições discretas"))
("std_laplace" . ("maxima.info-5" 100802 191 "Definições para distribuições contínuas"))
("std_logistic" . ("maxima.info-5" 86787 194 "Definições para distribuições contínuas"))
("std_lognormal" . ("maxima.info-5" 74894 195 "Definições para distribuições contínuas"))
("std_negative_binomial" . ("maxima.info-5" 128757 237 "Definições para distribuições discretas"))
("std_normal" . ("maxima.info-5" 49466 202 "Definições para distribuições contínuas"))
("std_pareto" . ("maxima.info-5" 88976 193 "Definições para distribuições contínuas"))
("std_poisson" . ("maxima.info-5" 111005 185 "Definições para distribuições discretas"))
("std_rayleigh" . ("maxima.info-5" 96343 847 "Definições para distribuições contínuas"))
("std_student_t" . ("maxima.info-5" 53020 192 "Definições para distribuições contínuas"))
("std_weibull" . ("maxima.info-5" 91163 193 "Definições para distribuições contínuas"))
("stirling" . ("maxima.info-6" 46477 1810 "Definições para stirling"))
("stirling1" . ("maxima.info-4" 139694 2029 "Definições para Conjuntos"))
("stirling2" . ("maxima.info-4" 141724 2391 "Definições para Conjuntos"))
("strim" . ("maxima.info-6" 75099 420 "Definições para sequências de caracteres"))
("striml" . ("maxima.info-6" 75520 141 "Definições para sequências de caracteres"))
("strimr" . ("maxima.info-6" 75662 150 "Definições para sequências de caracteres"))
("string" . ("maxima.info-1" 317123 245 "Definições para Entrada e Saída"))
("stringdisp" . ("maxima.info-1" 317369 785 "Definições para Entrada e Saída"))
("stringout" . ("maxima.info-1" 318155 2321 "Definições para Entrada e Saída"))
("stringout <1>" . ("maxima.info-1" 318156 2320 "Definições para Entrada e Saída"))
("stringout <2>" . ("maxima.info-1" 318226 2250 "Definições para Entrada e Saída"))
("stringout <3>" . ("maxima.info-1" 318273 2203 "Definições para Entrada e Saída"))
("stringout <4>" . ("maxima.info-1" 318315 2161 "Definições para Entrada e Saída"))
("stringp" . ("maxima.info-6" 64151 144 "Definições para sequências de caracteres"))
("sublis" . ("maxima.info-1" 128656 204 "Operadores Geral"))
("sublis_apply_lambda" . ("maxima.info-1" 129179 289 "Operadores Geral"))
("sublist" . ("maxima.info-1" 128861 317 "Operadores Geral"))
("sublist_indices" . ("maxima.info-4" 85661 1004 "Definições para Listas"))
("submatrix" . ("maxima.info-3" 46950 297 "Definições para Matrizes e Álgebra Linear"))
("submatrix <1>" . ("maxima.info-3" 46951 296 "Definições para Matrizes e Álgebra Linear"))
("submatrix <2>" . ("maxima.info-3" 47017 230 "Definições para Matrizes e Álgebra Linear"))
("subsample" . ("maxima.info-4" 273642 6500 "Definições para manipulação da dados"))
("subsample <1>" . ("maxima.info-4" 273643 6499 "Definições para manipulação da dados"))
("subset" . ("maxima.info-4" 144116 622 "Definições para Conjuntos"))
("subsetp" . ("maxima.info-4" 144739 409 "Definições para Conjuntos"))
("subst" . ("maxima.info-1" 129469 1820 "Operadores Geral"))
("substinpart" . ("maxima.info-1" 131290 2466 "Operadores Geral"))
("substpart" . ("maxima.info-1" 133757 1141 "Operadores Geral"))
("substring" . ("maxima.info-6" 75813 668 "Definições para sequências de caracteres"))
("substring <1>" . ("maxima.info-6" 75814 667 "Definições para sequências de caracteres"))
("subvar" . ("maxima.info-2" 281938 697 "Definições para Arrays"))
("subvarp" . ("maxima.info-1" 134899 165 "Operadores Geral"))
("sum" . ("maxima.info-1" 209750 5289 "Definições para Expressões"))
("sumcontract" . ("maxima.info-1" 234659 572 "Definições para Simplificação"))
("sumexpand" . ("maxima.info-1" 235232 966 "Definições para Simplificação"))
("summand_to_rec" . ("maxima.info-6" 8435 1234 "Definições para solve_rec"))
("summand_to_rec <1>" . ("maxima.info-6" 8436 1233 "Definições para solve_rec"))
("sumsplitfact" . ("maxima.info-1" 236199 156 "Definições para Simplificação"))
("sunlisp" . ("maxima.info-6" 63801 192 "Definições para sequências de caracteres"))
("supcase" . ("maxima.info-6" 76482 576 "Definições para sequências de caracteres"))
("supcase <1>" . ("maxima.info-6" 76483 575 "Definições para sequências de caracteres"))
("supcase <2>" . ("maxima.info-6" 76519 539 "Definições para sequências de caracteres"))
("supcontext" . ("maxima.info-2" 17782 261 "Definições para Contextos"))
("supcontext <1>" . ("maxima.info-2" 17783 260 "Definições para Contextos"))
("symbolp" . ("maxima.info-1" 135065 236 "Operadores Geral"))
("symmdifference" . ("maxima.info-4" 145149 1088 "Definições para Conjuntos"))
("symmetric" . ("maxima.info-1" 236356 236 "Definições para Simplificação"))
("symmetricp" . ("maxima.info-3" 182507 100 "Definições para ctensor"))
("system" . ("maxima.info-1" 326942 878 "Definições para Entrada e Saída"))
("tab" . ("maxima.info-6" 63431 49 "Definições para caracteres"))
("take_inference" . ("maxima.info-6" 14096 1881 "Definições para inference_result"))
("take_inference <1>" . ("maxima.info-6" 14097 1880 "Definições para inference_result"))
("take_inference <2>" . ("maxima.info-6" 14137 1840 "Definições para inference_result"))
("tan" . ("maxima.info-2" 90420 39 "Definições para Trigonometria"))
("tanh" . ("maxima.info-2" 90460 52 "Definições para Trigonometria"))
("taylor" . ("maxima.info-3" 233779 7982 "Definições para Séries"))
("taylor <1>" . ("maxima.info-3" 233780 7981 "Definições para Séries"))
("taylor <2>" . ("maxima.info-3" 233823 7938 "Definições para Séries"))
("taylor <3>" . ("maxima.info-3" 233882 7879 "Definições para Séries"))
("taylor <4>" . ("maxima.info-3" 234005 7756 "Definições para Séries"))
("taylor_logexpand" . ("maxima.info-3" 243016 699 "Definições para Séries"))
("taylor_order_coefficients" . ("maxima.info-3" 243716 301 "Definições para Séries"))
("taylor_simplifier" . ("maxima.info-3" 244018 132 "Definições para Séries"))
("taylor_truncate_polynomials" . ("maxima.info-3" 244151 321 "Definições para Séries"))
("taylordepth" . ("maxima.info-3" 241762 238 "Definições para Séries"))
("taylorinfo" . ("maxima.info-3" 242001 897 "Definições para Séries"))
("taylorp" . ("maxima.info-3" 242899 116 "Definições para Séries"))
("taytorat" . ("maxima.info-3" 244473 198 "Definições para Séries"))
("tcl_output" . ("maxima.info-1" 307615 1199 "Definições para Entrada e Saída"))
("tcl_output <1>" . ("maxima.info-1" 307616 1198 "Definições para Entrada e Saída"))
("tcl_output <2>" . ("maxima.info-1" 307662 1152 "Definições para Entrada e Saída"))
("tcontract" . ("maxima.info-3" 276313 212 "Definições para Simetrias"))
("tcontract <1>" . ("maxima.info-3" 300894 348 "Definições para Simetrias"))
("tellrat" . ("maxima.info-2" 71657 2299 "Definições para Polinómios"))
("tellrat <1>" . ("maxima.info-2" 71658 2298 "Definições para Polinómios"))
("tellsimp" . ("maxima.info-4" 61015 2469 "Definições para Regras e Modelos"))
("tellsimpafter" . ("maxima.info-4" 63485 9923 "Definições para Regras e Modelos"))
("tensorkill" . ("maxima.info-3" 203721 200 "Definições para ctensor"))
("tentex" . ("maxima.info-3" 138043 1073 "Definições para itensor"))
("tenth" . ("maxima.info-4" 86666 126 "Definições para Listas"))
("test_mean" . ("maxima.info-6" 16479 4601 "Definições para stats"))
("test_mean <1>" . ("maxima.info-6" 16480 4600 "Definições para stats"))
("test_means_difference" . ("maxima.info-6" 21081 5079 "Definições para stats"))
("test_means_difference <1>" . ("maxima.info-6" 21082 5078 "Definições para stats"))
("test_normality" . ("maxima.info-6" 39645 1079 "Definições para stats"))
("test_rank_sum" . ("maxima.info-6" 36841 2803 "Definições para stats"))
("test_rank_sum <1>" . ("maxima.info-6" 36842 2802 "Definições para stats"))
("test_sign" . ("maxima.info-6" 31651 1995 "Definições para stats"))
("test_sign <1>" . ("maxima.info-6" 31652 1994 "Definições para stats"))
("test_signed_rank" . ("maxima.info-6" 33647 3193 "Definições para stats"))
("test_signed_rank <1>" . ("maxima.info-6" 33648 3192 "Definições para stats"))
("test_variance" . ("maxima.info-6" 26161 2645 "Definições para stats"))
("test_variance <1>" . ("maxima.info-6" 26162 2644 "Definições para stats"))
("test_variance_ratio" . ("maxima.info-6" 28807 2843 "Definições para stats"))
("test_variance_ratio <1>" . ("maxima.info-6" 28808 2842 "Definições para stats"))
("testsuite_files" . ("maxima.info-1" 19526 708 "Definições para Detecção e Relato de Erros"))
("tex" . ("maxima.info-1" 320477 2331 "Definições para Entrada e Saída"))
("tex <1>" . ("maxima.info-1" 320478 2330 "Definições para Entrada e Saída"))
("tex <2>" . ("maxima.info-1" 320503 2305 "Definições para Entrada e Saída"))
("tex <3>" . ("maxima.info-1" 320530 2278 "Definições para Entrada e Saída"))
("texput" . ("maxima.info-1" 322809 4132 "Definições para Entrada e Saída"))
("texput <1>" . ("maxima.info-1" 322810 4131 "Definições para Entrada e Saída"))
("texput <2>" . ("maxima.info-1" 322840 4101 "Definições para Entrada e Saída"))
("texput <3>" . ("maxima.info-1" 322887 4054 "Definições para Entrada e Saída"))
("third" . ("maxima.info-4" 86793 130 "Definições para Listas"))
("throw" . ("maxima.info-4" 235760 183 "Definições para Fluxo de Programa"))
("time" . ("maxima.info-4" 9113 565 "Definições para Ambiente em Tempo de Execução"))
("timedate" . ("maxima.info-4" 9679 607 "Definições para Ambiente em Tempo de Execução"))
("timer" . ("maxima.info-4" 252284 1134 "Definições para Depuração"))
("timer <1>" . ("maxima.info-4" 252285 1133 "Definições para Depuração"))
("timer_devalue" . ("maxima.info-4" 254204 490 "Definições para Depuração"))
("timer_info" . ("maxima.info-4" 254695 838 "Definições para Depuração"))
("timer_info <1>" . ("maxima.info-4" 254696 837 "Definições para Depuração"))
("tldefint" . ("maxima.info-2" 173031 116 "Definições para Integração"))
("tlimit" . ("maxima.info-2" 124193 176 "Definições para Limites"))
("tlimit <1>" . ("maxima.info-2" 124194 175 "Definições para Limites"))
("tlimit <2>" . ("maxima.info-2" 124241 128 "Definições para Limites"))
("tlimswitch" . ("maxima.info-2" 124370 171 "Definições para Limites"))
("to_lisp" . ("maxima.info-1" 69588 111 "Definições para Linha de Comandos"))
("todd_coxeter" . ("maxima.info-4" 369 1757 "Definições para Grupos"))
("todd_coxeter <1>" . ("maxima.info-4" 370 1756 "Definições para Grupos"))
("toeplitz" . ("maxima.info-5" 198722 864 "Definições para linearalgebra"))
("toeplitz <1>" . ("maxima.info-5" 198723 863 "Definições para linearalgebra"))
("tokens" . ("maxima.info-6" 77059 907 "Definições para sequências de caracteres"))
("tokens <1>" . ("maxima.info-6" 77060 906 "Definições para sequências de caracteres"))
("totaldisrep" . ("maxima.info-2" 73957 440 "Definições para Polinómios"))
("totalfourier" . ("maxima.info-2" 262789 126 "Definições para Séries de Fourier"))
("totient" . ("maxima.info-3" 263069 131 "Definições para Teoria dos Números"))
("tpartpol" . ("maxima.info-3" 276526 212 "Definições para Simetrias"))
("tpartpol <1>" . ("maxima.info-3" 301243 348 "Definições para Simetrias"))
("tr" . ("maxima.info-3" 203272 123 "Definições para ctensor"))
("tr_array_as_ref" . ("maxima.info-4" 207384 435 "Definições para Definição de Função"))
("tr_bound_function_applyp" . ("maxima.info-4" 207869 400 "Definições para Definição de Função"))
("tr_file_tty_messagesp" . ("maxima.info-4" 208316 344 "Definições para Definição de Função"))
("tr_float_can_branch_complex" . ("maxima.info-4" 208713 579 "Definições para Definição de Função"))
("tr_function_call_default" . ("maxima.info-4" 209342 725 "Definições para Definição de Função"))
("tr_numer" . ("maxima.info-4" 210101 158 "Definições para Definição de Função"))
("tr_optimize_max_loop" . ("maxima.info-4" 210305 285 "Definições para Definição de Função"))
("tr_semicompile" . ("maxima.info-4" 210630 219 "Definições para Definição de Função"))
("tr_state_vars" . ("maxima.info-4" 210890 525 "Definições para Definição de Função"))
("tr_warn_bad_function_calls" . ("maxima.info-4" 211606 221 "Definições para Definição de Função"))
("tr_warn_fexpr" . ("maxima.info-4" 211866 232 "Definições para Definição de Função"))
("tr_warn_meval" . ("maxima.info-4" 212128 157 "Definições para Definição de Função"))
("tr_warn_mode" . ("maxima.info-4" 212314 131 "Definições para Definição de Função"))
("tr_warn_undeclared" . ("maxima.info-4" 212489 121 "Definições para Definição de Função"))
("tr_warn_undefined_variable" . ("maxima.info-4" 212662 109 "Definições para Definição de Função"))
("tr_warnings_get" . ("maxima.info-4" 211448 106 "Definições para Definição de Função"))
("trace" . ("maxima.info-4" 255534 1066 "Definições para Depuração"))
("trace <1>" . ("maxima.info-4" 255535 1065 "Definições para Depuração"))
("trace_options" . ("maxima.info-4" 256601 2337 "Definições para Depuração"))
("trace_options <1>" . ("maxima.info-4" 256602 2336 "Definições para Depuração"))
("tracematrix" . ("maxima.info-5" 280491 185 "Definições para simplification"))
("transcompile" . ("maxima.info-4" 201897 250 "Definições para Definição de Função"))
("translate" . ("maxima.info-4" 202191 2420 "Definições para Definição de Função"))
("translate <1>" . ("maxima.info-4" 202223 2388 "Definições para Definição de Função"))
("translate <2>" . ("maxima.info-4" 202251 2360 "Definições para Definição de Função"))
("translate_file" . ("maxima.info-4" 204664 2430 "Definições para Definição de Função"))
("translate_file <1>" . ("maxima.info-4" 204736 2358 "Definições para Definição de Função"))
("transpose" . ("maxima.info-3" 47248 401 "Definições para Matrizes e Álgebra Linear"))
("transrun" . ("maxima.info-4" 207128 215 "Definições para Definição de Função"))
("tree_reduce" . ("maxima.info-4" 146238 1407 "Definições para Conjuntos"))
("tree_reduce <1>" . ("maxima.info-4" 146239 1406 "Definições para Conjuntos"))
("treillis" . ("maxima.info-3" 285490 227 "Definições para Simetrias"))
("treillis <1>" . ("maxima.info-3" 301592 228 "Definições para Simetrias"))
("treinat" . ("maxima.info-3" 285718 597 "Definições para Simetrias"))
("treinat <1>" . ("maxima.info-3" 301821 540 "Definições para Simetrias"))
("triangularize" . ("maxima.info-3" 47650 1055 "Definições para Matrizes e Álgebra Linear"))
("trigexpand" . ("maxima.info-2" 90513 1494 "Definições para Trigonometria"))
("trigexpandplus" . ("maxima.info-2" 92008 347 "Definições para Trigonometria"))
("trigexpandtimes" . ("maxima.info-2" 92356 351 "Definições para Trigonometria"))
("triginverses" . ("maxima.info-2" 92708 488 "Definições para Trigonometria"))
("trigrat" . ("maxima.info-2" 94888 2532 "Definições para Trigonometria"))
("trigreduce" . ("maxima.info-2" 93197 1030 "Definições para Trigonometria"))
("trigreduce <1>" . ("maxima.info-2" 93198 1029 "Definições para Trigonometria"))
("trigsign" . ("maxima.info-2" 94228 266 "Definições para Trigonometria"))
("trigsimp" . ("maxima.info-2" 94495 392 "Definições para Trigonometria"))
("trivial_solutions" . ("maxima.info-6" 109593 234 "Definições para zeilberger"))
("true" . ("maxima.info-2" 78085 139 "Definições para Constantes"))
("trunc" . ("maxima.info-3" 244672 576 "Definições para Séries"))
("ttyoff" . ("maxima.info-1" 327821 365 "Definições para Entrada e Saída"))
("ueivects" . ("maxima.info-3" 48707 1263 "Definições para Matrizes e Álgebra Linear"))
("ufg" . ("maxima.info-3" 201141 166 "Definições para ctensor"))
("uforget" . ("maxima.info-6" 87417 1376 "Definições para Units"))
("ug" . ("maxima.info-3" 202158 85 "Definições para ctensor"))
("ultraspherical" . ("maxima.info-5" 248474 213 "Definições para polinómios ortogonais"))
("undiff" . ("maxima.info-3" 101834 512 "Definições para itensor"))
("union" . ("maxima.info-4" 147646 981 "Definições para Conjuntos"))
("unit_step" . ("maxima.info-5" 248189 284 "Definições para polinómios ortogonais"))
("uniteigenvectors" . ("maxima.info-3" 48706 1264 "Definições para Matrizes e Álgebra Linear"))
("unitvector" . ("maxima.info-3" 49971 227 "Definições para Matrizes e Álgebra Linear"))
("unknown" . ("maxima.info-1" 236593 154 "Definições para Simplificação"))
("unorder" . ("maxima.info-1" 135302 828 "Operadores Geral"))
("unsum" . ("maxima.info-3" 245249 1229 "Definições para Séries"))
("untellrat" . ("maxima.info-2" 74398 101 "Definições para Polinómios"))
("untimer" . ("maxima.info-4" 253419 784 "Definições para Depuração"))
("untimer <1>" . ("maxima.info-4" 253420 783 "Definições para Depuração"))
("untrace" . ("maxima.info-4" 258939 387 "Definições para Depuração"))
("untrace <1>" . ("maxima.info-4" 258940 386 "Definições para Depuração"))
("uppercasep" . ("maxima.info-6" 63481 106 "Definições para caracteres"))
("uric" . ("maxima.info-3" 201893 91 "Definições para ctensor"))
("uricci" . ("maxima.info-3" 156203 537 "Definições para ctensor"))
("uriem" . ("maxima.info-3" 201710 101 "Definições para ctensor"))
("uriemann" . ("maxima.info-3" 159672 201 "Definições para ctensor"))
("use_fast_arrays" . ("maxima.info-2" 282636 1533 "Definições para Arrays"))
("usersetunits" . ("maxima.info-6" 92384 8863 "Definições para Units"))
("uvect" . ("maxima.info-3" 49972 226 "Definições para Matrizes e Álgebra Linear"))
("values" . ("maxima.info-1" 69700 243 "Definições para Linha de Comandos"))
("vandermonde_matrix" . ("maxima.info-5" 199587 160 "Definições para linearalgebra"))
("var" . ("maxima.info-4" 281354 628 "Definições para estatística descritiva"))
("var <1>" . ("maxima.info-4" 281355 627 "Definições para estatística descritiva"))
("var1" . ("maxima.info-4" 281983 887 "Definições para estatística descritiva"))
("var1 <1>" . ("maxima.info-4" 281984 886 "Definições para estatística descritiva"))
("var_bernoulli" . ("maxima.info-5" 114524 555 "Definições para distribuições discretas"))
("var_beta" . ("maxima.info-5" 81069 177 "Definições para distribuições contínuas"))
("var_binomial" . ("maxima.info-5" 107405 215 "Definições para distribuições discretas"))
("var_chi2" . ("maxima.info-5" 58347 634 "Definições para distribuições contínuas"))
("var_continuous_uniform" . ("maxima.info-5" 84240 209 "Definições para distribuições contínuas"))
("var_discrete_uniform" . ("maxima.info-5" 121645 230 "Definições para distribuições discretas"))
("var_exp" . ("maxima.info-5" 69089 767 "Definições para distribuições contínuas"))
("var_f" . ("maxima.info-5" 64025 183 "Definições para distribuições contínuas"))
("var_gamma" . ("maxima.info-5" 77521 185 "Definições para distribuições contínuas"))
("var_geometric" . ("maxima.info-5" 118484 187 "Definições para distribuições discretas"))
("var_gumbel" . ("maxima.info-5" 104123 179 "Definições para distribuições contínuas"))
("var_hypergeometric" . ("maxima.info-5" 124424 268 "Definições para distribuições discretas"))
("var_laplace" . ("maxima.info-5" 100614 187 "Definições para distribuições contínuas"))
("var_logistic" . ("maxima.info-5" 86596 190 "Definições para distribuições contínuas"))
("var_lognormal" . ("maxima.info-5" 74702 191 "Definições para distribuições contínuas"))
("var_negative_binomial" . ("maxima.info-5" 128523 233 "Definições para distribuições discretas"))
("var_normal" . ("maxima.info-5" 49265 200 "Definições para distribuições contínuas"))
("var_pareto" . ("maxima.info-5" 88786 189 "Definições para distribuições contínuas"))
("var_poisson" . ("maxima.info-5" 110829 175 "Definições para distribuições discretas"))
("var_rayleigh" . ("maxima.info-5" 95472 870 "Definições para distribuições contínuas"))
("var_student_t" . ("maxima.info-5" 52688 331 "Definições para distribuições contínuas"))
("var_weibull" . ("maxima.info-5" 90973 189 "Definições para distribuições contínuas"))
("vect_cross" . ("maxima.info-3" 51555 240 "Definições para Matrizes e Álgebra Linear"))
("vectorpotential" . ("maxima.info-1" 136131 329 "Operadores Geral"))
("vectorsimp" . ("maxima.info-3" 50199 1355 "Definições para Matrizes e Álgebra Linear"))
("verbify" . ("maxima.info-1" 215733 376 "Definições para Expressões"))
("verbose" . ("maxima.info-3" 246479 150 "Definições para Séries"))
("vers" . ("maxima.info-5" 283545 132 "Definições para simplification"))
("warnings" . ("maxima.info-6" 109146 182 "Definições para zeilberger"))
("weyl" . ("maxima.info-3" 202244 73 "Definições para ctensor"))
("weyl <1>" . ("maxima.info-3" 160144 476 "Definições para ctensor"))
("while" . ("maxima.info-4" 235944 45 "Definições para Fluxo de Programa"))
("with_stdout" . ("maxima.info-1" 328187 1130 "Definições para Entrada e Saída"))
("write_data" . ("maxima.info-5" 218745 925 "Definições para numericalio"))
("write_data <1>" . ("maxima.info-5" 218746 924 "Definições para numericalio"))
("writefile" . ("maxima.info-1" 329318 1298 "Definições para Entrada e Saída"))
("wronskian" . ("maxima.info-5" 279983 507 "Definições para simplification"))
("xreduce" . ("maxima.info-4" 148628 1753 "Definições para Conjuntos"))
("xreduce <1>" . ("maxima.info-4" 148629 1752 "Definições para Conjuntos"))
("xthru" . ("maxima.info-1" 136461 1243 "Operadores Geral"))
("zerobern" . ("maxima.info-3" 263201 182 "Definições para Teoria dos Números"))
("zeroequiv" . ("maxima.info-1" 137705 1130 "Operadores Geral"))
("zerofor" . ("maxima.info-5" 199748 568 "Definições para linearalgebra"))
("zerofor <1>" . ("maxima.info-5" 199749 567 "Definições para linearalgebra"))
("zeromatrix" . ("maxima.info-3" 51796 105 "Definições para Matrizes e Álgebra Linear"))
("zeromatrixp" . ("maxima.info-5" 200317 294 "Definições para linearalgebra"))
("zeta" . ("maxima.info-3" 263384 660 "Definições para Teoria dos Números"))
("zeta%pi" . ("maxima.info-3" 264045 616 "Definições para Teoria dos Números"))
("|" . ("maxima.info-3" 132819 1393 "Definições para itensor"))
("~" . ("maxima.info-3" 131204 1614 "Definições para itensor"))
))
(section-pairs '(
; CONTENT: (<NODE NAME> . (<FILENAME> <BYTE OFFSET> <LENGTH IN CHARACTERS>))
("Análise gráfica de sistemas dinâmicos discretos" . ("maxima.info-5" 131825 10501))
("Comandos Palavra Chave" . ("maxima.info-4" 247301 2493))
("Comentários" . ("maxima.info-1" 265674 1300))
("Compartilhado" . ("maxima.info-4" 11117 644))
("Complexo" . ("maxima.info-1" 140981 553))
("Definições específicas para estatística descritiva de várias variáveis" . ("maxima.info-5" 284 10121))
("Definições para Ajuda" . ("maxima.info-1" 27010 6480))
("Definições para Ambiente em Tempo de Execução" . ("maxima.info-4" 5046 5240))
("Definições para Arrays" . ("maxima.info-2" 263573 20596))
("Definições para Conjuntos" . ("maxima.info-4" 97624 52757))
("Definições para Constantes" . ("maxima.info-2" 74749 3475))
("Definições para Contextos" . ("maxima.info-2" 5065 12978))
("Definições para Criação de Gráficos" . ("maxima.info-1" 237070 28254))
("Definições para Definição de Função" . ("maxima.info-4" 164730 50115))
("Definições para Depuração" . ("maxima.info-4" 249896 9430))
("Definições para Detecção e Relato de Erros" . ("maxima.info-1" 18259 2616))
("Definições para Diferenciação" . ("maxima.info-2" 124811 24297))
("Definições para Entrada e Saída de Dados" . ("maxima.info-1" 267598 63018))
("Definições para Equações" . ("maxima.info-2" 195743 40092))
("Definições para Equações Diferenciais" . ("maxima.info-2" 236835 8041))
("Definições para Expressões" . ("maxima.info-1" 154069 62040))
("Definições para Fluxo de Programa" . ("maxima.info-4" 215527 27317))
("Definições para Funções Afins" . ("maxima.info-3" 53328 5535))
("Definições para Funções Elípticas" . ("maxima.info-2" 117751 2275))
("Definições para Funções Especiais" . ("maxima.info-2" 99415 14128))
("Definições para Grupos" . ("maxima.info-4" 313 1813))
("Definições para Integrais Elípticas" . ("maxima.info-2" 120143 1666))
("Definições para Integração" . ("maxima.info-2" 150469 22678))
("Definições para Limites" . ("maxima.info-2" 122048 2493))
("Definições para Linha de Comandos" . ("maxima.info-1" 43155 26788))
("Definições para Listas" . ("maxima.info-4" 74735 12188))
("Definições para Logaritmos" . ("maxima.info-2" 78477 8469))
("Definições para Matrizes e Álgebra Linear" . ("maxima.info-3" 3972 49067))
("Definições para Numérico" . ("maxima.info-2" 246053 14122))
("Definições para Opções Diversas" . ("maxima.info-4" 11866 14573))
("Definições para Polinómios" . ("maxima.info-2" 21536 52963))
("Definições para QUADPACK" . ("maxima.info-2" 177340 18153))
("Definições para Regras e Modelos" . ("maxima.info-4" 27869 45711))
("Definições para Simetrias" . ("maxima.info-3" 264910 37451))
("Definições para Simplificação" . ("maxima.info-1" 216389 20358))
("Definições para Séries" . ("maxima.info-3" 218491 28138))
("Definições para Séries de Fourier" . ("maxima.info-2" 260286 3050))
("Definições para Teoria dos Números" . ("maxima.info-3" 246932 17729))
("Definições para Trigonometria" . ("maxima.info-2" 88304 9116))
("Definições para Units" . ("maxima.info-6" 82338 20106))
("Definições para augmented_lagrangian" . ("maxima.info-4" 259639 2445))
("Definições para bode" . ("maxima.info-4" 262303 3186))
("Definições para caracteres" . ("maxima.info-6" 60350 3237))
("Definições para ctensor" . ("maxima.info-3" 147048 60828))
("Definições para diag" . ("maxima.info-5" 22695 16830))
("Definições para distribuições contínuas" . ("maxima.info-5" 47846 57824))
("Definições para distribuições discretas" . ("maxima.info-5" 105801 25037))
("Definições para distribuições especiais" . ("maxima.info-6" 45086 1100))
("Definições para entrada e saída" . ("maxima.info-6" 53804 6384))
("Definições para estatística descritiva" . ("maxima.info-4" 280352 17756))
("Definições para eval_string" . ("maxima.info-5" 143051 1780))
("Definições para f90" . ("maxima.info-5" 145026 1698))
("Definições para ggf" . ("maxima.info-5" 146915 1747))
("Definições para gráficos estatísticos" . ("maxima.info-5" 10569 11920))
("Definições para impdiff" . ("maxima.info-5" 148882 506))
("Definições para inference_result" . ("maxima.info-6" 11240 4737))
("Definições para interpol" . ("maxima.info-5" 150033 9537))
("Definições para itensor" . ("maxima.info-3" 71382 70872))
("Definições para lbfgs" . ("maxima.info-5" 160911 5355))
("Definições para lindstedt" . ("maxima.info-5" 166507 1455))
("Definições para linearalgebra" . ("maxima.info-5" 173054 27557))
("Definições para lsquares" . ("maxima.info-5" 200896 9094))
("Definições para makeOrders" . ("maxima.info-5" 210235 902))
("Definições para manipulação da dados" . ("maxima.info-4" 271595 8547))
("Definições para mnewton" . ("maxima.info-5" 211367 1583))
("Definições para numericalio" . ("maxima.info-5" 215996 3674))
("Definições para o Pacote atensor" . ("maxima.info-3" 212245 5425))
("Definições para opsubst" . ("maxima.info-5" 219900 2355))
("Definições para plotdf" . ("maxima.info-5" 250387 9536))
("Definições para polinómios ortogonais" . ("maxima.info-5" 241213 7474))
("Definições para ponto Flutuante" . ("maxima.info-2" 364 4449))
("Definições para romberg" . ("maxima.info-5" 260137 7056))
("Definições para sequências de caracteres" . ("maxima.info-6" 63709 14257))
("Definições para simplex" . ("maxima.info-5" 267919 3780))
("Definições para simplification" . ("maxima.info-5" 272401 20598))
("Definições para solve_rec" . ("maxima.info-6" 1117 8552))
("Definições para stats" . ("maxima.info-6" 16127 28850))
("Definições para stirling" . ("maxima.info-6" 46417 1870))
("Definições para zeilberger" . ("maxima.info-6" 104877 5905))
("Depuração do Código Fonte" . ("maxima.info-4" 243177 3988))
("Descartando" . ("maxima.info-1" 25177 703))
("Desigualdade" . ("maxima.info-1" 149466 176))
("Documentação" . ("maxima.info-1" 25984 942))
("Ficheiros" . ("maxima.info-1" 267095 402))
("Função" . ("maxima.info-4" 151012 5030))
("Identificadores" . ("maxima.info-1" 144242 2198))
("Interrupções" . ("maxima.info-4" 3843 1071))
("Introdução a Ambiente em Tempo de Execução" . ("maxima.info-4" 2614 1046))
("Introdução a Conjuntos" . ("maxima.info-4" 87243 10279))
("Introdução a Definição de Função" . ("maxima.info-4" 150817 77))
("Introdução a Expressões" . ("maxima.info-1" 139310 1554))
("Introdução a Fluxo de Programa" . ("maxima.info-4" 215230 171))
("Introdução a Funções Elípticas e Integrais" . ("maxima.info-2" 113944 3639))
("Introdução a Funções Especiais" . ("maxima.info-2" 97807 1482))
("Introdução a Integração" . ("maxima.info-2" 149478 856))
("Introdução a Linha de Comandos" . ("maxima.info-1" 33860 9169))
("Introdução a Listas" . ("maxima.info-4" 73859 783))
("Introdução a Matrizes e Álgebra Linear" . ("maxima.info-3" 521 176))
("Introdução a Numérico" . ("maxima.info-2" 245230 55))
("Introdução a Opções Diversas" . ("maxima.info-4" 10693 282))
("Introdução a Polinómios" . ("maxima.info-2" 18356 3075))
("Introdução a QUADPACK" . ("maxima.info-2" 173283 3956))
("Introdução a Regras e Modelos" . ("maxima.info-4" 26808 938))
("Introdução a Séries" . ("maxima.info-3" 217968 430))
("Introdução a Units" . ("maxima.info-6" 78240 4009))
("Introdução a ctensor" . ("maxima.info-3" 142548 4404))
("Introdução a distrib" . ("maxima.info-5" 39876 7810))
("Introdução a interpol" . ("maxima.info-5" 149672 262))
("Introdução a itensor" . ("maxima.info-3" 59146 12140))
("Introdução a lbfgs" . ("maxima.info-5" 159828 995))
("Introdução a linearalgebra" . ("maxima.info-5" 168296 4644))
("Introdução a manipulação de sequências de caracteres" . ("maxima.info-6" 48733 4897))
("Introdução a numericalio" . ("maxima.info-5" 213263 2625))
("Introdução a plotdf" . ("maxima.info-5" 248957 1337))
("Introdução a polinómios ortogonais" . ("maxima.info-5" 222597 18490))
("Introdução a simplex" . ("maxima.info-5" 267477 346))
("Introdução a simplification" . ("maxima.info-5" 272041 243))
("Introdução a solve_rec" . ("maxima.info-6" 420 595))
("Introdução a stats" . ("maxima.info-6" 10019 1092))
("Introdução a zeilberger" . ("maxima.info-6" 102767 2005))
("Introdução ao Pacote Trigonométrico" . ("maxima.info-2" 87312 869))
("Introdução ao Pacote atensor" . ("maxima.info-3" 208221 3904))
("Introdução ao pacote descriptive" . ("maxima.info-4" 265990 5433))
("Introdução às Equações Diferenciais" . ("maxima.info-2" 236244 452))
("Lisp e Maxima" . ("maxima.info-1" 21219 3862))
("Macros" . ("maxima.info-4" 156163 8461))
("N-Argumentos" . ("maxima.info-1" 70442 497))
("O pacote dynamics" . ("maxima.info-5" 131194 481))
("Operador Préfixado" . ("maxima.info-1" 72163 291))
("Operador Pósfixado" . ("maxima.info-1" 71646 394))
("Operador não fixado" . ("maxima.info-1" 71053 473))
("Operadores Aritméticos" . ("maxima.info-1" 72581 8320))
("Operadores Geral" . ("maxima.info-1" 81242 57593))
("Operadores Relacionais" . ("maxima.info-1" 81026 122))
("Pacotes de Fourier" . ("maxima.info-2" 245411 504))
("Sequências de caracteres" . ("maxima.info-1" 146556 2802))
("Sintaxe" . ("maxima.info-1" 149752 4228))
("Substantivos e Verbos" . ("maxima.info-1" 141643 2474))
("Visualização usando VTK" . ("maxima.info-5" 142450 353))
)))
(load-info-hashtables (maxima::maxima-load-pathname-directory) deffn-defvr-pairs section-pairs))
